/*
 * MDC Desktop Client Created on 15-Jul-2005
 */
package org.mdcog.client.desktop.gui;

import javax.swing.Box;
import javax.swing.JDialog;
import javax.swing.JFrame;

import javax.swing.JPanel;
import javax.swing.JButton;
import java.awt.FlowLayout;

import javax.swing.JLabel;

import org.mdcog.client.desktop.gui.images.MDCIcons;
import org.mdcog.client.desktop.utils.BrowserControl;
import org.mdcog.client.desktop.utils.MDCConfig;

import java.awt.BorderLayout;

import javax.swing.BoxLayout;
import javax.swing.JEditorPane;
import javax.swing.event.HyperlinkEvent;

/**
 * This class shows the about dialog box
 */
public class AboutDialog extends JDialog
{

    /**
     * Stores a reference to the deafult home page if one is not defined
     */
    private final static String DEFAULT_HOME = "<html><body><a href=\"http://users.ox.ac.uk/%7Ejiscpub/JISC_MDC/Index.htm\">MDC Home Page</a></body><b</html>";

    /**
     * Stores a reference to the main content pane
     */
    private javax.swing.JPanel jContentPane = null;

    /**
     * Stores a reference to the close panel
     */
    private JPanel closePanel = null;

    /**
     * Stores a reference to the close button
     */
    private JButton closeButton = null;

    /**
     * Stores a reference to the banner
     */
    private JLabel ltgbannerLabel = null;

    /**
     * Stores a reference to the display panel
     */
    private JPanel displayPanel = null;

    /**
     * Stores a reference to the title label
     */
    private JLabel titleLabel = null;

    /**
     * Stores a reference to the text panel
     */
    private JPanel textPanel = null;

    /**
     * Stores a reference to the version label
     */
    private JLabel versionLabel = null;

    /**
     * Stores a reference to the desktop label
     */
    private JLabel desktopLabel = null;

    /**
     * Stores a reference to the editor pane
     */
    private JEditorPane jEditorPane = null;

    /**
     * This is the default constructor
     * 
     * @param parent the parent frame
     */
    public AboutDialog(JFrame parent)
    {
        super(parent);
        initialize();
        // set the screen position relative to the parent window
        setLocationRelativeTo(parent);

    }

    /**
     * This method initializes this
     * 
     * @return void
     */
    private void initialize()
    {
        this.setTitle("About Desktop Client");
        this.setResizable(false);
        this.setModal(true);
        this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        this.setSize(458, 308);
        this.setContentPane(getJContentPane());
    }

    /**
     * This method initializes main content pane
     * 
     * @return javax.swing.JPanel
     */
    private javax.swing.JPanel getJContentPane()
    {
        if (jContentPane == null)
        {
            ltgbannerLabel = new JLabel();
            jContentPane = new javax.swing.JPanel();
            jContentPane.setLayout(new java.awt.BorderLayout());
            ltgbannerLabel.setIcon(MDCIcons.LTGBANNER_ICON);
            jContentPane.add(getClosePanel(), java.awt.BorderLayout.SOUTH);
            jContentPane.add(getDisplayPanel(), java.awt.BorderLayout.NORTH);
        }
        return jContentPane;
    }

    /**
     * This method initializes close panel
     * 
     * @return javax.swing.JPanel
     */
    private JPanel getClosePanel()
    {
        if (closePanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            closePanel = new JPanel();
            closePanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            closePanel.add(getCloseButton(), null);
        }
        return closePanel;
    }

    /**
     * This method initializes close button
     * 
     * @return javax.swing.JButton
     */
    private JButton getCloseButton()
    {
        if (closeButton == null)
        {
            closeButton = new JButton();
            closeButton.setText("Close");
            closeButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    //close and dispose of the dialog
                    dispose();
                }
            });
        }
        return closeButton;
    }

    /**
     * This method initializes display panel
     * 
     * @return javax.swing.JPanel
     */
    private JPanel getDisplayPanel()
    {
        if (displayPanel == null)
        {
            BorderLayout borderLayout = new BorderLayout();
            displayPanel = new JPanel();
            displayPanel.setLayout(borderLayout);
            displayPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(10, 10, 10, 10));
            borderLayout.setVgap(10);
            displayPanel.add(ltgbannerLabel, java.awt.BorderLayout.SOUTH);
            displayPanel.add(getJEditorPane(), java.awt.BorderLayout.CENTER);
            displayPanel.add(getTextPanel(), java.awt.BorderLayout.NORTH);
        }
        return displayPanel;
    }

    /**
     * This method initializes text panel
     * 
     * @return javax.swing.JPanel
     */
    private JPanel getTextPanel()
    {
        if (textPanel == null)
        {
            desktopLabel = new JLabel();
            versionLabel = new JLabel();
            textPanel = new JPanel();
            titleLabel = new JLabel();
            textPanel.setLayout(new BoxLayout(textPanel, BoxLayout.Y_AXIS));
            titleLabel.setText("Middleware for Distributed Cognition");
            titleLabel.setFont(new java.awt.Font("Dialog", java.awt.Font.BOLD, 24));
            versionLabel.setText("Version 1.0");
            versionLabel.setFont(new java.awt.Font("Dialog", java.awt.Font.BOLD, 16));
            desktopLabel.setText("Desktop Client");
            desktopLabel.setFont(new java.awt.Font("Dialog", java.awt.Font.BOLD, 16));

            textPanel.add(Box.createVerticalStrut(10));
            textPanel.add(titleLabel, null);
            textPanel.add(Box.createVerticalStrut(10));
            textPanel.add(desktopLabel, null);
            textPanel.add(Box.createVerticalStrut(10));
            textPanel.add(versionLabel, null);
            textPanel.add(Box.createVerticalStrut(10));

        }
        return textPanel;
    }

    /**
     * This method initializes editor pane
     * 
     * @return javax.swing.JEditorPane
     */
    private JEditorPane getJEditorPane()
    {
        if (jEditorPane == null)
        {
            // get the home pane from the configuration file
            String homePage = MDCConfig.getInstance().getProperty(MDCConfig.MDC_HYPERLINK, DEFAULT_HOME);

            jEditorPane = new JEditorPane();
            jEditorPane.setContentType("text/html");
            jEditorPane.setEditable(false);
            jEditorPane.setBackground(this.getBackground());
            jEditorPane.setText(homePage);
            jEditorPane.addHyperlinkListener(new javax.swing.event.HyperlinkListener()
            {

                public void hyperlinkUpdate(javax.swing.event.HyperlinkEvent e)
                {
                    if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED)
                    {
                        BrowserControl.displayURL(e.getURL().toString());
                    }
                }
            });
        }
        return jEditorPane;
    }
} //  @jve:decl-index=0:visual-constraint="59,9"
