/*
 * MDC Desktop Client Created on 05-May-2005
 */
package org.mdcog.client.desktop.gui;

import java.awt.BorderLayout;
import java.awt.FlowLayout;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;

import org.mdcog.client.desktop.gui.controllers.CreateListDialogController;
import org.mdcog.client.desktop.gui.panels.CreateListCreateDocumentPanel;
import org.mdcog.client.desktop.gui.panels.CreateListExportPanel;
import org.mdcog.client.desktop.gui.panels.CreateListResourcesGridPanel;
import org.mdcog.client.desktop.model.ResourceList;

/**
 * This class implements the create list dialog. <br/><br/>Note - It was
 * partially created using the Eclipse Visual Editor plugin
 */
public class CreateListDialog extends JDialog
{

    /**
     * Stores a reference to the controller that looks after the dialog
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private CreateListDialogController controller = null;


    /**
     * Stores a reference to the main pane panel for laying out screen
     */
    private javax.swing.JPanel mainPane = null;

    /**
     * Stores a reference to the south pane panel for laying out screen
     */
    private JPanel southPanel = null;

    /**
     * Stores a reference to the export panel for laying out screen
     * 
     * @uml.property name="createListExportPanel"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private CreateListExportPanel createListExportPanel = null;

    /**
     * Stores a reference to the create document panel for laying out screen
     * 
     * @uml.property name="createListCreateDocumentPanel"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private CreateListCreateDocumentPanel createListCreateDocumentPanel = null;

    /**
     * Stores a reference to the resource grid panel for laying out screen
     * 
     * @uml.property name="createListResourcesGridPanel"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private CreateListResourcesGridPanel createListResourcesGridPanel = null;


    /**
     * Stores a reference to the close button on the screen
     */
    private JButton closeButton = null;

    /**
     * Stores a reference to the close panel for laying out screen
     */
    private JPanel closePanel = null;

    /**
     * Stores a reference to the actions panel for laying out screen
     */
    private JPanel actionsPanel = null;

    /**
     * This is the default constructor fro the dialog
     * 
     * @param entry This is the model for the dialog
     * @param parent The parent window that the dialog is modal to
     */
    public CreateListDialog(ResourceList entry, JFrame parent)
    {
        super(parent);
        // create the controller passing the model
        this.controller = new CreateListDialogController(entry,parent);
        // initialise the dialog controlls
        initialize();
        // set the screen position relative to the parent window
        setLocationRelativeTo(parent);
    }

    /**
     * This method initializes the screen creating all the panels and laying
     * them out on the screen
     */
    private void initialize()
    {
        this.setTitle("Create resource list");
        this.setModal(true);
        this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        this.setSize(985, 649);
        this.setContentPane(getMainPane());
        // make sure we dispose of the controller when we close
        this.addWindowListener(new java.awt.event.WindowAdapter()
        {

            public void windowClosing(java.awt.event.WindowEvent e)
            {
                controller.dispose();
            }
        });
    }

    /**
     * This method initializes the main panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="mainPane"
     */
    private javax.swing.JPanel getMainPane() {
        if (mainPane == null) {
            mainPane = new javax.swing.JPanel();
            mainPane.setLayout(new java.awt.BorderLayout());
            mainPane.setBorder(javax.swing.BorderFactory.createEmptyBorder(10, 10, 10, 10));
            mainPane.add(getSouthPanel(), java.awt.BorderLayout.SOUTH);
            mainPane.add(getCreateListResourcesGridPanel(), java.awt.BorderLayout.CENTER);
        }
        return mainPane;
    }

    /**
     * This method initializes the south panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="southPanel"
     */
    private JPanel getSouthPanel() {
        if (southPanel == null) {
            southPanel = new JPanel();
            southPanel.setLayout(new BorderLayout());
            southPanel.add(getClosePanel(), java.awt.BorderLayout.SOUTH);
            southPanel.add(getActionsPanel(), java.awt.BorderLayout.NORTH);
        }
        return southPanel;
    }

    /**
     * This method initializes the export panel
     * 
     * @return org.mdc.client.desktop.gui.panels.CreateListExportPanel
     * 
     * @uml.property name="createListExportPanel"
     */
    private CreateListExportPanel getCreateListExportPanel() {
        if (createListExportPanel == null) {
            createListExportPanel = new CreateListExportPanel(controller);
        }
        return createListExportPanel;
    }

    /**
     * This method initializes
     * 
     * @return org.mdc.client.desktop.gui.panels.CreateListCreateDocumentPanel
     * 
     * @uml.property name="createListCreateDocumentPanel"
     */
    private CreateListCreateDocumentPanel getCreateListCreateDocumentPanel() {
        if (createListCreateDocumentPanel == null) {
            createListCreateDocumentPanel = new CreateListCreateDocumentPanel(controller);
        }
        return createListCreateDocumentPanel;
    }

    /**
     * This method initializes create document panel
     * 
     * @return org.mdc.client.desktop.gui.panels.CreateListCreateDocumentPanel
     * 
     * @uml.property name="createListResourcesGridPanel"
     */
    private CreateListResourcesGridPanel getCreateListResourcesGridPanel() {
        if (createListResourcesGridPanel == null) {
            createListResourcesGridPanel = new CreateListResourcesGridPanel(controller);
        }
        return createListResourcesGridPanel;
    }

    /**
     * This method initializes the close panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="closePanel"
     */
    private JPanel getClosePanel() {
        if (closePanel == null) {
            closePanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            closePanel.setLayout(flowLayout);
            closePanel.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            closePanel.setSize(473, 37);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            closePanel.add(getCloseButton(), null);
        }
        return closePanel;
    }

    /**
     * This method initializes the close button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="closeButton"
     */
    private JButton getCloseButton() {
        if (closeButton == null) {
            closeButton = new JButton();
            closeButton.setText("Close");
            closeButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    // close and dispose of the dialog
                    dispose();
                }
            });
        }
        return closeButton;
    }

    /**
     * This method initializes the action panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="actionsPanel"
     */
    private JPanel getActionsPanel() {
        if (actionsPanel == null) {
            actionsPanel = new JPanel();
            actionsPanel.setLayout(new BoxLayout(actionsPanel, BoxLayout.X_AXIS));
            actionsPanel.add(getCreateListExportPanel(), null);
            actionsPanel.add(getCreateListCreateDocumentPanel(), null);
        }
        return actionsPanel;
    }

} //  @jve:decl-index=0:visual-constraint="25,6"
