/*
 * MDC Desktop Client Created on 20-Apr-2005
 */
package org.mdcog.client.desktop.gui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.io.FileNotFoundException;

import javax.swing.JFrame;
import javax.swing.UIManager;

import org.mdcog.client.desktop.dataaccess.InvalidFileFormatException;
import org.mdcog.client.desktop.gui.controllers.LibraryTabController;
import org.mdcog.client.desktop.gui.menus.DesktopMenuBar;
import org.mdcog.client.desktop.gui.panels.DesktopTabPanel;
import org.mdcog.client.desktop.model.MDCLibraryModel;
import org.mdcog.client.desktop.utils.MDCConfig;

/**
 * This class implements the main application window. It is this class that
 * should be called to start up the client. <br/><br/>Note - It was partially
 * created using the Eclipse Visual Editor plugin
 */
public class DesktopClientApp extends JFrame
{

    /**
     * Stores a reference to the main pane panel for laying out screen
     */
    private javax.swing.JPanel mainPane = null; //  @jve:decl-index=0:visual-constraint="22,42"

    /**
     * Stores a reference to the tab control on the screen
     * 
     * @uml.property name="desktopTabPane"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private DesktopTabPanel desktopTabPane = null;

    /**
     * Stores a reference to the main menu bar on the screen
     * 
     * @uml.property name="desktopMenuBar"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private DesktopMenuBar desktopMenuBar = null;

    /**
     * This method initializes the tab pane
     * 
     * @return org.mdc.client.desktop.gui.DesktopTabPane
     * @uml.property name="desktopTabPane"
     */
    private DesktopTabPanel getDesktopTabPane()
    {
        if (desktopTabPane == null)
        {
            desktopTabPane = new DesktopTabPanel();
        }
        return desktopTabPane;
    }

    /**
     * This method initializes menu
     * 
     * @return org.mdc.client.desktop.gui.DesktopMenuBar
     * @uml.property name="desktopMenuBar"
     */
    private DesktopMenuBar getDesktopMenuBar()
    {
        if (desktopMenuBar == null)
        {
            desktopMenuBar = new DesktopMenuBar(this);

        }
        return desktopMenuBar;
    }

    /**
     * The main method that starts the application setting the look and feel to
     * the current operating system
     * 
     * @param args
     */
    public static void main(String[] args)
    {
        String startupFile = "";
        // set start up parameters
        if (args.length >= 1)
        {
            // we have an RLY specified as an argument
            startupFile = args[0];
        }
        else
        {
            // load the config file to get the last loaded library
            MDCConfig config = MDCConfig.getInstance();
            if (config.loadConfig())
            {
                startupFile = config.getProperty(MDCConfig.LASTLIBRARY);
                if (startupFile == null || startupFile.length() == 0)
                {
                    System.out.println("MISSING CONFIG KEY FOR LAST LOADED LIBRARY");
                }
            }
        }

        // if we have a startup file try and open it
        if (startupFile != null && startupFile.length() > 0)
        {
            try
            {
                // open the library into model
                MDCLibraryModel.getInstance().openLibrary(startupFile);
            }
            catch (FileNotFoundException e)
            {
                // print error but ignore and open blank
                System.err.println("RLY FILE NOT FOUND");
            }
            catch (InvalidFileFormatException e)
            {
                // print error but ignore and open blank
                System.err.println("RLY FILE INVALID FORMAT");
            }
        }

        // set up look and feel of application
        try
        {
            // set it to the system format
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }

        // now create the application and display it
        DesktopClientApp app = new DesktopClientApp();
        app.setVisible(true);
    }

    /**
     * This is the default constructor
     */
    public DesktopClientApp()
    {
        super();
        initialize();
        // tell the master controller this this instance is the top parent frame
        LibraryTabController.getInstance().setApplicationFrame(this);
    }

    /**
     * This method initializes the application window and creates the sub panels
     */
    private void initialize()
    {
        this.setExtendedState(JFrame.MAXIMIZED_BOTH);
        this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        this.setJMenuBar(getDesktopMenuBar());
        this.setName("desktopClientAppFrame");
        this.setSize(1283, 592);
        this.setTitle("MDC Desktop Client");
        this.setContentPane(getMainPane());
        this.addWindowListener(new java.awt.event.WindowAdapter()
        {

            public void windowClosing(java.awt.event.WindowEvent e)
            {
                LibraryTabController.getInstance().applicationTerminating();
                // store current filename back to config file
                MDCConfig config = MDCConfig.getInstance();
                config.setProperty(MDCConfig.LASTLIBRARY, MDCLibraryModel.getInstance().getCurrentLibraryFileName());
                config.saveConfig();
            }
        });

    }

    /**
     * This method initializes the main panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="mainPane"
     */
    private javax.swing.JPanel getMainPane()
    {
        if (mainPane == null)
        {
            GridBagConstraints desktopPanelConstraints = new GridBagConstraints();
            mainPane = new javax.swing.JPanel();
            mainPane.setLayout(new GridBagLayout());
            mainPane.setPreferredSize(new java.awt.Dimension(0, 3));
            mainPane.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            mainPane.setBorder(javax.swing.BorderFactory.createEmptyBorder(5, 5, 5, 5));
            desktopPanelConstraints.gridx = 0;
            desktopPanelConstraints.gridy = 1;
            desktopPanelConstraints.weightx = 1.0;
            desktopPanelConstraints.weighty = 1.0;
            desktopPanelConstraints.fill = java.awt.GridBagConstraints.BOTH;
            mainPane.add(getDesktopTabPane(), desktopPanelConstraints);
        }
        return mainPane;
    }

} //  @jve:decl-index=0:visual-constraint="31,9"
