/*
 * MDC Desktop Client Created on 19-May-2005
 */
package org.mdcog.client.desktop.gui;

import java.awt.FlowLayout;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

/**
 * This dialog allows the user to edit an annotation. It does not have a
 * controller because it is so simple that it does not warrant one. <br/>
 * <br/>Note - It was partially created using the Eclipse Visual Editor plugin
 */
public class EditAnnotationDialog extends JDialog
{

    /**
     * Stores a reference to the anottation text
     */
    private String annotation = "";

    /**
     * Stores a reference to the whether the annotation was updated
     */
    private boolean annotationUpdated = false;

    /**
     * Stores a reference to the main content pane
     */
    private javax.swing.JPanel mainContentPane = null;

    /**
     * Stores a reference to the buttons panel
     */
    private JPanel buttonsPanel = null;

    /**
     * Stores a reference to the update button
     */
    private JButton updateButton = null;

    /**
     * Stores a reference to the close button
     */
    private JButton closeButton = null;

    /**
     * Stores a reference to the annotation scroll pane
     */
    private JScrollPane textScrollPane = null;

    /**
     * Stores a reference to the annotation text area
     */
    private JTextArea annotationTextArea = null;

    /**
     * This is the default constructor
     * 
     * @param anno The annottation text to display
     * @param parent The parent window of this dialog
     */
    public EditAnnotationDialog(String anno, JFrame parent)
    {
        super(parent);
        // create dialog
        initialize();
        // store annotation if not null and place on screen
        if (anno != null)
        {
            this.annotation = anno;
            annotationTextArea.setText(annotation);
        }
        // set the screen position relative to the parent window
        setLocationRelativeTo(parent);
    }

    /**
     * Returns the updated annotation
     * 
     * @return Returns the annotation.
     * 
     * @uml.property name="annotation"
     */
    public String getAnnotation() {
        return annotation;
    }


    /**
     * Tell the caller if the annotation was updated during the dialogs lifetime
     * 
     * @return true if annotation was updated
     */
    public boolean annotationUpdated()
    {
        return annotationUpdated;
    }

    /**
     * This method initializes this dialog
     */
    private void initialize()
    {
        this.setModal(true);
        this.setTitle("Edit Annotation");
        this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        this.setSize(771, 458);
        this.setContentPane(getMainContentPane());
    }

    /**
     * This method initializes main content pane
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="mainContentPane"
     */
    private javax.swing.JPanel getMainContentPane() {
        if (mainContentPane == null) {
            mainContentPane = new javax.swing.JPanel();
            mainContentPane.setLayout(new java.awt.BorderLayout());
            mainContentPane.add(getButtonsPanel(), java.awt.BorderLayout.SOUTH);
            mainContentPane.add(getTextScrollPane(), java.awt.BorderLayout.CENTER);
        }
        return mainContentPane;
    }

    /**
     * This method initializes the buttons panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="buttonsPanel"
     */
    private JPanel getButtonsPanel() {
        if (buttonsPanel == null) {
            FlowLayout flowLayout1 = new FlowLayout();
            buttonsPanel = new JPanel();
            buttonsPanel.setLayout(flowLayout1);
            flowLayout1.setAlignment(java.awt.FlowLayout.RIGHT);
            buttonsPanel.add(getUpdateButton(), null);
            buttonsPanel.add(getCloseButton(), null);
        }
        return buttonsPanel;
    }

    /**
     * This method initializes the update button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="updateButton"
     */
    private JButton getUpdateButton() {
        if (updateButton == null) {
            updateButton = new JButton();
            updateButton.setText("Update");
            updateButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    // store the value back into annotation
                    annotation = annotationTextArea.getText();
                    // set flag to state updated
                    annotationUpdated = true;
                    // close the dialog
                    dispose();
                }
            });
        }
        return updateButton;
    }

    /**
     * This method initializes the close button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="closeButton"
     */
    private JButton getCloseButton() {
        if (closeButton == null) {
            closeButton = new JButton();
            closeButton.setText("Close");
            closeButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    // close the dialog
                    dispose();
                }
            });
        }
        return closeButton;
    }

    /**
     * This method initializes the text scroll pane
     * 
     * @return javax.swing.JScrollPane
     * 
     * @uml.property name="textScrollPane"
     */
    private JScrollPane getTextScrollPane() {
        if (textScrollPane == null) {
            textScrollPane = new JScrollPane();
            textScrollPane.setViewportView(getAnnotationTextArea());
            textScrollPane.setHorizontalScrollBarPolicy(javax.swing.JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);
            textScrollPane.setVerticalScrollBarPolicy(javax.swing.JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
            textScrollPane.setBorder(javax.swing.BorderFactory.createCompoundBorder(javax.swing.BorderFactory.createEmptyBorder(
                10,
                10,
                10,
                10), new javax.swing.border.SoftBevelBorder(javax.swing.border.SoftBevelBorder.LOWERED)));
        }
        return textScrollPane;
    }

    /**
     * This method initializes the annotation text area
     * 
     * @return javax.swing.JTextArea
     * 
     * @uml.property name="annotationTextArea"
     */
    private JTextArea getAnnotationTextArea() {
        if (annotationTextArea == null) {
            annotationTextArea = new JTextArea();
            annotationTextArea.setLineWrap(true);
            annotationTextArea.setTabSize(3);
            annotationTextArea.setFont(new java.awt.Font("Dialog", java.awt.Font.PLAIN, 14));
        }
        return annotationTextArea;
    }

} //  @jve:decl-index=0:visual-constraint="53,24"
