/*
 * MDC Desktop Client Created on 13-May-2005
 */
package org.mdcog.client.desktop.gui;

import java.awt.FlowLayout;
import java.util.Collection;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

import org.mdcog.client.desktop.gui.controllers.AddNewResourceItemDialogController;
import org.mdcog.client.desktop.gui.panels.AddResourceTabPanel;

/**
 * This class implements the add resource popup dialog <br/><br/>Note - It was
 * partially created using the Eclipse Visual Editor plugin
 */
public class NewResourceItemDialog extends JDialog
{

    /**
     * Stores a reference to the parent frame for popups
     */
    private JFrame parentFrame = null;

    /**
     * Stores a reference to the controller for the dialog
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private AddNewResourceItemDialogController controller = null;


    /**
     * Stores a reference to the main panel for laying out controls on screen
     */
    private javax.swing.JPanel mainContentPane = null;

    /**
     * Stores a reference to the tabbed dialoog that holds a tab for each type
     * of resource that can be added
     */
    private JTabbedPane resourceItemsTabsPane = null;

    /**
     * Stores a reference to the close panel for laying out buttons on screen
     */
    private JPanel closePanel = null;

    /**
     * Stores a reference to the close button on the screen
     */
    private JButton closeButton = null;

    /**
     * This is the default constructor
     * 
     * @param parent
     */
    public NewResourceItemDialog(JFrame parent)
    {
        super(parent);
        // create the controller for this dialog
        this.controller = new AddNewResourceItemDialogController();
        parentFrame = parent;
        initialize();
        // set dialogue relative to the parent on the screen
        setLocationRelativeTo(parentFrame);
    }

    /**
     * Returns the created resources to the caller as a collection
     * 
     * @return The resources that were created during the life of the dialog
     */
    public Collection getCreatedResources()
    {
        return controller.getCreatedResources();
    }

    /**
     * This method initializes the screen and creates all controls and panels
     */
    private void initialize()
    {
        this.setResizable(false);
        this.setModal(true);
        this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        this.setTitle("Add new resource");
        this.setSize(800, 468);
        this.setContentPane(getMainContentPane());
    }

    /**
     * This method initializes main content panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="mainContentPane"
     */
    private javax.swing.JPanel getMainContentPane() {
        if (mainContentPane == null) {
            mainContentPane = new javax.swing.JPanel();
            mainContentPane.setLayout(new java.awt.BorderLayout());
            mainContentPane.setBorder(javax.swing.BorderFactory.createEmptyBorder(20, 10, 10, 10));
            mainContentPane.add(getResourceItemsTabsPane(), java.awt.BorderLayout.CENTER);
            mainContentPane.add(getClosePanel(), java.awt.BorderLayout.SOUTH);
        }
        return mainContentPane;
    }

    /**
     * This method initializes the resource item tab panel
     * 
     * @return javax.swing.JTabbedPane
     * 
     * @uml.property name="resourceItemsTabsPane"
     */
    private JTabbedPane getResourceItemsTabsPane() {
        if (resourceItemsTabsPane == null) {
            resourceItemsTabsPane = new JTabbedPane();
            resourceItemsTabsPane.add("Book", new AddResourceTabPanel(controller, "Book", parentFrame));
            resourceItemsTabsPane.add("Journal", new AddResourceTabPanel(controller, "Journal", parentFrame));
            resourceItemsTabsPane.add("Image", new AddResourceTabPanel(controller, "Image", parentFrame));
            resourceItemsTabsPane.add("Video", new AddResourceTabPanel(controller, "Video", parentFrame));
        }
        return resourceItemsTabsPane;
    }

    /**
     * This method initializes the close panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="closePanel"
     */
    private JPanel getClosePanel() {
        if (closePanel == null) {
            FlowLayout flowLayout1 = new FlowLayout();
            closePanel = new JPanel();
            closePanel.setLayout(flowLayout1);
            flowLayout1.setAlignment(java.awt.FlowLayout.RIGHT);
            closePanel.add(getCloseButton(), null);
        }
        return closePanel;
    }

    /**
     * This method initializes the close button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="closeButton"
     */
    private JButton getCloseButton() {
        if (closeButton == null) {
            closeButton = new JButton();
            closeButton.setText("Close");
            closeButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    // close and dispose of the dialog
                    dispose();
                }
            });
        }
        return closeButton;
    }

}  //  @jve:decl-index=0:visual-constraint="26,35"
