/*
 * MDC Desktop Client Created on 16-May-2005
 */
package org.mdcog.client.desktop.gui;

import java.awt.FlowLayout;
import java.awt.GridLayout;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import org.mdcog.client.desktop.gui.controllers.OpenLocalURLDialogController;
import org.mdcog.client.desktop.gui.models.MDCModelUpdateListener;
import org.mdcog.client.desktop.model.ResourceItem;

/**
 * This class implements the open local URL dialog for assigning and opening
 * resource items that are stored on the users local machine <br/><br/>Note -
 * It was partially created using the Eclipse Visual Editor plugin
 */
public class OpenLocalURLDialog extends JDialog implements MDCModelUpdateListener
{

    /**
     * Stores a reference to the controller for this dialog
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private OpenLocalURLDialogController controller = null;


    /**
     * Stores a reference to the main content pane
     */
    private javax.swing.JPanel jContentPane = null;

    /**
     * Stores a reference to the buttons panel for laying out items on the
     * screen
     */
    private JPanel buttonsPanel = null;

    /**
     * Stores a reference to the open button on the screen
     */
    private JButton openButton = null;

    /**
     * Stores a reference to the change button on the screen
     */
    private JButton changeButton = null;

    /**
     * Stores a reference to the close button on the screen
     */
    private JButton closeButton = null;

    /**
     * Stores a reference to the label panel for laying out items on the screen
     */
    private JPanel labelsPanel = null;

    /**
     * Stores a reference to the fields panel for laying out items on the screen
     */
    private JPanel fieldsPanel = null;

    /**
     * Stores a reference to the filename label on the screen
     */
    private JLabel filenameLabel = null;

    /**
     * Stores a reference to the url label on the screen
     */
    private JLabel urlLabel = null;

    /**
     * Stores a reference to the filename read only text box on the screen
     */
    private JTextField filenameTextField = null;

    /**
     * Stores a reference to the url read only text box on the screen
     */
    private JTextField urlTextField = null;

    /**
     * Stores a reference to the filename panel for laying out items on the
     * screen
     */
    private JPanel filenamePanel = null;

    /**
     * Stores a reference to the url panel for laying out items on the screen
     */
    private JPanel urlPanel = null;

    /**
     * Stores a reference to the clear button on the screen
     */
    private JButton clearButton = null;

    /**
     * This is the default constructor
     * 
     * @param parent The window the dialog is modal to
     * @param item The resource item that is the model for this dialog
     */
    public OpenLocalURLDialog(JFrame parent, ResourceItem item)
    {
        super(parent);
        // create the controller
        controller = new OpenLocalURLDialogController(item);
        // register the dialogue as requiring notifications when it updates the
        // model
        controller.registerModelUpdateListener(this);
        initialize();
        // refresh screen
        modelUpdated();
        // set the position relative to the parent
        setLocationRelativeTo(parent);
    }

    /**
     * This call back method is called by the controller whenever it makes
     * changes to the model so that the screen can refresh any screen controls
     */
    public void modelUpdated()
    {
        // update the text on the field now the model has changed
        filenameTextField.setText(controller.getFilename());
        urlTextField.setText(controller.getURL());
        // enable open and clear file button if we have a file
        openButton.setEnabled(controller.canOpenURL());
        clearButton.setEnabled(controller.canOpenURL());
    }

    /**
     * This method initializes the dialog creating and laying out controls
     * 
     */
    private void initialize()
    {
        this.setModal(true);
        this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        this.setTitle("Open Local URL");
        this.setResizable(false);
        this.setSize(799, 159);
        this.setContentPane(getJContentPane());
    }

    /**
     * This method initializes main content panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="jContentPane"
     */
    private javax.swing.JPanel getJContentPane() {
        if (jContentPane == null) {
            jContentPane = new javax.swing.JPanel();
            jContentPane.setLayout(new java.awt.BorderLayout());
            jContentPane.setBorder(javax.swing.BorderFactory.createEmptyBorder(10, 10, 0, 10));
            jContentPane.add(getButtonsPanel(), java.awt.BorderLayout.SOUTH);
            jContentPane.add(getLabelsPanel(), java.awt.BorderLayout.WEST);
            jContentPane.add(getFieldsPanel(), java.awt.BorderLayout.CENTER);
        }
        return jContentPane;
    }

    /**
     * This method initializes the button panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="buttonsPanel"
     */
    private JPanel getButtonsPanel() {
        if (buttonsPanel == null) {
            FlowLayout flowLayout1 = new FlowLayout();
            buttonsPanel = new JPanel();
            buttonsPanel.setLayout(flowLayout1);
            flowLayout1.setAlignment(java.awt.FlowLayout.RIGHT);
            buttonsPanel.add(getOpenButton(), null);
            buttonsPanel.add(getClearButton(), null);
            buttonsPanel.add(getChangeButton(), null);
            buttonsPanel.add(getCloseButton(), null);
        }
        return buttonsPanel;
    }

    /**
     * This method initializes the open button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="openButton"
     */
    private JButton getOpenButton() {
        if (openButton == null) {
            openButton = new JButton();
            openButton.setText("Open file");
            openButton.setEnabled(controller.canOpenURL());
            openButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    controller.openLocalURL();
                }
            });
        }
        return openButton;
    }

    /**
     * This method initializes the change button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="changeButton"
     */
    private JButton getChangeButton() {
        if (changeButton == null) {
            changeButton = new JButton();
            changeButton.setText("Assign new file");
            changeButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    controller.assignNewFile(jContentPane);
                }
            });
        }
        return changeButton;
    }

    /**
     * This method initializes the close button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="closeButton"
     */
    private JButton getCloseButton() {
        if (closeButton == null) {
            closeButton = new JButton();
            closeButton.setText("Close");
            closeButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    // close and dispose of the dialog
                    dispose();
                }
            });
        }
        return closeButton;
    }

    /**
     * This method initializes labels panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="labelsPanel"
     */
    private JPanel getLabelsPanel() {
        if (labelsPanel == null) {
            urlLabel = new JLabel();
            filenameLabel = new JLabel();
            labelsPanel = new JPanel();
            GridLayout gridLayout = new GridLayout();
            labelsPanel.setLayout(gridLayout);
            gridLayout.setRows(2);
            gridLayout.setColumns(1);
            gridLayout.setVgap(5);
            filenameLabel.setText("Filename");
            urlLabel.setText("URL");
            urlLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            filenameLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            labelsPanel.add(filenameLabel, null);
            labelsPanel.add(urlLabel, null);
        }
        return labelsPanel;
    }

    /**
     * This method initializes fields panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="fieldsPanel"
     */
    private JPanel getFieldsPanel() {
        if (fieldsPanel == null) {
            fieldsPanel = new JPanel();
            GridLayout gridLayout = new GridLayout();
            fieldsPanel.setLayout(gridLayout);
            gridLayout.setRows(2);
            gridLayout.setColumns(2);
            gridLayout.setVgap(5);
            gridLayout.setHgap(10);
            fieldsPanel.add(getFilenamePanel(), null);
            fieldsPanel.add(getUrlPanel(), null);
        }
        return fieldsPanel;
    }

    /**
     * This method initializes filenametext field
     * 
     * @return javax.swing.JTextField
     * 
     * @uml.property name="filenameTextField"
     */
    private JTextField getFilenameTextField() {
        if (filenameTextField == null) {
            filenameTextField = new JTextField();
            filenameTextField.setEditable(false);
            filenameTextField.setColumns(30);
        }
        return filenameTextField;
    }

    /**
     * This method initializes the url text field
     * 
     * @return javax.swing.JTextField
     * 
     * @uml.property name="urlTextField"
     */
    private JTextField getUrlTextField() {
        if (urlTextField == null) {
            urlTextField = new JTextField();
            urlTextField.setColumns(63);
            urlTextField.setEditable(false);
        }
        return urlTextField;
    }

    /**
     * This method initializes the filename panel 
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="filenamePanel"
     */
    private JPanel getFilenamePanel() {
        if (filenamePanel == null) {
            FlowLayout flowLayout = new FlowLayout();
            filenamePanel = new JPanel();
            filenamePanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            filenamePanel.add(getFilenameTextField(), null);
        }
        return filenamePanel;
    }

    /**
     * This method initializes the url panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="urlPanel"
     */
    private JPanel getUrlPanel() {
        if (urlPanel == null) {
            FlowLayout flowLayout = new FlowLayout();
            urlPanel = new JPanel();
            urlPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            urlPanel.add(getUrlTextField(), null);
        }
        return urlPanel;
    }

    /**
     * This method initializes the clear button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="clearButton"
     */
    private JButton getClearButton() {
        if (clearButton == null) {
            clearButton = new JButton();
            clearButton.setText("Clear file");
            clearButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    controller.clearAssignedFile();
                }
            });
        }
        return clearButton;
    }

} //  @jve:decl-index=0:visual-constraint="32,12"
