/*
 * MDC Desktop Client Created on 22-Apr-2005
 */
package org.mdcog.client.desktop.gui.controllers;

import java.util.Iterator;
import java.util.Vector;

import javax.swing.JFrame;

import org.mdcog.client.desktop.gui.models.MDCModelUpdateListener;
import org.mdcog.client.desktop.model.MDCLibraryModel;

/**
 * This class is the super controller that all controllers extend. It provides
 * the basic functionality that all controllers require.
 */
public class Controller extends Object
{

    /**
     * Stores a reference to the screens or other controllers that have
     * registered to be notified of model changes
     */
    private Vector updateListeners;

    /**
     * Stores a reference to the main model object that represents a users
     * library. Its private to force the getter to be used which instantiates
     * model if does not already exist.
     * 
     * @uml.property name="mdcLibraryModel"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private static MDCLibraryModel mdcLibraryModel = null;

    /**
     * Stores a reference to the main application frame. It is static across all
     * controllers so only needs to be stored once.
     */
    protected static JFrame applicationMainFrame;

    /**
     * contructor to the master controller is protected as this controller can
     * not be directly istantiated
     */
    protected Controller()
    {
        updateListeners = new Vector();
    }

    /**
     * Store the application frame that all controllers may need to reference.
     * Only needs to be called once on one controller and will be visable to all
     * others.
     * 
     * @param frame
     */
    public void setApplicationFrame(JFrame frame)
    {
        applicationMainFrame = frame;
    }

    /**
     * Returns a reference to the library model. Although the library is a
     * singleton all controllers should use ths method as if the controller is a
     * singleton as well then instantiation sequence problems can occur
     * 
     * @return The main model that represents the users library
     */
    protected MDCLibraryModel getMDCLibraryModel()
    {
        // if we have not created the model yet then create it
        if (mdcLibraryModel == null)
        {
            mdcLibraryModel = MDCLibraryModel.getInstance();
        }
        return mdcLibraryModel;
    }

    /**
     * Called by controllers or panels that wish to be notified when the model
     * changes. All such componets must implement the
     * MDCLibraryModelUpdateListener interface in order to be register with the
     * controller
     * 
     * @param listener The registering component cast to the
     *        MDCLibraryModelUpdateListener interface
     */
    public void registerModelUpdateListener(MDCModelUpdateListener listener)
    {
        updateListeners.add(listener);
    }

    /**
     * A controller should call this method if it updates the model in any way
     * so that all the registered listeners can be notified of the update. This
     * is an important method to call else controls will not refresh their data
     * when the underlying model changes
     */
    public void notifyListenersOfModelChange()
    {
        Iterator iter = updateListeners.iterator();
        while (iter.hasNext())
        {
            // tell the listener the model has been updated
            ((MDCModelUpdateListener) iter.next()).modelUpdated();
        }
    }

}
