/*
 * MDC Desktop Client Created on 11-May-2005
 */
package org.mdcog.client.desktop.gui.error;

import javax.swing.JFrame;
import javax.swing.JOptionPane;

/**
 * This class represents all the message boxes displayed in the MDC client
 */
public class MDCMessageBox
{

    /**
     * Show an internal error message box
     * 
     * @param exc The exception that caused the internal error
     * @param parent The parent that the message should be modal to
     */
    public static void showInternalError(Exception exc, JFrame parent)
    {
        StringBuffer msg = new StringBuffer("An unexpected Internal error has occurred ").append(exc);
        JOptionPane.showMessageDialog(parent, msg, "Internal Error", JOptionPane.ERROR_MESSAGE);
    }

    /**
     * Show message box reporting that no URL is specified
     * 
     * @param parent The parent that the message should be modal to
     */
    public static void showOpenURLError(JFrame parent)
    {
        StringBuffer msg = new StringBuffer("No URL is specified for this resource");
        JOptionPane.showMessageDialog(parent, msg, "Unknown URL", JOptionPane.ERROR_MESSAGE);
    }

    /**
     * Show message box reporting an error occurred trying to open URL
     * 
     * @param filename The filename that caused problem
     * @param parent The parent that the message should be modal to
     */
    public static void showOpenURLError(JFrame parent, String filename)
    {
        StringBuffer msg = new StringBuffer("Error occured when trying to open URL: ").append(filename).append(
                "\n\n If your not running windows, netscape is required to open the URL");
        JOptionPane.showMessageDialog(parent, msg, "Browser error", JOptionPane.ERROR_MESSAGE);
    }

    /**
     * Show message box reporting that the file was not found
     * 
     * @param filename The filename that caused problem
     * @param parent The parent that the message should be modal to
     */
    public static void showFileNotFound(String filename, JFrame parent)
    {
        StringBuffer msg = new StringBuffer("The file ").append(filename).append(" was not found");

        JOptionPane.showMessageDialog(parent, msg, "File not found", JOptionPane.ERROR_MESSAGE);
    }

    /**
     * Show message box reporting file had an invalid format
     * 
     * @param filename The filename that caused problem
     * @param parent The parent that the message should be modal to
     */
    public static void showInvalidFileFormat(String filename, JFrame parent)
    {
        StringBuffer msg = new StringBuffer("The file ").append(filename).append(
                " was not in the correct format or has become corrupt");

        JOptionPane.showMessageDialog(parent, msg, "Invalid format", JOptionPane.ERROR_MESSAGE);

    }

    /**
     * Show message box reporting a delete on all resources is about to be
     * performed
     * 
     * @param parent The parent that the message should be modal to
     * @return The option selected Note -1 if directly closed
     */
    public static int showDeleteMasterResourceWarning(JFrame parent)
    {
        return JOptionPane
                .showConfirmDialog(
                        parent,
                        "Deleting this resource will remove it from the whole library and any of your personal libraries. \n\nAre you sure you want to delete?\n\n",
                        "Delete master resource?", JOptionPane.YES_NO_OPTION, JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Show message box reporting that a file already exists and does the user
     * want to over write *
     * 
     * @param filename The filename that exists
     * @param parent The parent that the message should be modal to
     * @return The option selected Note -1 if directly closed
     */
    public static int showFileExistsWarning(String filename, JFrame parent)
    {
        StringBuffer msg = new StringBuffer("The file ").append(filename).append(
                " all ready exists. \n\nDo you want to overwrite?");

        return JOptionPane.showConfirmDialog(parent, msg, "File already exists?", JOptionPane.YES_NO_OPTION,
                JOptionPane.QUESTION_MESSAGE);
    }

    /**
     * Show message box reporting that you can not create list without items
     * 
     * @param parent The parent that the message should be modal to
     */
    public static void showCreateListWarning(JFrame parent)
    {
        JOptionPane.showMessageDialog(parent, "You need to allocate resources in your folder to create a list.",
                "No resource items in list", JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Show message box reporting you have to select items to save
     * 
     * @param parent The parent that the message should be modal to
     */
    public static void showSaveToMyLibraryListWarning(JFrame parent)
    {
        JOptionPane.showMessageDialog(parent, "You need to select one or more resources in list to save to  mylibrary.",
                "No resource items selected", JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Show message box reporting that the library has changed and does the user
     * want to save it first
     * 
     * @param parent The parent that the message should be modal to
     * @return The option selected Note -1 if directly closed
     */
    public static int showSaveLibraryWarning(JFrame parent)
    {
        return JOptionPane.showConfirmDialog(parent, "Your current library has changed. Do you want to save first?",
                "Library changed", JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.INFORMATION_MESSAGE);
    }

    /**
     * Show message box reporting the application is about to terminate with
     * unsaved changes and does the user want to save
     * 
     * @param parent The parent that the message should be modal to
     * @return The option selected Note -1 if directly closed
     */
    public static int showTerminateWithOutSavingWarning(JFrame parent)
    {
        return JOptionPane.showConfirmDialog(parent, "You have unsaved changes. Do you want to save before exiting?",
                "Application closing", JOptionPane.YES_NO_OPTION, JOptionPane.QUESTION_MESSAGE);
    }

    /**
     * Show message box reporting you have to enter search criteria to perform
     * search
     * 
     * @param parent The parent that the message should be modal to
     */
    public static void showEnterSearchCriteriaWarning(JFrame parent)
    {
        JOptionPane.showMessageDialog(parent, "You have to enter one or more characters into search field to perform a search",
                "No search text", JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Show message box reporting you have to enter more data to add resource
     * 
     * @param parent The parent that the message should be modal to
     */
    public static void showMissingAddResourceDataWarning(JFrame parent)
    {
        JOptionPane
                .showMessageDialog(
                        parent,
                        "You have to enter one or more characters into the author, title, publisher and abstract text boxes to add a resource",
                        "Not enough data", JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Show message box reporting export success
     * 
     * @param filename The file that was exported to
     * @param parent The parent that the message should be modal to
     */
    public static void exportComplete(String filename, JFrame parent)
    {
        JOptionPane.showMessageDialog(parent, "Succesfully exported to " + filename, "Export Complete",
                JOptionPane.INFORMATION_MESSAGE);
    }

    /**
     * Show message box reporting not enough information to export
     * 
     * @param parent The parent that the message should be modal to
     */
    public static void showNotEnoughDataToExportWarning(JFrame parent)
    {
        JOptionPane
                .showMessageDialog(
                        parent,
                        "You have to enter one or more characters into the author, owner and description text boxes and add at least one resource to export the list",
                        "Not enough data", JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Show message box reporting not enough information to create document
     * 
     * @param parent The parent that the message should be modal to
     */
    public static void showNotEnoughDataToCreateListWarning(JFrame parent)
    {
        JOptionPane
                .showMessageDialog(
                        parent,
                        "You have to enter one or more characters into the author, owner and description text boxes and add at least one resource to create the document",
                        "Not enough data", JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Show message box reporting not search results found
     * 
     * @param searchText The text that supplied to the search
     * @param parent The parent that the message should be modal to
     */
    public static void showNoRecordsFound(String searchText, JFrame parent)
    {
        JOptionPane.showMessageDialog(parent, "The search text " + searchText + " found no results", "No Results Found",
                JOptionPane.INFORMATION_MESSAGE);
    }
}
