/*
 * MDC Desktop Client Created on 20-Apr-2005
 */
package org.mdcog.client.desktop.gui.menus;

import java.awt.event.KeyEvent;

import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;

import org.mdcog.client.desktop.gui.AboutDialog;
import org.mdcog.client.desktop.gui.controllers.LibraryTabController;
import org.mdcog.client.desktop.gui.controllers.SearchTabController;
import org.mdcog.client.desktop.gui.models.MDCModelUpdateListener;
import org.mdcog.client.desktop.utils.BrowserControl;
import org.mdcog.client.desktop.utils.MDCConfig;

/**
 * This class represents the Menu barfor the whole application. It only defines
 * the menu items all actions are controlled by the GUI Controller class
 */
public class DesktopMenuBar extends JMenuBar implements MDCModelUpdateListener
{
    /**
     * Stores a reference to the deafult home page if one is not defined
     */
    private final static String DEFAULT_HOME = "http://users.ox.ac.uk/%7Ejiscpub/JISC_MDC/Index.htm";

    /**
     * Stores a reference to the deafult home page if one is not defined
     */
    private final static String DEFAULT_USER_GUIDE = "http://users.ox.ac.uk/%7Ejiscpub/JISC_MDC/MDCClientUserGuide.hmt";

    /**
     * Stores a reference to the file menu
     */
    private JMenu fileMenu = null;

    /**
     * Stores a reference to the help menu
     */
    private JMenu helpMenu = null;

    /**
     * Stores a reference to the save menu item
     */
    private JMenuItem saveLibraryMenuItem = null;

    /**
     * Stores a reference to the open menu item
     */
    private JMenuItem openLibraryMenuItem = null;

    /**
     * Stores a reference to the new menu item
     */
    private JMenuItem newLibraryMenuItem = null;

    /**
     * Stores a reference to the save as menu item
     */
    private JMenuItem saveAsLibraryMenuItem = null;

    /**
     * Stores a reference to the import menu item
     */
    private JMenuItem importLibraryMenuItem = null;

    /**
     * Stores a reference to the exit menu item
     */
    private JMenuItem exitMenuItem = null;

    /**
     * Stores a reference to the delete menu item
     */
    private JMenuItem aboutMenuItem = null;
    
    /**
     * Stores a reference to the home page menu item
     */
    private JMenuItem homePageMenuItem = null;
    
    /**
     * Stores a reference to the user guide menu item
     */
    private JMenuItem userGuideMenuItem = null;
    
    /**
     * Stores a reference to the library controller to action the menu requests
     * 
     * @uml.property name="libraryController"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private LibraryTabController libraryController = LibraryTabController.getInstance();

    /**
     * Stores a reference to the search controller to action the menu requests
     * 
     * @uml.property name="searchController"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private SearchTabController searchController = SearchTabController.getInstance();

    /**
     * Stores a reference to the owning pane
     */
    private JFrame owner = null;

    /**
     * Constructor for the menu. Calls initialise to build the menuBar
     * 
     * @param owner The frame the menu sits on
     */
    public DesktopMenuBar(JFrame owner)
    {
        this.owner = owner;
        // create the menu bar
        initialise();
        // register to be updated when model changes
        libraryController.registerModelUpdateListener(this);
    }

    /**
     * Initialise the menu bar and add all its menu items
     */
    private void initialise()
    {
        add(getFileMenu());
        add(getHelpMenu());

    }

    /**
     * Called when the model has been updated so the save button can be enabled
     * and disabled
     */
    public void modelUpdated()
    {
        getSaveLibraryMenuItem().setEnabled(libraryController.canSave());
    }

    /**
     * Build the file menu
     * 
     * @return JMenu the created menu
     * @uml.property name="fileMenu"
     */
    public JMenu getFileMenu()
    {
        if (fileMenu == null)
        {
            fileMenu = new javax.swing.JMenu();
            fileMenu.setText("File");
            fileMenu.add(getNewLibraryMenuItem());
            fileMenu.add(getOpenLibraryMenuItem());
            fileMenu.addSeparator();
            fileMenu.add(getSaveLibraryMenuItem());
            fileMenu.add(getSaveAsLibraryMenuItem());
            fileMenu.addSeparator();
            fileMenu.add(getImportLibraryMenuItem());
            fileMenu.addSeparator();
            fileMenu.add(getExitMenuItem());
        }
        return fileMenu;
    }

    /**
     * Build the help menu
     * 
     * @return JMenu the created menu
     * @uml.property name="helpMenu"
     */
    public JMenu getHelpMenu()
    {
        if (helpMenu == null)
        {
            helpMenu = new javax.swing.JMenu();
            helpMenu.setText("Help");
            helpMenu.setMnemonic(KeyEvent.VK_H);
            helpMenu.setDisplayedMnemonicIndex(0);
            helpMenu.add(getUserGuideMenuItem());
            helpMenu.add(getHomePageMenuItem());
            helpMenu.add(getAboutMenuItem());
        }
        return helpMenu;
    }

    /**
     * Build the new library menu item
     * 
     * @return JMenu the created menu
     * @uml.property name="newLibraryMenuItem"
     */
    public JMenuItem getNewLibraryMenuItem()
    {
        if (newLibraryMenuItem == null)
        {
            newLibraryMenuItem = new javax.swing.JMenuItem();
            newLibraryMenuItem.setText("New library");
            newLibraryMenuItem.setMnemonic(KeyEvent.VK_N);
            newLibraryMenuItem.setDisplayedMnemonicIndex(0);
            newLibraryMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    libraryController.newResourceLibrary();
                }
            });
        }
        return newLibraryMenuItem;
    }

    /**
     * Build the open library menu item
     * 
     * @return JMenu the created menu
     * @uml.property name="openLibraryMenuItem"
     */
    public JMenuItem getOpenLibraryMenuItem()
    {
        if (openLibraryMenuItem == null)
        {
            openLibraryMenuItem = new javax.swing.JMenuItem();
            openLibraryMenuItem.setText("Open library...");
            openLibraryMenuItem.setMnemonic(KeyEvent.VK_O);
            openLibraryMenuItem.setDisplayedMnemonicIndex(0);
            openLibraryMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    libraryController.openResourceLibrary();
                }
            });
        }
        return openLibraryMenuItem;
    }

    /**
     * Build the save library menu item
     * 
     * @return JMenu the created menu
     * @uml.property name="saveLibraryMenuItem"
     */
    public JMenuItem getSaveLibraryMenuItem()
    {
        if (saveLibraryMenuItem == null)
        {
            saveLibraryMenuItem = new javax.swing.JMenuItem();
            saveLibraryMenuItem.setText("Save library");
            saveLibraryMenuItem.setMnemonic(KeyEvent.VK_S);
            saveLibraryMenuItem.setDisplayedMnemonicIndex(0);
            saveLibraryMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    libraryController.saveResourceLibrary(false);
                }
            });
        }
        return saveLibraryMenuItem;
    }

    /**
     * Build the save As library menu item
     * 
     * @return JMenu the created menu
     * @uml.property name="saveAsLibraryMenuItem"
     */
    public JMenuItem getSaveAsLibraryMenuItem()
    {
        if (saveAsLibraryMenuItem == null)
        {
            saveAsLibraryMenuItem = new javax.swing.JMenuItem();
            saveAsLibraryMenuItem.setText("Save As library...");
            saveAsLibraryMenuItem.setMnemonic(KeyEvent.VK_A);
            saveAsLibraryMenuItem.setDisplayedMnemonicIndex(5);
            saveAsLibraryMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    libraryController.saveResourceLibrary(true);
                }
            });
        }
        return saveAsLibraryMenuItem;
    }

    /**
     * Build the import library menu item
     * 
     * @return JMenu the created menu
     * @uml.property name="importLibraryMenuItem"
     */
    public JMenuItem getImportLibraryMenuItem()
    {
        if (importLibraryMenuItem == null)
        {
            importLibraryMenuItem = new javax.swing.JMenuItem();
            importLibraryMenuItem.setText("Import resources...");
            importLibraryMenuItem.setMnemonic(KeyEvent.VK_I);
            importLibraryMenuItem.setDisplayedMnemonicIndex(0);
            importLibraryMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    searchController.fileMenuImport();
                }
            });
        }
        return importLibraryMenuItem;
    }

    /**
     * Build the exit menu item
     * 
     * @return JMenu the created menu
     * @uml.property name="exitMenuItem"
     */
    public JMenuItem getExitMenuItem()
    {
        if (exitMenuItem == null)
        {
            exitMenuItem = new javax.swing.JMenuItem();
            exitMenuItem.setText("Exit");
            exitMenuItem.setMnemonic(KeyEvent.VK_E);
            exitMenuItem.setDisplayedMnemonicIndex(0);

            exitMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    libraryController.applicationTerminating();
                    System.exit(0);
                }
            });
        }
        return exitMenuItem;
    }

    /**
     * Build the about menu item
     * 
     * @return JMenu the created menu
     * @uml.property name="aboutMenuItem"
     */
    public JMenuItem getAboutMenuItem()
    {
        if (aboutMenuItem == null)
        {
            aboutMenuItem = new javax.swing.JMenuItem();
            aboutMenuItem.setText("About Desktop Client...");
            aboutMenuItem.setMnemonic(KeyEvent.VK_A);
            aboutMenuItem.setDisplayedMnemonicIndex(0);
            aboutMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    // create the about dialogue
                    AboutDialog dialog = new AboutDialog(owner);
                    // show the dilaogue.
                    dialog.show();
                }
            });
        }
        return aboutMenuItem;
    }
    
    /**
     * Build the home page menu item
     * 
     * @return JMenu the created menu
     */
    public JMenuItem getHomePageMenuItem()
    {
        if (homePageMenuItem == null)
        {
            homePageMenuItem = new javax.swing.JMenuItem();
            homePageMenuItem.setText("MDC Home Page...");
            homePageMenuItem.setMnemonic(KeyEvent.VK_H);
            homePageMenuItem.setDisplayedMnemonicIndex(4);
            homePageMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    String homePage =MDCConfig.getInstance().getProperty(MDCConfig.MDC_HOME_PAGE,DEFAULT_HOME);
                    BrowserControl.displayURL(homePage);
                }
            });
        }
        return homePageMenuItem;
    }

    /**
     * Build the user guide menu item
     * 
     * @return JMenu the created menu
     */
    public JMenuItem getUserGuideMenuItem()
    {
        if (userGuideMenuItem == null)
        {
            userGuideMenuItem = new javax.swing.JMenuItem();
            userGuideMenuItem.setText("User guide...");
            userGuideMenuItem.setMnemonic(KeyEvent.VK_U);
            userGuideMenuItem.setDisplayedMnemonicIndex(0);
            userGuideMenuItem.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    String homePage =MDCConfig.getInstance().getProperty(MDCConfig.MDC_USER_GUIDE,DEFAULT_USER_GUIDE);
                    BrowserControl.displayURL(homePage);
                }
            });
        }
        return userGuideMenuItem;
    }
}