/*
 * MDC Desktop Client Created on 22-Apr-2005
 */
package org.mdcog.client.desktop.gui.menus;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JMenuItem;
import javax.swing.JTable;

import org.mdcog.client.desktop.gui.controllers.LibraryTabController;
import org.mdcog.client.desktop.gui.images.MDCIcons;

/**
 * This class represents the pop up menu shown when an item is clicked on the
 * library resource list item
 */
public class MyLibaryResourceListPopUpMenu extends javax.swing.JPopupMenu
{

    /**
     * Stores a reference to the new list menu item
     */
    private JMenuItem newList;

    /**
     * Stores a reference to the delete list menu item
     */
    private JMenuItem deleteList;

    /**
     * Stores a reference to the rename list menu item
     */
    private JMenuItem renameList;

    /**
     * Stores a reference to the controller to action the menu requests
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private LibraryTabController controller;

    /**
     * Stores a reference to the resource list row effected
     */
    private int rowAffected = 0;

    /**
     * Stores a reference to the resource list column effected
     */
    private int columnAffected = 0;

    /**
     * Stores a reference to the resource list table
     */
    private JTable table;

    /**
     * Constructor for the menu. If row can not be altered the delete and rename
     * options will be disabled.
     * 
     * @param table the resource list table
     * @param rowAffected the row affected in table
     * @param columnAffected the column affected in the table
     * @param rowCanBeAltered boolean indicating if the row can be altered
     */
    public MyLibaryResourceListPopUpMenu(JTable table, int rowAffected, int columnAffected, boolean rowCanBeAltered)
    {
        controller = LibraryTabController.getInstance();
        this.table = table;
        this.rowAffected = rowAffected;
        this.columnAffected = columnAffected;
        // create menu
        this.add(getNewMenuItem());
        this.add(getDeleteMenuItem());
        this.add(getRenameMenuItem());
        // disable delete and rename if row can not be altered
        if (!rowCanBeAltered)
        {
            deleteList.setEnabled(false);
            renameList.setEnabled(false);
        }
    }

    /**
     * Gets and constructs the new menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getNewMenuItem()
    {
        newList = new JMenuItem("New", MDCIcons.NEWRESOURCELIST_ICON);
        newList.setMnemonic(KeyEvent.VK_N);
        newList.setDisplayedMnemonicIndex(0);
        newList.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                int row = controller.addNewResourceListToMyLibary();
                table.setRowSelectionInterval(row, row);
            }
        });
        return newList;
    }

    /**
     * Gets and constructs the delete menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getDeleteMenuItem()
    {
        deleteList = new JMenuItem("Delete", MDCIcons.DELETE_ICON);
        deleteList.setMnemonic(KeyEvent.VK_D);
        deleteList.setDisplayedMnemonicIndex(0);
        deleteList.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                controller.deleteResourceListFromMyLibary(rowAffected);
                // select the previous list item
                table.setRowSelectionInterval(rowAffected - 1, rowAffected - 1);
            }
        });
        return deleteList;
    }

    /**
     * Gets and constructs the rename menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getRenameMenuItem()
    {
        renameList = new JMenuItem("Rename", MDCIcons.RENAMERESOURCELIST_ICON);
        renameList.setMnemonic(KeyEvent.VK_R);
        renameList.setDisplayedMnemonicIndex(0);
        renameList.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                table.editCellAt(rowAffected, columnAffected);
            }
        });
        return renameList;
    }

}
