/*
 * MDC Desktop Client Created on 22-Apr-2005
 */
package org.mdcog.client.desktop.gui.menus;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JMenuItem;
import javax.swing.JTable;

import org.mdcog.client.desktop.gui.controllers.LibraryTabController;
import org.mdcog.client.desktop.gui.images.MDCIcons;

/**
 * This class represents the pop up menu shown when an item is clicked on the
 * library resource list item
 */
public class MyLibraryResourceGridPopUpMenu extends javax.swing.JPopupMenu
{

    /**
     * Stores a reference to the add menu item
     */
    private JMenuItem addItem;

    /**
     * Stores a reference to the delete menu item
     */
    private JMenuItem deleteItem;

    /**
     * Stores a reference to the copy menu item
     */
    private JMenuItem copyItem;

    /**
     * Stores a reference to the controller to action the menu requests
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private LibraryTabController controller;

    /**
     * Stores a reference to the rows selected before pop up was shown
     */
    private int[] rowsSelected;

    /**
     * Stores a reference to the table that the pop up is against
     */
    private JTable table;

    /**
     * Constructor for the menu.
     * 
     * @param table The related controller that performs the actions
     * @param rowsSelected The rows currently slected that the pop up is against
     */
    public MyLibraryResourceGridPopUpMenu(JTable table, int[] rowsSelected)
    {
        controller = LibraryTabController.getInstance();
        this.table = table;
        this.rowsSelected = rowsSelected;

        // create menu
        this.add(getAddMenuItem());
        this.add(getCopyMenuItem());
        this.add(getDeleteMenuItem());
    }

    /**
     * Gets and constructs the add menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getAddMenuItem()
    {
        addItem = new JMenuItem("Add", MDCIcons.ADDRESOURCEITEM_ICON);
        addItem.setMnemonic(KeyEvent.VK_A);
        addItem.setDisplayedMnemonicIndex(0);
        addItem.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                controller.createResourceItems();
            }
        });
        return addItem;
    }

    /**
     * Gets and constructs the copy menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getCopyMenuItem()
    {
        copyItem = new JMenuItem("Copy", MDCIcons.COPYRESOURCEITEM_ICON);
        copyItem.setMnemonic(KeyEvent.VK_C);
        copyItem.setDisplayedMnemonicIndex(0);
        copyItem.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                controller.copyResourceItemFromListInMyLibary(rowsSelected);
            }
        });
        return copyItem;
    }

    /**
     * Gets and constructs the delete menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getDeleteMenuItem()
    {
        deleteItem = new JMenuItem("Delete", MDCIcons.DELETE_ICON);
        deleteItem.setMnemonic(KeyEvent.VK_D);
        deleteItem.setDisplayedMnemonicIndex(0);
        deleteItem.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                controller.deleteResourceItemFromListInMyLibary(rowsSelected);
            }
        });
        return deleteItem;
    }

}
