/*
 * MDC Desktop Client Created on 22-Apr-2005
 */
package org.mdcog.client.desktop.gui.menus;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JMenuItem;

import org.mdcog.client.desktop.gui.controllers.SearchResultsTabController;
import org.mdcog.client.desktop.gui.images.MDCIcons;

/**
 * This class represents the pop up menu shown when an item is clicked on the
 * library resource list item
 */
public class SearchResultsResourceGridPopUpMenu extends javax.swing.JPopupMenu
{

    /**
     * Stores a reference to the delete menu item
     */
    private JMenuItem deleteItem;

    /**
     * Stores a reference to the move menu item
     */
    private JMenuItem moveItem;

    /**
     * Stores a reference to the rows selected before pop up was shown
     */
    private int[] rowsSelected;

    /**
     * Stores a reference to the controller to action the menu requests
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private SearchResultsTabController controller = null;

    /**
     * Constructor for the menu.
     * 
     * @param controller The related controller that performs the actions
     * @param rowsSelected The rows currently slected that the pop up is against
     */
    public SearchResultsResourceGridPopUpMenu(SearchResultsTabController controller, int[] rowsSelected)
    {
        this.rowsSelected = rowsSelected;
        this.controller = controller;
        // create menu
        this.add(getMoveMenuItem());
        this.add(getDeleteMenuItem());
    }

    /**
     * Gets and constructs the move menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getMoveMenuItem()
    {
        moveItem = new JMenuItem("Move to My List", MDCIcons.MOVERESOURCEITEMTOMYLIST_ICON);
        moveItem.setMnemonic(KeyEvent.VK_M);
        moveItem.setDisplayedMnemonicIndex(0);
        moveItem.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                controller.copySearchResultResourceItemsToMyList(rowsSelected);
            }
        });
        return moveItem;
    }

    /**
     * Gets and constructs the delete menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getDeleteMenuItem()
    {
        deleteItem = new JMenuItem("Delete", MDCIcons.DELETE_ICON);
        deleteItem.setMnemonic(KeyEvent.VK_D);
        deleteItem.setDisplayedMnemonicIndex(0);
        deleteItem.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                controller.deleteResourceItemsFromList(rowsSelected);
            }
        });
        return deleteItem;
    }

}
