/*
 * MDC Desktop Client Created on 22-Apr-2005
 */
package org.mdcog.client.desktop.gui.menus;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JMenuItem;

import org.mdcog.client.desktop.gui.controllers.SearchTabController;
import org.mdcog.client.desktop.gui.images.MDCIcons;

/**
 * This class represents the pop up menu shown when the user clicks on a tab
 * label
 */
public class SearchResultsResourceTabPopUpMenu extends javax.swing.JPopupMenu
{

    /**
     * Stores a reference to the close menu item
     */
    private JMenuItem closeItem;

    /**
     * Stores a reference to the close all menu item
     */
    private JMenuItem closeAllItem;

    /**
     * Stores a reference to the controller to action the menu requests
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private SearchTabController controller = null;

    /**
     * stores a reference to the index of the tab to close
     */
    private int tabToClose = -1;

    /**
     * Constructor for the menu.
     * 
     * @param controller The related controller that performs the actions
     * @param tabToClose the index of the tab to close
     */
    public SearchResultsResourceTabPopUpMenu(SearchTabController controller, int tabToClose)
    {
        this.controller = controller;
        this.tabToClose = tabToClose;
        // create menu
        this.add(getCloseMenuItem());
        this.add(getCloseAllMenuItem());

    }

    /**
     * Gets and constructs the close menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getCloseMenuItem()
    {
        closeItem = new JMenuItem("Close Tab", MDCIcons.CLOSETAB_ICON);
        closeItem.setMnemonic(KeyEvent.VK_C);
        closeItem.setDisplayedMnemonicIndex(0);
        closeItem.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                controller.closeSearchResultsTab(tabToClose);
            }
        });
        return closeItem;
    }

    /**
     * Gets and constructs the close all menu item
     * 
     * @return the created menu item
     */
    private JMenuItem getCloseAllMenuItem()
    {
        closeAllItem = new JMenuItem("Close All Tabs", MDCIcons.CLOSEALLTABS_ICON);
        closeAllItem.setMnemonic(KeyEvent.VK_A);
        closeAllItem.setDisplayedMnemonicIndex(6);
        closeAllItem.addActionListener(new ActionListener()
        {

            public void actionPerformed(ActionEvent e)
            {
                controller.closeAllSearchResultsTabs();
            }
        });
        return closeAllItem;
    }

}
