/*
 * MDC Desktop Client Created on 23-Jun-2005
 */
package org.mdcog.client.desktop.gui.menus;

import java.util.Iterator;
import java.util.Map;

import javax.swing.JCheckBoxMenuItem;
import javax.swing.table.TableColumn;

import org.mdcog.client.desktop.gui.error.MDCInternalException;
import org.mdcog.client.desktop.gui.models.ColumnDisplayInterface;
import org.mdcog.client.desktop.gui.models.ColumnPopUpMenuListener;

/**
 * This class dynamically creates a pop up a menu to allow the user to deselect
 * or reselect a column to show on the grid
 */
public class SelectResourceItemColumnsPopUpMenu extends javax.swing.JPopupMenu
{

    /**
     * Make default constructor private to force proper construction
     */
    private SelectResourceItemColumnsPopUpMenu()
    {
    }

    /**
     * Dynamically constructs the pop up menu and registers the listner
     * 
     * @param displayer The displayer to call back on when the user selects a
     *        column
     * @param columnData A map of column names to show flags
     * @throws MDCInternalException
     */
    public SelectResourceItemColumnsPopUpMenu(ColumnDisplayInterface displayer, Map columnData) throws MDCInternalException
    {
        if (columnData.isEmpty())
        {
            // do nothing just return
            throw new MDCInternalException("Empty Column data for columns popup");
        }

        // get an iterator round the key set
        Iterator iter = columnData.keySet().iterator();

        boolean displayed = true;
        JCheckBoxMenuItem checkboxItem = null;
        TableColumn column = null;

        while (iter.hasNext())
        {
            // get the next key which is the table column
            column = (TableColumn) iter.next();
            // Is this column currently displayed
            displayed = ((Boolean) columnData.get(column)).booleanValue();
            // create the check box item
            checkboxItem = new JCheckBoxMenuItem(column.getHeaderValue().toString(), displayed);
            // add the actiobn listener
            checkboxItem.addActionListener(new ColumnPopUpMenuListener(checkboxItem, displayer, column));
            // add then menu item
            this.add(checkboxItem);
        }

    }
}
