/*
 * MDC Desktop Client Created on 27-Apr-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;

/**
 * This class is used to hold the transfer object information during a drag and
 * drop move. It is specificly built to only work with objects.
 */
public class JVMLocalObjectTransfer implements Transferable
{

    /**
     * Stores a reference to the object being transfered
     */
    private Object obj = null;

    /**
     * Stores a reference to the formats that this transfer object supports
     */
    private static DataFlavor[] flavors = null;

    /**
     * creates the transferable object
     * 
     * @param object The object to transfer
     */
    public JVMLocalObjectTransfer(Object object)
    {
        // create the data flavors if not already created
        if (flavors == null)
        {
            try
            {
                flavors = new DataFlavor[] { new DataFlavor(DataFlavor.javaJVMLocalObjectMimeType) };
            }
            catch (ClassNotFoundException e)
            {
                //. should not occurr in our app
                e.printStackTrace();
            }
        }
        this.obj = object;
    }

    /**
     * This method returns all the formats that this transfer object supports.
     * In this case it only supports objects
     * 
     * @return supported flavours
     */
    public DataFlavor[] getTransferDataFlavors()
    {
        // returning flavors itself would allow client code to modify
        // our internal behavior
        return (DataFlavor[]) flavors.clone();
    }

    /**
     * Called by drop traget controls to see if any of the formats it supports
     * is supported by this transfer object inorder to determine if a drop is
     * allowed
     * 
     * @param flavor The format the control supports
     * @return true if the format is supported
     */
    public boolean isDataFlavorSupported(DataFlavor flavor)
    {
        // loop round and see if the flavour is supported
        for (int i = 0; i < flavors.length; i++)
        {
            if (flavor.equals(flavors[i]))
            {
                return true;
            }
        }
        return false;
    }

    /**
     * Called by the drop control to retrieve the stored object when it has
     * confirmed that the format is supported and the drop has been initiated
     * 
     * @param flavor The data format the control expects
     * @return The stored object
     * @throws UnsupportedFlavorException
     * @throws IOException
     */
    public Object getTransferData(DataFlavor flavor) throws UnsupportedFlavorException, IOException
    {
        if (isDataFlavorSupported(flavor))
        {
            return obj;
        }
        // we do not support so
        throw new UnsupportedFlavorException(flavor);

    }
}
