/*
 * MDC Desktop Client Created on 11-May-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * Super class that implements the main functionality for MDC file filters
 */
public class MDCFileFilter extends javax.swing.filechooser.FileFilter
{

    /**
     * Stores a reference to the allowable extensions
     */
    private ArrayList extensions = new ArrayList();

    /**
     * Stores a reference to the name of the filer for display purposes
     */
    private String filterName = "";

    /**
     * Stop the user using the deault constructor by making it private
     */
    private MDCFileFilter()
    {
    };

    /**
     * Constructor setting filter name
     * 
     * @param filterName the name of this filter
     */
    public MDCFileFilter(String filterName)
    {
        this.filterName = filterName;
    }

    /**
     * Set the extensions this filter should use
     * @param ext Array of String extension filters
     * 
     * @uml.property name="extensions"
     */
    protected void setExtensions(ArrayList ext) {
        this.extensions = ext;
    }

    /**
     * Called to see if the file should be displayed. It is only excepted if it
     * is a directory or has a matching extension type
     * 
     * @param file
     * @return true if the file can be displayed
     */
    public boolean accept(File file)
    {
        // directories okay
        if (file.isDirectory())
        {
            return true;
        }

        Iterator iterator = extensions.iterator();
        while (iterator.hasNext())
        {
            // return true if equals our file extension
            if (getExtension(file).equalsIgnoreCase((String) iterator.next()))
            {
                return true;
            }
        }
        return false;
    }

    /**
     * This function extracts the extension of the file provided
     * 
     * @param file The File object to get extension from
     * @return the determined extension
     */
    public static String getExtension(File file)
    {
        String ext = "";
        String name = file.getName();
        int i = name.lastIndexOf('.');

        if (i > 0 && i < name.length() - 1)
        {
            ext = name.substring(i + 1).toLowerCase();
        }
        return ext;
    }

    /**
     * Returns the description that the file dialog should display for this
     * filter
     * 
     * @return The library file extension format
     */
    public String getDescription()
    {
        return filterName;
    }
}
