/*
 * MDC Desktop Client Created on 27-Apr-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;

import javax.swing.JComponent;
import javax.swing.JTable;

import org.mdcog.client.desktop.gui.controllers.LibraryTabController;

/**
 * This class transfers ResourceItems into the my resource list grid only. 
 */
public class MyLibraryResourceItemTransferInHandler extends ResourceItemTransferHandler
{

    /**
     * Causes a transfer to a component from a clipboard or a DND drop
     * operation. The Transferable represents the data to be imported into the
     * component
     * 
     * @param component the component we are transfering in to
     * @param trans the transferable object
     * @return true if import was succesful
     */
    public boolean importData(JComponent component, Transferable trans)
    {
        // can we import this data
        if (canImport(component, trans.getTransferDataFlavors()))
        {
            try
            {
                // get the selected row we are dropping onto
                // we can perform the drop if not the all resources row (0)
                JTable resourceListTable = (JTable) component;

                int selectedRow = resourceListTable.getSelectedRow();

                // extract and decode the string
                ResourceItemDragInformation dragInfo = (ResourceItemDragInformation) trans.getTransferData(supportedDataFlavor);

                // oask the controller to add the resources to the selected list
                LibraryTabController.getInstance().addDraggedResourceItemToResourceListMyLibary(selectedRow, dragInfo);
                return true;

            }
            catch (UnsupportedFlavorException ufe)
            {
            }
            catch (IOException ioe)
            {
            }

        }
        return false;
    }

    /**
     * Checks if the flavour of the import is supported and whether the
     * component accepts imports
     * 
     * @param component The component to transfer into
     * @param flavors the formats the component supports
     * @return true if the import is allowed
     */
    public boolean canImport(JComponent component, DataFlavor[] flavors)
    {
        for (int i = 0; i < flavors.length; i++)
        {
            if (supportedDataFlavor.equals(flavors[i]))
            {
                return true;
            }
        }
        return false;
    }

    /**
     * Called to create the transferable object and do the export
     * 
     * @param component The component to transfer from 
     * @return null as we do not support drag only drop on library resource list
     */
    protected Transferable createTransferable(JComponent component)
    {
        // return null as we do not support itemsgoing out
        return null;
    }
}
