/*
 * MDC Desktop Client Created on 27-Apr-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;

import javax.swing.JComponent;
import javax.swing.JTable;

import org.mdcog.client.desktop.gui.controllers.LibraryTabController;

/**
 * This class transfers ResourceItems out of the resource items grid only.
 */
public class MyLibraryResourceItemTransferOutHandler extends ResourceItemTransferHandler
{

    /**
     * Stores a reference to the information about what is being dragged
     * 
     * @uml.property name="dragInfo"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private ResourceItemDragInformation dragInfo = null;

    /**
     * Called to create the transferable object and do the export
     * 
     * @param component The component transfering from
     * @return the created tranfer object
     */
    protected Transferable createTransferable(JComponent component)
    {
        return new JVMLocalObjectTransfer(exportData(component));
    }

    /**
     * Creates a string representing the row to export the data
     */
    /**
     * @param component The component transfering from
     * @return The created drag information
     */
    public ResourceItemDragInformation exportData(JComponent component)
    {
        JTable resourceItemsTable = (JTable) component;
        dragInfo = LibraryTabController.getInstance().createResourceItemDragInformation(resourceItemsTable.getSelectedRows());
        return dragInfo;
    }

    /**
     * Invoked after data has been exported. This method should remove the data
     * that was transferred if the action was MOVE.
     * @param component The component transfering from
     * @param data the transfer object
     * @param action the action performed MOVE or COPY
     */
    protected void exportDone(JComponent component, Transferable data, int action)
    {
        // if we did a move ask controller to delete the original if allowed
        if (action == MOVE)
        {
            // as a move occured we need remove the item from the list it was
            // moved from
            LibraryTabController.getInstance().deleteDraggedResourceItemFromResourceListFromLibary(dragInfo);
        }
    }

    /**
     * Checks if the flavour of the import is String and whether the component
     * accepts imports
     * @param component The component transfering from
     * @param flavors the formats to check against
     * @return always false as we do not support drops on to the resource item grid
     */
    public boolean canImport(JComponent component, DataFlavor[] flavors)
    {
        // we do not accept imports
        return false;
    }

    /**
     * Causes a transfer to a component from a clipboard or a DND drop
     * operation. The Transferable represents the data to be imported into the
     * component.

     * @param component The component transfering from
     * @param trans The transferable object
     * @return always false as we do not support drops on to the resource item grid
     */
    public boolean importData(JComponent component, Transferable trans)
    {
        // This handler does not deal with incoming targets
        return false;
    }

}
