/*
 * MDC Desktop Client Created on 16-May-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JTable;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

import org.mdcog.client.desktop.gui.table.renderers.ResourceItemURLRenderer;

/**
 * Handles the clicks on resource item grid buttons (Annotation, Local, Web and
 * Open)
 * 
 * @uml.dependency supplier="org.mdcog.client.desktop.gui.table.renderers.ResourceItemURLRenderer" stereotypes="Basic::Call"
 */

public class ResourceItemButtonMouseListener implements MouseListener
{

    /**
     * Stores a reference to the table we are listening to
     */
    private JTable table;

    /**
     * Called whenever the mouse is clicked on a button
     * 
     * @param event The mouse event
     */
    public void mouseClicked(MouseEvent event)
    {
        // get the column model
        TableColumnModel columnModel = table.getColumnModel();
        // work out the column that was clicked
        int column = columnModel.getColumnIndexAtX(event.getX());
        // work out the row that was clicked
        int row = event.getY() / table.getRowHeight();

        ResourceItemURLRenderer renderer;
        // make sure the event was in bounds of table
        if (row >= table.getRowCount() || row < 0 || column >= table.getColumnCount() || column < 0)
            return;

        // get the table column
        TableColumn value = columnModel.getColumn(column);

        // check it is a ResourceItemURLRenderer button renderer
        if (!(value.getCellRenderer() instanceof ResourceItemURLRenderer))
            return;

        // convert to ResourceItemURLRenderer and tell it to perform its click
        renderer = (ResourceItemURLRenderer) value.getCellRenderer();
        renderer.clicked(row);
    }

    /**
     * Create the Listener telling it the table it is listening on
     * 
     * @param table The table the listner is listening to
     */
    public ResourceItemButtonMouseListener(JTable table)
    {
        this.table = table;
    }

    /**
     * Do Nothing on this event
     * 
     * @param event The mouse event
     */
    public void mouseEntered(MouseEvent event)
    {
    }

    /**
     * Do Nothing on this event
     * 
     * @param event The mouse event
     */
    public void mouseExited(MouseEvent event)
    {
    }

    /**
     * Do Nothing on this event
     * 
     * @param event The mouse event
     */
    public void mousePressed(MouseEvent event)
    {
    }

    /**
     * Do Nothing on this event
     * 
     * @param event The mouse event
     */
    public void mouseReleased(MouseEvent event)
    {
    }

}
