/*
 * MDC Desktop Client Created on 27-Apr-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.io.Serializable;

import org.mdcog.client.desktop.gui.controllers.Controller;
import org.mdcog.client.desktop.model.ResourceItem;

/**
 * This class is used to store drag information for both the Library and Search
 * tabs
 */
public class ResourceItemDragInformation implements Serializable
{

    /**
     * Stores a reference to the row that the drag was performed on. Tis is only
     * used for the LibraryTab Drag and Drop support
     */
    private int resourceListRow = -1;

    /**
     * Stores a reference to the resource items beinging dragged
     * 
     * @uml.property name="resourceItems"
     * @uml.associationEnd multiplicity="(0 -1)"
     */
    private ResourceItem[] resourceItems;

    /**
     * Stores a reference to the controller handling the grid data
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private Controller controller = null;


    /**
     * constructor to use when dragging library resource items
     * 
     * @param resourceListRow The resource list row dragged from
     * @param resourceItems The resource items dragged
     */
    public ResourceItemDragInformation(int resourceListRow, ResourceItem[] resourceItems)
    {
        this.resourceListRow = resourceListRow;
        this.resourceItems = resourceItems;
    }

    /**
     * Constructor to use when dragging search items
     * 
     * @param controller The controller to process the drop
     * @param resourceItems The resource items dragged
     */
    public ResourceItemDragInformation(Controller controller, ResourceItem[] resourceItems)
    {
        this.controller = controller;
        this.resourceItems = resourceItems;
    }

    /**
     * @return Returns the resourceItemIndex.
     * 
     * @uml.property name="resourceItems"
     */
    public ResourceItem[] getResourceItems() {
        return resourceItems;
    }

    /**
     * @return Returns the resourceListIndex.
     * 
     * @uml.property name="resourceListRow"
     */
    public int getResourceListRow() {
        return resourceListRow;
    }

    /**
     * @return Returns the controller.
     * 
     * @uml.property name="controller"
     */
    public Controller getController() {
        return controller;
    }

}
