/*
 * MDC Desktop Client Created on 26-Apr-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.util.Comparator;

import org.mdcog.client.desktop.model.ResourceList;

import ca.odell.glazedlists.gui.AdvancedTableFormat;
import ca.odell.glazedlists.gui.WritableTableFormat;
import ca.odell.glazedlists.impl.sort.ComparableComparator;

/**
 * Defines the Table format for the resource list grid. This class is heavly
 * linked to the ResourceIList class that it displays data about. *
 * 
 * @see <a href="http://publicobject.com/glazedlists">Glazed Lists HomePage </a>
 */
public class ResourceListTableFormat implements AdvancedTableFormat, WritableTableFormat
{

    /**
     * Stores a reference to the standard comparator
     */
    protected ComparableComparator comparableComparator = null;

    /**
     * Stores a reference to the number of displayable columns
     */
    protected final static int NUMOFCOLUMNS = 1;

    /**
     * Constructor
     */
    public ResourceListTableFormat()
    {

        comparableComparator = new ComparableComparator();
    }

    /**
     * Returns the number of columns to display
     * 
     * @return Number of displayable columns
     */
    public int getColumnCount()
    {
        return NUMOFCOLUMNS;
    }

    /**
     * Returns the titles for the columns
     * 
     * @param columnIndex the column that requires it header title
     * @return The header which is always blank
     */
    public String getColumnName(int columnIndex)
    {
        return "";
    }

    /**
     * Extracts from the baseObject the data for the specific column. For this
     * model the render takes care of extracting from the base object so this is
     * simply forwarded on
     * 
     * @param baseObject The base Object (ResourceList)
     * @param columnIndex the column that requires its value
     * @return The extracted data for the column
     */
    public Object getColumnValue(Object baseObject, int columnIndex)
    {
        // check for no base object
        if (baseObject == null)
        {
            return null;
        }
        // renders deal with extracting information
        return baseObject;
    }

    /**
     * Check if the column object is editable
     * 
     * @param baseObject The base Object (ResourceList)
     * @param columnIndex The column to check
     * @return Always returns true as TableModel deals with this
     */
    public boolean isEditable(Object baseObject, int columnIndex)
    {
        return true;
    }

    /**
     * Updates the baseObject with the edited data for the specific column. For
     * this model the editor takes care of extracting from the base object so
     * this is simply forwarded on
     * 
     * @param baseObject The base Object (ResourceList)
     * @param editedValue The new value
     * @param columnIndex the column that requires its value
     * @return The updated object
     */
    public Object setColumnValue(Object baseObject, Object editedValue, int columnIndex)
    {
        if (baseObject == null)
        {
            return null;
        }
        return baseObject;
    }

    /**
     * Returns the class for the column inorder to implement custom renderes
     * 
     * @param columnIndex the column that requires it column class type
     * @return All columns are of type ResourceList
     */
    public Class getColumnClass(int columnIndex)
    {
        return ResourceList.class;
    }

    /**
     * Returns the comparator to use for the column
     * 
     * @param columnIndex the column that requires its comparator
     * @return The standard String comparator or null when button columns
     */
    public Comparator getColumnComparator(int columnIndex)
    {
        return comparableComparator;
    }
}
