/*
 * MDC Desktop Client Created on 27-Apr-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;

import javax.swing.JComponent;

import org.mdcog.client.desktop.gui.controllers.SearchResultsTabController;

/**
 * This class transfers ResourceItems into the search my list grid only.
 */
public class SearchMyListResourceItemTransferInHandler extends ResourceItemTransferHandler
{

    /**
     * Causes a transfer to a component from a clipboard or a DND drop
     * operation. The Transferable represents the data to be imported into the
     * component
     * 
     * @param component The componet transfering to
     * @param trans The transferable data
     * @return True if import succeeded
     */
    public boolean importData(JComponent component, Transferable trans)
    {
        // can we import this data
        if (canImport(component, trans.getTransferDataFlavors()))
        {
            try
            {
                // extract and decode the string
                ResourceItemDragInformation dragInfo = (ResourceItemDragInformation) trans.getTransferData(supportedDataFlavor);
                SearchResultsTabController controller = (SearchResultsTabController) dragInfo.getController();

                //ask the controller to add the resources to the my list grid
                controller.copySearchResultResourceItemsToMyList(dragInfo.getResourceItems());
                return true;

            }
            catch (UnsupportedFlavorException ufe)
            {
            }
            catch (IOException ioe)
            {
            }

        }
        return false;
    }

    /**
     * Checks if the format of the import is supported and whether the component
     * accepts imports
     * 
     * @param component component The componet transfering to
     * @param flavors The formats to check against
     * @return true if format is of the correct type to import
     */
    public boolean canImport(JComponent component, DataFlavor[] flavors)
    {
        for (int i = 0; i < flavors.length; i++)
        {
            if (supportedDataFlavor.equals(flavors[i]))
            {
                return true;
            }
        }
        return false;
    }

    /**
     * Called to create the transferable object and do the export
     * 
     * @param component component The componet transfering to
     * @return Return null as drag not supported
     */
    protected Transferable createTransferable(JComponent component)
    {
        // return null as we do not support itemsgoing out
        return null;
    }
}
