/*
 * MDC Desktop Client Created on 26-Apr-2005
 */
package org.mdcog.client.desktop.gui.models;

import javax.swing.table.TableCellRenderer;

import org.mdcog.client.desktop.gui.controllers.ResourceItemButtonControllerInterface;
import org.mdcog.client.desktop.gui.images.MDCIcons;
import org.mdcog.client.desktop.gui.table.renderers.ResourceItemURLRenderer;
import org.mdcog.client.desktop.model.ResourceItem;

/**
 * The search result grid is identical to normal grid except it has no local URL
 * button or annotation button this class extends the normal grid format to
 * remove this option. This is done this way at the moment because the final
 * grid format is still volatile.
 * 
 * @see <a href="http://publicobject.com/glazedlists">Glazed Lists HomePage </a>
 */
public class SearchResultResourceItemTableFormat extends ResourceItemTableFormat
{

    /**
     * Constructor
     * 
     * @param controller The controller to process URL button clicks
     */
    public SearchResultResourceItemTableFormat(ResourceItemButtonControllerInterface controller)
    {
        super(controller);
    }

    /**
     * Returns the number of columns displayed, in this model it is 2 less than
     * normal as no local or annotation button
     * 
     * @return the number of columns to display
     */
    public int getColumnCount()
    {
        return NUMOFCOLUMNS - 2;
    }
    
    /**
     * Returns the name for the column 
     * @param columnIndex the column that requires it header title 
     * @return The header
     */
    public String getColumnName(int columnIndex)
    {
        switch (columnIndex)
        {
        case 0:
            return "Author";
        case 1:
            return "Title";
        case 2:
            return "Publisher";
        case 3:
            return "Type";
        case 4:
            return "ISBN";
        case 5:
            return "ISSN";
        case 6:
            return "Abstract";
        case 7:
            return "Web URL";
        case 8:
            return "Open URL";

        }
        return "Undefined";
    }

    /**
     * Extracts from the baseObject the data for the specific column. This is
     * modified from super class as the local URL and annotation buttons are not
     * displayed so indexes are different
     * 
     * @param baseObject The base Object (ResourceItem)
     * @param columnIndex the column that requires its value
     * @return The extracted data for the column
     */
    public Object getColumnValue(Object baseObject, int columnIndex)
    {
        if (baseObject == null)
        {
            return null;
        }
        ResourceItem item = (ResourceItem) baseObject;
        switch (columnIndex)
        {
        case 0:
        case 1:
        case 2:
        case 3:
        case 4:
        case 5:
        case 6:
            // all other columns are as normal
            return super.getColumnValue(baseObject, columnIndex);
        case 7:
            return item.getWebURL();
        case 8:
            return item.getOpenURL();
        }
        return null;
    }

    /**
     * Returns the special column render for given column numbers null if no
     * specific one applies. This sets up the listeners and controller calls for
     * the button renderers to process mouse clicks.This is modified from super
     * class as the local URL button is not displayed so indexes are different
     * 
     * @param columnIndex the column that requires setting up
     * @return The renderer for the column
     */
    public TableCellRenderer getColumnRender(int columnIndex)
    {
        ResourceItemURLRenderer renderer = null;
        switch (columnIndex)
        {
        case 0:
        case 1:
        case 2:
        case 3:
        case 4:
        case 5:
        case 6:
            return null;
        case 7:
            // create the URL renderer and add listner for when its clicked
            renderer = new ResourceItemURLRenderer("...", MDCIcons.WORLD_ICON);
            renderer.addURLListener(new ResourceItemButtonListener()
            {

                public void buttonClicked(int row)
                {
                    controller.openWebURL(row);
                }
            });
            return renderer;
        case 8:
            // create the URL renderer and add listner for when its clicked
            renderer = new ResourceItemURLRenderer("...", MDCIcons.WORLD_ICON);
            renderer.addURLListener(new ResourceItemButtonListener()
            {

                public void buttonClicked(int row)
                {
                    controller.openOpenURL(row);
                }
            });
            return renderer;
        }
        return null;
    }
}
