/*
 * MDC Desktop Client Created on 27-Apr-2005
 */
package org.mdcog.client.desktop.gui.models;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;

import javax.swing.JComponent;
import javax.swing.JTable;

import org.mdcog.client.desktop.gui.controllers.SearchResultsTabController;

/**
 * This class transfers ResourceItems out of the resource items search results
 * grid only.
 */
public class SearchResultsResourceItemTransferOutHandler extends ResourceItemTransferHandler
{

    /**
     * Stores a reference to the controller processing drag
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private SearchResultsTabController controller = null;

    /**
     * Constructor that stores the controller
     * 
     * @param controller
     */
    public SearchResultsResourceItemTransferOutHandler(SearchResultsTabController controller)
    {
        this.controller = controller;
    }

    /**
     * Priavte constructor to force use of controller version
     */
    private SearchResultsResourceItemTransferOutHandler()
    {
    }

    /**
     * Called to create the transferable object and do the export
     * 
     * @param component The component transfering from
     * @return The created tansfer object
     */
    protected Transferable createTransferable(JComponent component)
    {
        return new JVMLocalObjectTransfer(exportData(component));
    }

    /**
     * Creates a string representing the row to export the data
     * 
     * @param component The component transfering from
     * @return The ResourceItemDragInformation that is being exported
     */
    public ResourceItemDragInformation exportData(JComponent component)
    {
        // get the selected row and create the export string
        // we can perform the cast because this is only going to be attached to
        // the search results ResourceItems Grid
        JTable resourceItemsTable = (JTable) component;
        return controller.createResourceItemDragInformation(resourceItemsTable.getSelectedRows());

    }

    /**
     * Invoked after data has been exported. In this case we have nothing to
     * clear up
     * 
     * @param component The component transfering from
     * @param data The transferable data
     * @param action The action performed MOVE or COPY
     */
    protected void exportDone(JComponent component, Transferable data, int action)
    {
        // Nothing to do as we are always copying
    }

    /**
     * Checks if the format of the import is String and whether the component
     * accepts imports
     * 
     * @param component The component transfering from
     * @param flavors The formats to check against
     * @return Always false as do not support drops
     */
    public boolean canImport(JComponent component, DataFlavor[] flavors)
    {
        // we do not accept imports
        return false;
    }

    /**
     * Causes a transfer to a component from a clipboard or a DND drop
     * operation. The Transferable represents the data to be imported into the
     * component.
     * 
     * @param component The component transfering from
     * @param trans The transferable data
     * @return always false as do not support drops
     */
    public boolean importData(JComponent component, Transferable trans)
    {
        // This handler does not deal with incoming targets
        return false;
    }

}
