/*
 * MDC Desktop Client Created on 26-May-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import org.mdcog.client.desktop.gui.EditAnnotationDialog;
import org.mdcog.client.desktop.gui.OpenLocalURLDialog;
import org.mdcog.client.desktop.gui.controllers.AddNewResourceItemDialogController;
import org.mdcog.client.desktop.gui.error.MDCMessageBox;
import org.mdcog.client.desktop.gui.images.MDCIcons;
import org.mdcog.client.desktop.model.ResourceItem;
import org.mdcog.client.desktop.utils.BrowserControl;

/**
 * This class represents the add book tab
 */
public class AddResourceTabPanel extends JPanel
{

    /**
     * Stores a reference to the type of resource this adds
     */
    private String resourceType = null;

    /**
     * Stores a reference to the resource item to add
     */
    private ResourceItem resourceItem = new ResourceItem();

    /**
     * Stores a reference to the annotation text
     */
    private String annotationText = "";

    /**
     * Stores a reference to the parent frame for popups
     */
    private JFrame parentFrame = null;

    /**
     * Stores a reference to the labels panel
     */
    private JPanel labelsPanel = null;

    /**
     * Stores a reference to the fields panel
     */
    private JPanel fieldsPanel = null;

    /**
     * Stores a reference to the author label
     */
    private JLabel authorLabel = null;

    /**
     * Stores a reference to the publisher label
     */
    private JLabel publisherLabel = null;

    /**
     * Stores a reference to the title label
     */
    private JLabel titleLabel = null;

    /**
     * Stores a reference to the abstract label
     */
    private JLabel abstractLabel = null;

    /**
     * Stores a reference to the author field
     */
    private JTextField authorField = null;

    /**
     * Stores a reference to the title field
     */
    private JTextField titleField = null;

    /**
     * Stores a reference to the publisher field
     */
    private JTextField publisherField = null;

    /**
     * Stores a reference to the title panel
     */
    private JPanel titlePanel = null;

    /**
     * Stores a reference to the author panel
     */
    private JPanel authorPanel = null;

    /**
     * Stores a reference to the abstract panel
     */
    private JPanel abstractPanel = null;

    /**
     * Stores a reference to the publisher panel
     */
    private JPanel publisherPanel = null;

    /**
     * Stores a reference to the abstract field
     */
    private JTextField abstractField = null;

    /**
     * Stores a reference to the buttons panel
     */
    private JPanel buttonsPanel = null;

    /**
     * Stores a reference to the add Button
     */
    private JButton addButton = null;

    /**
     * Stores a reference to the clear Button
     */
    private JButton clearButton = null;

    /**
     * Stores a reference to the controller for the dialog
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private AddNewResourceItemDialogController controller = null;

    /**
     * Stores a reference to the resource dat apanel
     */
    private JPanel resourceDataPanel = null;

    /**
     * Stores a reference to the web label
     */
    private JLabel webLabel = null;

    /**
     * Stores a reference to the web url panel
     */
    private JPanel webURLPanel = null;

    /**
     * Stores a reference to the web url text field
     */
    private JTextField webURLField = null;

    /**
     * Stores a reference to the browse button
     */
    private JButton browseButton = null;

    /**
     * Stores a reference to the options panel
     */
    private JPanel optionsPanel = null;

    /**
     * Stores a reference to the local url button
     */
    private JButton LocalURLButton = null;

    /**
     * Stores a reference to the annotation button
     */
    private JButton AnnotationButton = null;

    /**
     * This is the default constructor
     * 
     * @param controller The main dialog controller
     * @param type The type of resource adding (book, video etc)
     * @param frame The parent frame for popups
     */
    public AddResourceTabPanel(AddNewResourceItemDialogController controller, String type, JFrame frame)
    {
        super();
        parentFrame = frame;
        resourceType = type;
        this.controller = controller;
        initialize();
    }

    /**
     * This method initializes the panel
     * 
     * @return void
     */
    private void initialize()
    {
        this.setLayout(new BorderLayout());
        this.setSize(826, 326);
        this.setBorder(javax.swing.BorderFactory.createEmptyBorder(10, 10, 10, 10));
        this.add(getButtonsPanel(), java.awt.BorderLayout.SOUTH);
        this.add(getResourceDataPanel(), java.awt.BorderLayout.NORTH);
    }

    /**
     * Clears all the data on the screen
     */
    private void clearData()
    {
        resourceItem = new ResourceItem();
        authorField.setText("");
        titleField.setText("");
        abstractField.setText("");
        webURLField.setText("");
        publisherField.setText("");
        annotationText = "";

    }

    /**
     * Adds all the text to the resource item and adds it to return list
     */
    private void addResourceItem()
    {
        // first check we have text in Author, title,publisher and Abstract
        if ((authorField.getText().length() == 0) || (publisherField.getText().length() == 0))
        {
            MDCMessageBox.showMissingAddResourceDataWarning(parentFrame);
            return;
        }
        // add all the items to the resource item
        resourceItem.setAuthor(authorField.getText());
        resourceItem.setTitle(titleField.getText());
        resourceItem.setAbstractStr(abstractField.getText());
        resourceItem.setWebURL(webURLField.getText());
        resourceItem.setAnnotation(annotationText);
        resourceItem.setPublisher(publisherField.getText());
        resourceItem.setType(resourceType);
        controller.addResourceItem(resourceItem);
    }

    /**
     * This method initializes the buttons panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="buttonsPanel"
     */
    private JPanel getButtonsPanel()
    {
        if (buttonsPanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            buttonsPanel = new JPanel();
            buttonsPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            buttonsPanel.add(getAddButton(), null);
            buttonsPanel.add(getClearButton(), null);
        }
        return buttonsPanel;
    }

    /**
     * This method initializes add button
     * 
     * @return javax.swing.JButton
     * @uml.property name="addButton"
     */
    private JButton getAddButton()
    {
        if (addButton == null)
        {
            addButton = new JButton();
            addButton.setText("Add");
            addButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    addResourceItem();
                }
            });
        }
        return addButton;
    }

    /**
     * This method initializes the clear button
     * 
     * @return javax.swing.JButton
     * @uml.property name="clearButton"
     */
    private JButton getClearButton()
    {
        if (clearButton == null)
        {
            clearButton = new JButton();
            clearButton.setText("Clear fields");
            clearButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    clearData();
                }
            });
        }
        return clearButton;
    }

    /**
     * This method initializes resource data panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="resourceDataPanel"
     */
    private JPanel getResourceDataPanel()
    {
        if (resourceDataPanel == null)
        {
            resourceDataPanel = new JPanel();
            resourceDataPanel.setLayout(new BorderLayout());
            resourceDataPanel.setSize(846, 143);
            resourceDataPanel.add(getLabelsPanel(), java.awt.BorderLayout.WEST);
            resourceDataPanel.add(getFieldsPanel(), java.awt.BorderLayout.CENTER);
        }
        return resourceDataPanel;
    }

    /**
     * This method initializes the labels panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="labelsPanel"
     */
    private JPanel getLabelsPanel()
    {
        if (labelsPanel == null)
        {
            webLabel = new JLabel();
            labelsPanel = new JPanel();
            titleLabel = new JLabel();
            publisherLabel = new JLabel();
            authorLabel = new JLabel();
            abstractLabel = new JLabel();
            GridLayout gridLayout = new GridLayout();
            labelsPanel.setLayout(gridLayout);
            gridLayout.setRows(6);
            gridLayout.setColumns(1);
            gridLayout.setVgap(5);
            authorLabel.setText("Author");
            titleLabel.setText("Title");
            publisherLabel.setText("Publisher");
            abstractLabel.setText("Abstract");

            authorLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            titleLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            abstractLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            publisherLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            webLabel.setText("Web URL");
            labelsPanel.add(authorLabel, null);
            labelsPanel.add(titleLabel, null);
            labelsPanel.add(publisherLabel, null);
            labelsPanel.add(abstractLabel, null);
            labelsPanel.add(webLabel, null);

        }
        return labelsPanel;
    }

    /**
     * This method initializes the fields panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="fieldsPanel"
     */
    private JPanel getFieldsPanel()
    {
        if (fieldsPanel == null)
        {
            fieldsPanel = new JPanel();
            GridLayout gridLayout = new GridLayout();
            fieldsPanel.setLayout(gridLayout);
            gridLayout.setRows(6);
            gridLayout.setColumns(2);
            gridLayout.setVgap(5);
            gridLayout.setHgap(10);
            fieldsPanel.add(getAuthorPanel(), null);
            fieldsPanel.add(getTitlePanel(), null);
            fieldsPanel.add(getPublisherPanel(), null);
            fieldsPanel.add(getAbstractPanel(), null);
            fieldsPanel.add(getWebURLPanel(), null);
            fieldsPanel.add(getOptionsPanel(), null);
        }
        return fieldsPanel;
    }

    /**
     * This method initializes the publisher text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="publisherField"
     */
    private JTextField getPublisherField()
    {
        if (publisherField == null)
        {
            publisherField = new JTextField();
            publisherField.setColumns(25);

        }
        return publisherField;
    }

    /**
     * This method initializes the author text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="authorField"
     */
    private JTextField getAuthorField()
    {
        if (authorField == null)
        {
            authorField = new JTextField();
            authorField.setColumns(25);

        }
        return authorField;
    }

    /**
     * This method initializes the title text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="titleField"
     */
    private JTextField getTitleField()
    {
        if (titleField == null)
        {
            titleField = new JTextField();
            titleField.setColumns(25);

        }
        return titleField;
    }

    /**
     * This method initializes the title panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="titlePanel"
     */
    private JPanel getTitlePanel()
    {
        if (titlePanel == null)
        {
            titlePanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            titlePanel.setLayout(flowLayout);
            titlePanel.add(getTitleField(), null);
        }
        return titlePanel;
    }

    /**
     * This method initializes the publisher panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="publisherPanel"
     */
    private JPanel getPublisherPanel()
    {
        if (publisherPanel == null)
        {
            publisherPanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            publisherPanel.setLayout(flowLayout);
            publisherPanel.add(getPublisherField(), null);
        }
        return publisherPanel;
    }

    /**
     * This method initializes the author panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="authorPanel"
     */
    private JPanel getAuthorPanel()
    {
        if (authorPanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            authorPanel = new JPanel();
            authorPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            authorPanel.add(getAuthorField(), null);
        }
        return authorPanel;
    }

    /**
     * This method initializes the abstract panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="abstractPanel"
     */
    private JPanel getAbstractPanel()
    {
        if (abstractPanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            abstractPanel = new JPanel();
            abstractPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            abstractPanel.add(getAbstractField(), null);
        }
        return abstractPanel;
    }

    /**
     * This method initializes the abstract field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="abstractField"
     */
    private JTextField getAbstractField()
    {
        if (abstractField == null)
        {
            abstractField = new JTextField();
            abstractField.setColumns(50);

        }
        return abstractField;
    }

    /**
     * This method initializes the web url panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="webURLPanel"
     */
    private JPanel getWebURLPanel()
    {
        if (webURLPanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            webURLPanel = new JPanel();
            webURLPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            webURLPanel.add(getWebURLTextField(), null);
            webURLPanel.add(getBrowseButton(), null);
        }
        return webURLPanel;
    }

    /**
     * This method initializes the web url text field
     * 
     * @return javax.swing.JTextField
     */
    private JTextField getWebURLTextField()
    {
        if (webURLField == null)
        {
            webURLField = new JTextField();
            webURLField.setColumns(50);
        }
        return webURLField;
    }

    /**
     * This method initializes the browse button
     * 
     * @return javax.swing.JButton
     * @uml.property name="browseButton"
     */
    private JButton getBrowseButton()
    {
        if (browseButton == null)
        {
            browseButton = new JButton();
            browseButton.setText("Browse...");
            browseButton.setIcon(MDCIcons.WORLD_ICON);
            browseButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    String url = webURLField.getText();
                    // make sure we have text in field
                    if (url.length() >= 0)
                    {
                        // if it does not start with http then add it to start
                        // of
                        // string
                        if (!url.startsWith("http://"))
                        {
                            url = "http://" + url;
                            webURLField.setText(url);
                        }
                        BrowserControl.displayURL(url);
                    }
                }
            });
        }
        return browseButton;
    }

    /**
     * This method initializes the options panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="optionsPanel"
     */
    private JPanel getOptionsPanel()
    {
        if (optionsPanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            optionsPanel = new JPanel();
            optionsPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            optionsPanel.add(getLocalURLButton(), null);
            optionsPanel.add(getAnnotationButton(), null);
        }
        return optionsPanel;
    }

    /**
     * This method initializes the local url panel
     * 
     * @return javax.swing.JButton
     * @uml.property name="localURLButton"
     */
    private JButton getLocalURLButton()
    {
        if (LocalURLButton == null)
        {
            LocalURLButton = new JButton();
            LocalURLButton.setText("Local URL...");
            LocalURLButton.setIcon(MDCIcons.OPENSMALL_ICON);
            LocalURLButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    OpenLocalURLDialog urlDialog = new OpenLocalURLDialog(parentFrame, resourceItem);
                    urlDialog.show();
                }
            });
        }
        return LocalURLButton;
    }

    /**
     * This method initializes the annotation panel
     * 
     * @return javax.swing.JButton
     * @uml.property name="annotationButton"
     */
    private JButton getAnnotationButton()
    {
        if (AnnotationButton == null)
        {
            AnnotationButton = new JButton();
            AnnotationButton.setText("Anotation...");
            AnnotationButton.setIcon(MDCIcons.ANNOTATION_ICON);
            AnnotationButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    EditAnnotationDialog editDialog = new EditAnnotationDialog(annotationText, parentFrame);
                    editDialog.show();
                    annotationText = editDialog.getAnnotation();
                }
            });
        }
        return AnnotationButton;
    }

} //  @jve:decl-index=0:visual-constraint="74,31"
