/*
 * MDC Desktop Client Created on 05-May-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;

import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

import org.mdcog.client.desktop.gui.controllers.CreateListDialogController;
import org.mdcog.client.desktop.gui.images.MDCFonts;
import org.mdcog.client.styles.MDCStyle;

/**
 * This class creates the create list dialogs document selection panel <br/>
 * <br/>Note - It was partially created using the Eclipse Visual Editor plugin
 */
public class CreateListCreateDocumentPanel extends JPanel
{

    /**
     * Stores a reference to the controller for the panel
     * 
     */
    private CreateListDialogController controller = null;


    /**
     * Stores a reference to the header panel
     */
    private JPanel headerPanel = null;

    /**
     * Stores a reference to the header label
     */
    private JLabel headerLabel = null;

    /**
     * Stores a reference to the button panel
     */
    private JPanel buttonPanel = null;

    /**
     * Stores a reference to the create button
     */
    private JButton createButton = null;

    /**
     * Stores a reference to the style options panel
     */
    private JPanel styleOptionsPanel = null;

    /**
     * Stores a reference to the style panel
     */
    private JPanel stylePanel = null;

    /**
     * Stores a reference to the format panel
     */
    private JPanel formatPanel = null;

    /**
     * Stores a reference to the format buttons group
     */
    private ButtonGroup formatButtonGroup = null;

    /**
     * Stores a reference to the html radio button
     */
    private JRadioButton HTMLRadio = null;

    /**
     * Stores a reference to the pdf radio button
     */
    private JRadioButton PDFRadio = null;

    /**
     * Stores a reference to the style combobox
     */
    private JComboBox styleTypesCombo = null;

    /**
     * Stores a reference to the style label
     */
    private JLabel styleLabel = null;

	/**
	 * Stores a reference to the format selection panel 
	 */
	private JPanel formatSelectionPanel = null;
    /**
     * This is the default constructor
     * 
     * @param controller The controller for the panel
     */
    public CreateListCreateDocumentPanel(CreateListDialogController controller)
    {
        super();
        this.controller = controller;
        initialize();
    }

    /**
     * This method initializes the panel
     */
    private void initialize()
    {
        this.setLayout(new BorderLayout());
        this.setSize(449, 102);
        this.setBorder(new javax.swing.border.SoftBevelBorder(javax.swing.border.SoftBevelBorder.LOWERED));
        this.add(getStyleOptionsPanel(), java.awt.BorderLayout.CENTER);
        this.add(getHeaderPanel(), java.awt.BorderLayout.NORTH);
    }

    /**
     * This method initializes the header panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="headerPanel"
     */
    private JPanel getHeaderPanel() {
        if (headerPanel == null) {
            FlowLayout flowLayout = new FlowLayout();
            headerLabel = new JLabel();
            headerPanel = new JPanel();
            headerPanel.setLayout(flowLayout);
            headerLabel.setText("Create Document");
            headerLabel.setFont(MDCFonts.HEADER_FONT);
            headerLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            headerPanel.add(headerLabel, null);
        }
        return headerPanel;
    }

    /**
     * This method initializes the button panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="buttonPanel"
     */
    private JPanel getButtonPanel() {
        if (buttonPanel == null) {
            FlowLayout flowLayout = new FlowLayout();
            buttonPanel = new JPanel();
            buttonPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            buttonPanel.add(getCreateButton(), null);
        }
        return buttonPanel;
    }

    /**
     * This method initializes the create button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="createButton"
     */
    private JButton getCreateButton() {
        if (createButton == null) {
            createButton = new JButton();
            createButton.setText("Create");
            createButton.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    controller.createDocument((MDCStyle) styleTypesCombo.getSelectedItem());
                }
            });
        }
        return createButton;
    }

    /**
     * This method initializes the options panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="styleOptionsPanel"
     */
    private JPanel getStyleOptionsPanel() {
        if (styleOptionsPanel == null) {
            styleOptionsPanel = new JPanel();
            styleOptionsPanel.setLayout(new BoxLayout(styleOptionsPanel, BoxLayout.Y_AXIS));
            styleOptionsPanel.add(getStylePanel(), null);
            styleOptionsPanel.add(getFormatPanel(), null);
        }
        return styleOptionsPanel;
    }

    /**
     * This method initializes the style panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="stylePanel"
     */
    private JPanel getStylePanel() {
        if (stylePanel == null) {
            stylePanel = new JPanel();
            styleLabel = new JLabel();
            FlowLayout flowLayout = new FlowLayout();
            stylePanel.setLayout(flowLayout);
            styleLabel.setText("Apply style:");
            styleLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            stylePanel.add(styleLabel, null);
            stylePanel.add(getStyleTypesCombo(), null);
        }
        return stylePanel;
    }

    /**
     * This method initializes the format panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="formatPanel"
     */
    private JPanel getFormatPanel() {
        if (formatPanel == null) {
            formatPanel = new JPanel();
            formatPanel.setLayout(new BorderLayout());
            formatPanel.add(getFormatSelectionPanel(), java.awt.BorderLayout.CENTER);
            formatPanel.add(getButtonPanel(), java.awt.BorderLayout.EAST);            
        }
        return formatPanel;
    }

    /**
     * This method initializes the html radio button
     * 
     * @return javax.swing.JRadioButton
     * 
     * @uml.property name="hTMLRadio"
     */
    private JRadioButton getHTMLRadio() {
        if (HTMLRadio == null) {
            HTMLRadio = new JRadioButton();
            HTMLRadio.setText("HTML");
            HTMLRadio.setActionCommand(CreateListDialogController.STYLE_HTML);
            HTMLRadio.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
            HTMLRadio.setSelected(true);
        }
        return HTMLRadio;
    }

    /**
     * This method initializes the pdf radio button
     * 
     * @return javax.swing.JRadioButton
     * 
     * @uml.property name="pDFRadio"
     */
    private JRadioButton getPDFRadio() {
        if (PDFRadio == null) {
            PDFRadio = new JRadioButton();
            PDFRadio.setText("PDF");
            PDFRadio.setActionCommand(CreateListDialogController.STYLE_PDF);
            PDFRadio.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        }
        return PDFRadio;
    }

    /**
     * This method initializes styles combobox
     * 
     * @return javax.swing.JComboBox
     * 
     * @uml.property name="styleTypesCombo"
     */
    private JComboBox getStyleTypesCombo() {
        if (styleTypesCombo == null) {
            styleTypesCombo = new JComboBox(controller.getCreateDocumentStyles());
            styleTypesCombo.setPreferredSize(new java.awt.Dimension(300, 22));
            styleTypesCombo.setSelectedIndex(0);
        }
        return styleTypesCombo;
    }

	/**
	 * This method initializes format selection panel	
	 * 	
	 * @return javax.swing.JPanel	
	 */    
	private JPanel getFormatSelectionPanel() {
		if (formatSelectionPanel == null) {
			formatSelectionPanel = new JPanel();
			FlowLayout flowLayout = new FlowLayout();
			formatSelectionPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            flowLayout.setHgap(10);
            formatSelectionPanel.add(getHTMLRadio(), null);
            formatSelectionPanel.add(getPDFRadio(), null);
            formatButtonGroup = new ButtonGroup();
            formatButtonGroup.add(HTMLRadio);
            formatButtonGroup.add(PDFRadio);
            controller.setFormatOptionsButtonGroup(formatButtonGroup);
		}
		return formatSelectionPanel;
	}
 } //  @jve:decl-index=0:visual-constraint="10,10"
