/*
 * MDC Desktop Client Created on 05-May-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

import org.mdcog.client.desktop.gui.controllers.CreateListDialogController;
import org.mdcog.client.desktop.gui.images.MDCFonts;

/**
 * This class creates the create list dialogs export panel <br/><br/>Note - It
 * was partially created using the Eclipse Visual Editor plugin
 */
public class CreateListExportPanel extends JPanel
{

    /**
     * Stores a reference to the controller for the panel
     * 
     */
    private CreateListDialogController controller = null;


    /**
     * Stores a reference to the header panel
     */
    private JPanel headerPanel = null;

    /**
     * Stores a reference to the header label
     */
    private JLabel headerLabel = null;

    /**
     * Stores a reference to the button panel
     */
    private JPanel buttonPanel = null;

    /**
     * Stores a reference to the export button
     */
    private JButton exportButton = null;

    /**
     * Stores a reference to the options button group
     */
    private ButtonGroup optionsButtonGroup = null;

    /**
     * Stores a reference to the IMSRLI radio button
     */
    private JRadioButton IMSRLIRadio = null;

    /**
     * Stores a reference to the MODS radio button
     */
    private JRadioButton MODSRadio = null;

    /**
     * Stores a reference to the export options panel
     */
    private JPanel exportOptionsPanel = null;

	/**
	 * Stores a reference to the export panel
	 */
	private JPanel exportPanel = null;
	/**
	 * Stores a reference to the export options layout panel
	 */
	private JPanel exportOptionsLayoutPanel = null;
    /**
     * This is the default constructor
     * 
     * @param controller The controller for the panel
     */
    public CreateListExportPanel(CreateListDialogController controller)
    {
        super();
        this.controller = controller;
        initialize();

    }

    /**
     * This method initializes the panel
     */
    private void initialize()
    {
        this.setLayout(new BorderLayout());
        this.setSize(419, 93);
        this.setBorder(new javax.swing.border.SoftBevelBorder(javax.swing.border.SoftBevelBorder.LOWERED));
        this.add(getHeaderPanel(), java.awt.BorderLayout.NORTH);
        this.add(getExportPanel(), java.awt.BorderLayout.SOUTH);
    }

    /**
     * This method initializes the header panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="headerPanel"
     */
    private JPanel getHeaderPanel() {
        if (headerPanel == null) {
            FlowLayout flowLayout = new FlowLayout();
            headerLabel = new JLabel();
            headerPanel = new JPanel();
            headerPanel.setLayout(flowLayout);
            headerLabel.setText("Export");
            headerLabel.setFont(MDCFonts.HEADER_FONT);
            headerLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            headerPanel.add(headerLabel, null);
        }
        return headerPanel;
    }

    /**
     * This method initializes button panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="buttonPanel"
     */
    private JPanel getButtonPanel() {
        if (buttonPanel == null) {
            buttonPanel = new JPanel();
            buttonPanel.setLayout(new BorderLayout());
            buttonPanel.add(getExportButton(), java.awt.BorderLayout.SOUTH);
        }
        return buttonPanel;
    }

    /**
     * This method initializes export button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="exportButton"
     */
    private JButton getExportButton() {
        if (exportButton == null) {
            exportButton = new JButton();
            exportButton.setText("Export");
            exportButton.addActionListener(new java.awt.event.ActionListener() {
                public void actionPerformed(java.awt.event.ActionEvent e) {
                    controller.export();
                }
            });
        }
        return exportButton;
    }

    /**
     * This method initializes the export option panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="exportOptionsPanel"
     */
    private JPanel getExportOptionsPanel() {
        if (exportOptionsPanel == null) {
            exportOptionsPanel = new JPanel();
            exportOptionsPanel.setLayout(new BorderLayout());
            exportOptionsPanel.add(getIMSRLIRadio(), java.awt.BorderLayout.NORTH);
            exportOptionsPanel.add(getMODSRadio(), java.awt.BorderLayout.SOUTH);
            optionsButtonGroup = new ButtonGroup();
            optionsButtonGroup.add(IMSRLIRadio);
            optionsButtonGroup.add(MODSRadio);
            controller.setExportOptionsButtonGroup(optionsButtonGroup);
        }
        return exportOptionsPanel;
    }

    /**
     * This method initializes IMSRLI radio button
     * 
     * @return javax.swing.JRadioButton
     * 
     * @uml.property name="iMSRLIRadio"
     */
    private JRadioButton getIMSRLIRadio() {
        if (IMSRLIRadio == null) {
            IMSRLIRadio = new JRadioButton();
            IMSRLIRadio.setText("As IMS RLI e.g. publish to repository");
            IMSRLIRadio.setActionCommand(CreateListDialogController.EXPORT_IMS);
            IMSRLIRadio.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
            IMSRLIRadio.setSelected(false);
        }
        return IMSRLIRadio;
    }

    /**
     * This method initializes mods radio button
     * 
     * @return javax.swing.JRadioButton
     * 
     * @uml.property name="mODSRadio"
     */
    private JRadioButton getMODSRadio() {
        if (MODSRadio == null) {
            MODSRadio = new JRadioButton();
            MODSRadio.setText("As MODS e.g. for citations management in open office");
            MODSRadio.setActionCommand(CreateListDialogController.EXPORT_MODS);
            MODSRadio.setSelected(true);
        }
        return MODSRadio;
    }

	/**
	 * This method initializes the export panel	
	 * 	
	 * @return javax.swing.JPanel	
	 */    
	private JPanel getExportPanel() {
		if (exportPanel == null) {
			exportPanel = new JPanel();
			exportPanel.setLayout(new BorderLayout());
			exportPanel.add(getButtonPanel(), java.awt.BorderLayout.EAST);
			exportPanel.add(getExportOptionsLayoutPanel(), java.awt.BorderLayout.WEST);
		}
		return exportPanel;
	}
	/**
	 * This method initializes the export options layout	
	 * 	
	 * @return javax.swing.JPanel	
	 */    
	private JPanel getExportOptionsLayoutPanel() {
		if (exportOptionsLayoutPanel == null) {
			exportOptionsLayoutPanel = new JPanel();
			exportOptionsLayoutPanel.setLayout(new BorderLayout());
			exportOptionsLayoutPanel.add(getExportOptionsPanel(), java.awt.BorderLayout.WEST);
		}
		return exportOptionsLayoutPanel;
	}
  }  //  @jve:decl-index=0:visual-constraint="82,11"
