/*
 * MDC Desktop Client Created on 09-May-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Point;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

import org.mdcog.client.desktop.gui.controllers.CreateListDialogController;
import org.mdcog.client.desktop.gui.error.MDCInternalException;
import org.mdcog.client.desktop.gui.error.MDCMessageBox;
import org.mdcog.client.desktop.gui.menus.CreateListResourceGridPopUpMenu;
import org.mdcog.client.desktop.gui.models.ResourceItemButtonMouseListener;
import org.mdcog.client.desktop.gui.models.ResourceItemTableFormat;

import ca.odell.glazedlists.swing.EventTableModel;
import ca.odell.glazedlists.swing.TableComparatorChooser;

/**
 * This class creates the create list dialogs resources grid panel <br/>
 * <br/>Note - It was partially created using the Eclipse Visual Editor plugin
 */
public class CreateListResourcesGridPanel extends JPanel
{

    /**
     * Stores a reference to the controller for the panel
     */
    private CreateListDialogController controller = null;

    /**
     * Stores a reference to the resource table
     */
    private JTable resourceTable = null;

    /**
     * Stores a reference to the resource table scroll window
     */
    private JScrollPane resourceGridScrollPane = null;

    /**
     * Stores a reference to the filter panel
     */
    private JPanel filterPanel = null;

    /**
     * Stores a reference to the filter label
     */
    private JLabel filterLabel = null;

    /**
     * Stores a reference to the filter text field
     */
    private JTextField filterTextField = null;

    /**
     * Stores a reference to the resource grid panel
     */
    private JPanel resourceGridPanel = null;

    /**
     * Stores a reference to the list header panel
     * 
     * @uml.property name="resourceListHeaderPanel"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private ResourceListHeaderPanel resourceListHeaderPanel = null;

    /**
     * Stores a reference to the validate panel
     * 
     * @uml.property name="validatePanel"
     * @uml.associationEnd inverse=":javax.swing.JPanel" multiplicity="(0 1)"
     */
    private JPanel validatePanel = null;

    /**
     * Stores a reference to the add resource button
     * 
     * @uml.property name="addResourceButton"
     * @uml.associationEnd inverse=":javax.swing.JButton" multiplicity="(0 1)"
     */
    private JButton addResourceButton = null;

    /**
     * This is the default constructor
     * 
     * @param controller The controller for the panel
     */
    public CreateListResourcesGridPanel(CreateListDialogController controller)
    {
        super();
        this.controller = controller;
        initialize();
    }

    /**
     * This method initializes this panel
     */
    private void initialize()
    {
        this.setLayout(new BorderLayout());
        this.setBorder(new javax.swing.border.SoftBevelBorder(javax.swing.border.SoftBevelBorder.LOWERED));
        this.setSize(1121, 526);
        this.add(getResourceGridPanel(), java.awt.BorderLayout.CENTER);
        this.add(getResourceListHeaderPanel(), java.awt.BorderLayout.NORTH);
        this.add(getValidatePanel(), java.awt.BorderLayout.SOUTH);
    }

    /**
     * This method initializes the resource table
     * 
     * @return javax.swing.JTable
     * @uml.property name="resourceTable"
     */
    private JTable getResourceTable()
    {
        if (resourceTable == null)
        {
            resourceTable = new JTable(controller.getResourceTableModel());
            resourceTable.setAutoCreateColumnsFromModel(true);
            new TableComparatorChooser(resourceTable, controller.getSortedResourceItems(), false);
            resourceTable.setSelectionMode(javax.swing.ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
            // set up special renders
            resourceTable.setRowHeight(ResourceItemTableFormat.ROW_HEIGHT);
            resourceTable.setAutoResizeMode(javax.swing.JTable.AUTO_RESIZE_NEXT_COLUMN);
            setupColumns(resourceTable);
            resourceTable.addMouseListener(new ResourceItemButtonMouseListener(resourceTable));
            resourceTable.getTableHeader().addMouseListener(new java.awt.event.MouseAdapter()
                    {

                        // handle right click on resource list to show popup
                        public void mouseReleased(java.awt.event.MouseEvent e)
                        {
                            // check if context popup event
                            if (e.isPopupTrigger())
                            {
                                try
                                {
                                    // get the column where click occured as new column may be inserted here
                                    int columnClicked = resourceTable.columnAtPoint(new Point(e.getX(), e.getY()));
                                    // get the table format information holder
                                    EventTableModel eventTableModel = (EventTableModel) resourceTable.getModel();
                                    ResourceItemTableFormat tableFormat = (ResourceItemTableFormat) eventTableModel.getTableFormat();
                                    tableFormat.showSelectedColumnsPopUp(resourceTable,columnClicked,e.getX(),e.getY());
                                }
                                catch (MDCInternalException exc)
                                {
                                    exc.printStackTrace();
                                    MDCMessageBox.showInternalError(exc,null);
                                }
                            }
                        }
                    });
            resourceTable.addMouseListener(new java.awt.event.MouseAdapter()
            {

                // handle right click on resource list to show popup
                public void mouseReleased(java.awt.event.MouseEvent e)
                {
                    // check if context popup event
                    if (e.isPopupTrigger())
                    {
                        // find out row and column affected
                        int rowAffected = resourceTable.rowAtPoint(new Point(e.getX(), e.getY()));
                        //make sure the row/column is automatically selected
                        // that this popup is on
                        resourceTable.addRowSelectionInterval(rowAffected, rowAffected);
                        // show the popup giving it reference to the
                        // resourceList
                        CreateListResourceGridPopUpMenu popup = new CreateListResourceGridPopUpMenu(controller, resourceTable
                                .getSelectedRows());
                        popup.show(resourceTable, e.getX(), e.getY());
                    }
                    else
                    {
                        super.mouseReleased(e);
                    }
                }
            });
        }
        return resourceTable;
    }

    /**
     * This method initializes scroll pane
     * 
     * @return javax.swing.JScrollPane
     * @uml.property name="resourceGridScrollPane"
     */
    private JScrollPane getResourceGridScrollPane()
    {
        if (resourceGridScrollPane == null)
        {
            resourceGridScrollPane = new JScrollPane();
            resourceGridScrollPane.setViewportView(getResourceTable());
        }
        return resourceGridScrollPane;
    }

    /**
     * Sets up the special renders for the grid using ResourceListTableFormat
     * 
     * @param resourceTable
     */
    private void setupColumns(JTable resourceTable)
    {
        // get the table format information holder
        EventTableModel eventTableModel = (EventTableModel)resourceTable.getModel();
        ResourceItemTableFormat tableFormat = (ResourceItemTableFormat)eventTableModel.getTableFormat();
       // get the column model
        TableColumnModel columnModel = resourceTable.getColumnModel();
        TableColumn column = null;
        // now loop round each column setting it upt
        for (int i = 0; i < columnModel.getColumnCount(); i++)
        {
            column = columnModel.getColumn(i);
            tableFormat.setUpColumn(column, column.getModelIndex());

        }
    }

    /**
     * This method initializes the filter panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="filterPanel"
     */
    private JPanel getFilterPanel()
    {
        if (filterPanel == null)
        {
            filterPanel = new JPanel();
            FlowLayout flowLayout1 = new FlowLayout();
            filterLabel = new JLabel();
            filterPanel.setLayout(flowLayout1);
            filterPanel.setSize(50, 46);
            filterPanel.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            filterLabel.setText("Filter: ");
            filterLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            flowLayout1.setAlignment(java.awt.FlowLayout.RIGHT);
            filterPanel.add(filterLabel, null);
            filterPanel.add(getFilterTextField(), null);
        }
        return filterPanel;
    }

    /**
     * This method initializes filter text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="filterTextField"
     */
    private JTextField getFilterTextField()
    {
        if (filterTextField == null)
        {
            filterTextField = controller.getResourceItemsFilterTextControl();
            filterTextField.setPreferredSize(new java.awt.Dimension(500, 23));
        }
        return filterTextField;
    }

    /**
     * This method initializes the resource grid panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="resourceGridPanel"
     */
    private JPanel getResourceGridPanel()
    {
        if (resourceGridPanel == null)
        {
            resourceGridPanel = new JPanel();
            resourceGridPanel.setLayout(new BorderLayout());
            resourceGridPanel.add(getResourceGridScrollPane(), java.awt.BorderLayout.CENTER);
            resourceGridPanel.add(getFilterPanel(), java.awt.BorderLayout.NORTH);
        }
        return resourceGridPanel;
    }

    /**
     * This method initializes myLibraryResourceListHeaderPanel
     * 
     * @return org.mdc.client.desktop.gui.panels.MyLibraryResourceListHeaderPanel
     * @uml.property name="resourceListHeaderPanel"
     */
    private ResourceListHeaderPanel getResourceListHeaderPanel()
    {
        if (resourceListHeaderPanel == null)
        {
            resourceListHeaderPanel = new ResourceListHeaderPanel(controller);
        }
        return resourceListHeaderPanel;
    }

    /**
     * This method initializes the validate panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="validatePanel"
     */
    private JPanel getValidatePanel()
    {
        if (validatePanel == null)
        {
            FlowLayout flowLayout11 = new FlowLayout();
            validatePanel = new JPanel();
            validatePanel.setLayout(flowLayout11);
            flowLayout11.setAlignment(java.awt.FlowLayout.RIGHT);
            validatePanel.add(getAddResourceButton(), null);
        }
        return validatePanel;
    }

    /**
     * This method initializes add resource button
     * 
     * @return javax.swing.JButton
     * @uml.property name="addResourceButton"
     */
    private JButton getAddResourceButton()
    {
        if (addResourceButton == null)
        {
            addResourceButton = new JButton();
            addResourceButton.setText("Add Resource Item");
            addResourceButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.createResourceItems();
                }
            });
        }
        return addResourceButton;
    }

} //  @jve:decl-index=0:visual-constraint="10,10"
