/*
 * MDC Desktop Client Created on 20-Apr-2005
 */
package org.mdcog.client.desktop.gui.panels;

import javax.swing.JTabbedPane;

import org.mdcog.client.desktop.gui.controllers.LibraryTabController;
import org.mdcog.client.desktop.gui.controllers.SearchTabController;
import org.mdcog.client.desktop.gui.controllers.TabSelectorInterface;
import org.mdcog.client.desktop.gui.images.MDCFonts;
import org.mdcog.client.desktop.gui.images.MDCIcons;

/**
 * This class implements the libary and search tabs for the application <br/>
 * <br/>Note - It was partially created using the Eclipse Visual Editor plugin
 */
public class DesktopTabPanel extends JTabbedPane implements TabSelectorInterface
{

    /**
     * Stores a reference to the library tab panel for laying out the screen
     * 
     * @uml.property name="myLibaryTab"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private MyLibaryTabPanel myLibaryTab = null; //  @jve:decl-index=0:visual-constraint="335,12"

    /**
     * Stores a reference to the search tab panel for laying out the screen
     * 
     * @uml.property name="searchTab"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private SearchTabPanel searchTab = null;


    /**
     * This is the default constructor for the tab panle that intialises the
     * tabs
     */
    public DesktopTabPanel()
    {
        super();
        initialize();
    }

    /**
     * This method switches selection to the library tab. Note the index must be
     * the same as the index the tab was added in the initialise method
     * 
     * @see org.mdcog.client.desktop.gui.panels.DesktopTabPanel#initialize()
     */
    public void selectLibraryTab()
    {
        setSelectedIndex(0);
    }

    /**
     * This method switches selection to the search tab. Note the index must be
     * the same as the index the tab was added in the initialise method
     * 
     * @see org.mdcog.client.desktop.gui.panels.DesktopTabPanel#initialize()
     */
    public void selectSearchTab()
    {
        setSelectedIndex(1);
    }

    /**
     * This method initializes the tab pane adding the individual library and
     * search tabs to the screen. The index that the tabs are added at must be
     * aligned with the selectXXXTab methods.
     */
    private void initialize()
    {
        this.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
        this.setFont(MDCFonts.HEADER_FONT);
        this.addTab("My Library", MDCIcons.LIBRARY_ICON, getMyLibaryTab(), null);
        this.addTab("Search", MDCIcons.SEARCH_ICON, getSearchTab(), null);
        // resgister as tab selector to tab controllers
        LibraryTabController.getInstance().setTabSelector(this);
        SearchTabController.getInstance().setTabSelector(this);
    }

    /**
     * This method initializes the library tab panel
     * 
     * @return org.mdc.client.desktop.gui.MyLibaryTab
     * 
     * @uml.property name="myLibaryTab"
     */
    private MyLibaryTabPanel getMyLibaryTab() {
        if (myLibaryTab == null) {
            myLibaryTab = new MyLibaryTabPanel();
            myLibaryTab.setBorder(javax.swing.BorderFactory.createEmptyBorder(5, 5, 5, 5));
        }
        return myLibaryTab;
    }

    /**
     * This method initializes the search tab panel
     * 
     * @return org.mdc.client.desktop.gui.SearchTab
     * 
     * @uml.property name="searchTab"
     */
    private SearchTabPanel getSearchTab() {
        if (searchTab == null) {
            searchTab = new SearchTabPanel();
            searchTab.setBorder(javax.swing.BorderFactory.createEmptyBorder(5, 5, 5, 5));
        }
        return searchTab;
    }

} //  @jve:decl-index=0:visual-constraint="213,51"
