/*
 * MDC Desktop Client Created on 21-Apr-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Point;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

import org.mdcog.client.desktop.gui.controllers.LibraryTabController;
import org.mdcog.client.desktop.gui.error.MDCInternalException;
import org.mdcog.client.desktop.gui.error.MDCMessageBox;
import org.mdcog.client.desktop.gui.menus.MyLibraryResourceGridPopUpMenu;
import org.mdcog.client.desktop.gui.models.MyLibraryResourceItemTransferOutHandler;
import org.mdcog.client.desktop.gui.models.ResourceItemButtonMouseListener;
import org.mdcog.client.desktop.gui.models.ResourceItemTableFormat;

import ca.odell.glazedlists.swing.EventTableModel;
import ca.odell.glazedlists.swing.TableComparatorChooser;

/**
 * This class implements the My Library resource grid panel <br/><br/>Note - It
 * was partially created using the Eclipse Visual Editor plugin
 * 
 * @uml.dependency supplier="org.mdcog.client.desktop.gui.panels.ResourceListHeaderPanel"
 *                 stereotypes="Basic::Instantiate"
 */

public class MyLibraryResourceGridPanel extends JPanel
{

    /**
     * Stores a reference to the controller for the panel
     */
    private LibraryTabController controller = null;

    /**
     * Stores a reference to the resource table
     */
    private JTable resourceTable = null;

    /**
     * Stores a reference to the resource table scroll pane
     */
    private JScrollPane resourceGridScrollPane = null;

    /**
     * Stores a reference to the create list panel
     */
    private JPanel createListPanel = null;

    /**
     * Stores a reference to the create list button
     */
    private JButton createListButton = null;

    /**
     * Stores a reference to the filter panel
     */
    private JPanel filterPanel = null;

    /**
     * Stores a reference to the filter label
     */
    private JLabel filterLabel = null;

    /**
     * Stores a reference to the filter text field
     */
    private JTextField filterTextField = null;

    /**
     * Stores a reference to the
     */
    private JPanel resourceGridPanel = null;

    /**
     * Stores a reference to the resource list header panel
     * 
     * @uml.property name="myLibraryResourceListHeaderPanel"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private ResourceListHeaderPanel myLibraryResourceListHeaderPanel = null;

    /**
     * Stores a reference to the new resource button
     */
    private JButton newResourceItemButton = null;

    /**
     * This is the default constructor
     */
    public MyLibraryResourceGridPanel()
    {
        super();
        initialize();
    }

    /**
     * This method initializes this panel
     */
    private void initialize()
    {
        //	  get a reference to the controller
        controller = LibraryTabController.getInstance();
        this.setLayout(new BorderLayout());
        this.setBorder(new javax.swing.border.SoftBevelBorder(javax.swing.border.SoftBevelBorder.LOWERED));
        this.setSize(1121, 526);
        this.add(getCreateListPanel(), java.awt.BorderLayout.SOUTH);
        this.add(getResourceGridPanel(), java.awt.BorderLayout.CENTER);
        this.add(getMyLibraryResourceListHeaderPanel(), java.awt.BorderLayout.NORTH);
    }

    /**
     * This method initializes the resource table
     * 
     * @return javax.swing.JTable
     * @uml.property name="resourceTable"
     */
    private JTable getResourceTable()
    {
        if (resourceTable == null)
        {
            resourceTable = new JTable(controller.getResourceItemTableModel());
            resourceTable.setAutoCreateColumnsFromModel(true);
            new TableComparatorChooser(resourceTable, controller.getSortedResourceItems(), false);
            resourceTable.setSelectionMode(javax.swing.ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
            resourceTable.setDragEnabled(true);
            resourceTable.setTransferHandler(new MyLibraryResourceItemTransferOutHandler());
            // set up special renders
            resourceTable.setRowHeight(ResourceItemTableFormat.ROW_HEIGHT);
            setupColumns(resourceTable);
            resourceTable.addMouseListener(new ResourceItemButtonMouseListener(resourceTable));

            resourceTable.getTableHeader().addMouseListener(new java.awt.event.MouseAdapter()
            {

                // handle right click on resource list to show popup
                public void mouseReleased(java.awt.event.MouseEvent e)
                {
                    // check if context popup event
                    if (e.isPopupTrigger())
                    {
                        try
                        {
                            // get the column where click occured as new column may be inserted here
                            int columnClicked = resourceTable.columnAtPoint(new Point(e.getX(), e.getY()));
                            // get the table format information holder
                            EventTableModel eventTableModel = (EventTableModel) resourceTable.getModel();
                            ResourceItemTableFormat tableFormat = (ResourceItemTableFormat) eventTableModel.getTableFormat();
                            tableFormat.showSelectedColumnsPopUp(resourceTable, columnClicked,e.getX(),e.getY());
                        }
                        catch (MDCInternalException exc)
                        {
                            exc.printStackTrace();
                            MDCMessageBox.showInternalError(exc,null);
                        }
                    }
                }
            });

            resourceTable.addMouseListener(new java.awt.event.MouseAdapter()
            {

                // handle right click on resource list to show popup
                public void mouseReleased(java.awt.event.MouseEvent e)
                {
                    // check if context popup event
                    if (e.isPopupTrigger())
                    {
                        // find out row and column affected
                        int rowAffected = resourceTable.rowAtPoint(new Point(e.getX(), e.getY()));
                        //make sure the row/column is automatically selected
                        // that this popup is on
                        resourceTable.addRowSelectionInterval(rowAffected, rowAffected);
                        // show the popup giving it reference to the
                        // resourceList
                        MyLibraryResourceGridPopUpMenu popup = new MyLibraryResourceGridPopUpMenu(resourceTable, resourceTable
                                .getSelectedRows());
                        popup.show(resourceTable, e.getX(), e.getY());
                    }
                    else
                    {
                        super.mouseReleased(e);
                    }
                }
            });
        }
        return resourceTable;
    }

    /**
     * This method initializes the resource grid scroll pane
     * 
     * @return javax.swing.JScrollPane
     * @uml.property name="resourceGridScrollPane"
     */
    private JScrollPane getResourceGridScrollPane()
    {
        if (resourceGridScrollPane == null)
        {
            resourceGridScrollPane = new JScrollPane();
            resourceGridScrollPane.setViewportView(getResourceTable());
        }
        return resourceGridScrollPane;
    }

    /**
     * Sets up the special renders for the grid using ResourceItemTableFormat
     * 
     * @param resourceTable
     */
    private void setupColumns(JTable resourceTable)
    {
        // get the table format information holder
        EventTableModel eventTableModel = (EventTableModel) resourceTable.getModel();
        ResourceItemTableFormat tableFormat = (ResourceItemTableFormat) eventTableModel.getTableFormat();
        // get the column model
        TableColumnModel columnModel = resourceTable.getColumnModel();
        TableColumn column = null;
        // now loop round each column setting it upt
        for (int i = 0; i < columnModel.getColumnCount(); i++)
        {
            column = columnModel.getColumn(i);
            tableFormat.setUpColumn(column, column.getModelIndex());

        }
    }

    /**
     * This method initializes the create list panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="createListPanel"
     */
    private JPanel getCreateListPanel()
    {
        if (createListPanel == null)
        {
            createListPanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            createListPanel.setLayout(flowLayout);
            createListPanel.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            createListPanel.setSize(473, 37);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            createListPanel.add(getNewResourceItemButton(), null);
            createListPanel.add(getCreateListButton(), null);
        }
        return createListPanel;
    }

    /**
     * This method initializes the filter panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="filterPanel"
     */
    private JPanel getFilterPanel()
    {
        if (filterPanel == null)
        {
            filterPanel = new JPanel();
            FlowLayout flowLayout1 = new FlowLayout();
            filterLabel = new JLabel();
            filterPanel.setLayout(flowLayout1);
            filterPanel.setSize(50, 46);
            filterPanel.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            filterLabel.setText("Filter: ");
            filterLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            flowLayout1.setAlignment(java.awt.FlowLayout.RIGHT);
            filterPanel.add(filterLabel, null);
            filterPanel.add(getFilterTextField(), null);
        }
        return filterPanel;
    }

    /**
     * This method initializes the filter text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="filterTextField"
     */
    private JTextField getFilterTextField()
    {
        if (filterTextField == null)
        {
            filterTextField = controller.getResourceItemsFilterTextControl();
            filterTextField.setPreferredSize(new java.awt.Dimension(500, 23));
        }
        return filterTextField;
    }

    /**
     * This method initializes resource grid panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="resourceGridPanel"
     */
    private JPanel getResourceGridPanel()
    {
        if (resourceGridPanel == null)
        {
            resourceGridPanel = new JPanel();
            resourceGridPanel.setLayout(new BorderLayout());
            resourceGridPanel.add(getResourceGridScrollPane(), java.awt.BorderLayout.CENTER);
            resourceGridPanel.add(getFilterPanel(), java.awt.BorderLayout.NORTH);
        }
        return resourceGridPanel;
    }

    /**
     * This method initializes the resource list header panel
     * 
     * @return ResourceListHeaderPanel
     * @uml.property name="myLibraryResourceListHeaderPanel"
     */
    private ResourceListHeaderPanel getMyLibraryResourceListHeaderPanel()
    {
        if (myLibraryResourceListHeaderPanel == null)
        {
            myLibraryResourceListHeaderPanel = new ResourceListHeaderPanel(controller);
        }
        return myLibraryResourceListHeaderPanel;
    }

    /**
     * This method initializes the new resource button
     * 
     * @return javax.swing.JButton
     * @uml.property name="newResourceItemButton"
     */
    private JButton getNewResourceItemButton()
    {
        if (newResourceItemButton == null)
        {
            newResourceItemButton = new JButton();
            newResourceItemButton.setText("Add Resources...");
            newResourceItemButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.createResourceItems();
                }
            });
        }
        return newResourceItemButton;
    }

    /**
     * This method initializes the create list button
     * 
     * @return javax.swing.JButton
     * @uml.property name="createListButton"
     */
    private JButton getCreateListButton()
    {
        if (createListButton == null)
        {
            createListButton = new JButton();
            createListButton.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            createListButton.setText("Create List...");
            createListButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.createList();
                }
            });
        }
        return createListButton;
    }

} //  @jve:decl-index=0:visual-constraint="10,10"
