/*
 * MDC Desktop Client Created on 20-Apr-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Point;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import org.mdcog.client.desktop.gui.controllers.LibraryTabController;
import org.mdcog.client.desktop.gui.images.MDCFonts;
import org.mdcog.client.desktop.gui.menus.MyLibaryResourceListPopUpMenu;
import org.mdcog.client.desktop.gui.models.MDCModelUpdateListener;
import org.mdcog.client.desktop.gui.models.MyLibraryResourceItemTransferInHandler;
import org.mdcog.client.desktop.gui.table.editors.ResourceListEntryEditor;
import org.mdcog.client.desktop.gui.table.renderers.ResourceListEntryRenderer;
import org.mdcog.client.desktop.model.ResourceList;

/**
 * This class implements the My Library resource list panel <br/><br/>Note - It
 * was partially created using the Eclipse Visual Editor plugin
 */
public class MyLibraryResourceListsPanel extends JPanel implements MDCModelUpdateListener
{

    /**
     * Stores a reference to the controller for the panel
     * 
     */
    private LibraryTabController controller = null;


    /**
     * Stores a reference to the resource list table
     */
    private JTable resourceList = null;

    /**
     * Stores a reference to the resource list scroll pane
     */
    private JScrollPane resourceListScrollPane = null;

    /**
     * Stores a reference to the new resource panel
     */
    private JPanel newResourcePanel = null;

    /**
     * Stores a reference to the new resource list button
     */
    private JButton newResourceList = null;

    /**
     * Stores a reference to the header panel
     */
    private JPanel headerPanel = null;

    /**
     * Stores a reference to the resource list titled
     */
    private JLabel resourceListTitle = null;

    /**
     * This is the default constructor
     */
    public MyLibraryResourceListsPanel()
    {
        super();
        initialize();
    }

    /**
     * This method initializes this panel
     */
    private void initialize()
    {
        // get a reference to the controller
        controller = LibraryTabController.getInstance();
        controller.registerModelUpdateListener(this);
        this.setLayout(new BorderLayout());
        this.setSize(222, 583);
        this.setBorder(new javax.swing.border.SoftBevelBorder(javax.swing.border.SoftBevelBorder.LOWERED));
        this.add(getHeaderPanel(), java.awt.BorderLayout.NORTH);
        this.add(getResourceListScrollPane(), java.awt.BorderLayout.CENTER);
        // impoertnat this is done last as it needs to pass the table into
        this.add(getNewResourcePanel(), java.awt.BorderLayout.SOUTH);
    }

    /**
     * Called when the model has been updated
     */

    public void modelUpdated()
    {
        // if the currently selected row in controller is not the same as on the
        // screen reselect to that row
        if (getResourceList().getSelectedRow() != controller.getCurrentlySelectedResourceListRow())
        {
            getResourceList().setRowSelectionInterval(controller.getCurrentlySelectedResourceListRow(),
                    controller.getCurrentlySelectedResourceListRow());
            getResourceList().setColumnSelectionInterval(0, 0);
        }
    }

    /**
     * This method initializes the resource list table
     * 
     * @return javax.swing.JTable
     * 
     * @uml.property name="resourceList"
     */
    private JTable getResourceList() {
        if (resourceList == null) {
            resourceList = new JTable(controller.getResourceListTableModel());
            resourceList.setRowHeight(50);
            resourceList.setTableHeader(null);
            resourceList.setShowGrid(false);
            resourceList.setCellSelectionEnabled(true);
            resourceList.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
            // ensure all resource items is auto selected
            resourceList.setRowSelectionInterval(0, 0);
            resourceList.setColumnSelectionInterval(0, 0);
            resourceList.addMouseListener(new java.awt.event.MouseAdapter() {

                // handle right click on resource list to show popup
                public void mouseReleased(java.awt.event.MouseEvent e) {
                    // check if context popup event
                    if (e.isPopupTrigger()) {
                        // find out row and column affected
                        int rowAffected = resourceList.rowAtPoint(new Point(e.getX(), e.getY()));
                        int columnAffected = resourceList.columnAtPoint(new Point(e.getX(), e.getY()));
                        // see if that cell an be edited
                        boolean editable = resourceList.getModel().isCellEditable(rowAffected, columnAffected);
                        //make sure the row/column is automatically selected
                        // that this popup is on
                        resourceList.setRowSelectionInterval(rowAffected, rowAffected);
                        resourceList.setColumnSelectionInterval(columnAffected, columnAffected);
                        // show the popup giving it reference to the
                        // resourceList
                        MyLibaryResourceListPopUpMenu popup = new MyLibaryResourceListPopUpMenu(
                            resourceList,
                            rowAffected,
                            columnAffected,
                            editable);
                        popup.show(resourceList, e.getX(), e.getY());
                    } else {
                        super.mouseReleased(e);
                    }
                }
            });
            resourceList.setDefaultRenderer(ResourceList.class, new ResourceListEntryRenderer());
            resourceList.setDefaultEditor(ResourceList.class, new ResourceListEntryEditor());
            resourceList.setDragEnabled(true);
            resourceList.setTransferHandler(new MyLibraryResourceItemTransferInHandler());
            // deal with what happens when a row is slected
            ListSelectionModel rowSM = resourceList.getSelectionModel();
            rowSM.addListSelectionListener(new ListSelectionListener() {

                public void valueChanged(ListSelectionEvent e) {
                    //Ignore extra messages.
                    if (e.getValueIsAdjusting()) {
                        return;
                    }

                    // detect the row that was selected
                    ListSelectionModel lsm = (ListSelectionModel) e.getSource();
                    if (!lsm.isSelectionEmpty()) {
                        controller.selectedNewResourceListInMyLibary(lsm.getMinSelectionIndex());
                    }
                }
            });
            // TODO Sort out Horizontal scrolling on resource list enable line
            // below and switch on scroll bar
            // resourceList.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        }
        return resourceList;
    }

    /**
     * This method initializes the resource list scroll pane
     * 
     * @return javax.swing.JScrollPane
     * 
     * @uml.property name="resourceListScrollPane"
     */
    private JScrollPane getResourceListScrollPane() {
        if (resourceListScrollPane == null) {
            resourceListScrollPane = new JScrollPane();
            resourceListScrollPane.setViewportView(getResourceList());
            //resourceListScrollPane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);

        }
        return resourceListScrollPane;
    }

    /**
     * This method initializes the new resource panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="newResourcePanel"
     */
    private JPanel getNewResourcePanel() {
        if (newResourcePanel == null) {
            newResourcePanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            newResourcePanel.setLayout(flowLayout);
            newResourcePanel.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            newResourcePanel.setSize(206, 47);
            newResourcePanel.add(getNewResourceList(), null);
        }
        return newResourcePanel;
    }

    /**
     * This method initializes the new resource button
     * 
     * @return javax.swing.JButton
     * 
     * @uml.property name="newResourceList"
     */
    private JButton getNewResourceList() {
        if (newResourceList == null) {
            newResourceList = new JButton();
            newResourceList.setText("New List");
            newResourceList.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            newResourceList.addActionListener(new java.awt.event.ActionListener() {

                public void actionPerformed(java.awt.event.ActionEvent e) {
                    int row = controller.addNewResourceListToMyLibary();
                    resourceList.setRowSelectionInterval(row, row);

                }
            });
        }
        return newResourceList;
    }

    /**
     * This method initializes header panel
     * 
     * @return javax.swing.JPanel
     * 
     * @uml.property name="headerPanel"
     */
    private JPanel getHeaderPanel() {
        if (headerPanel == null) {
            headerPanel = new JPanel();
            headerPanel.setLayout(new BorderLayout());
            headerPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(10, 5, 10, 5));
            resourceListTitle = new JLabel();
            resourceListTitle.setText("Resource Lists");
            resourceListTitle.setPreferredSize(new java.awt.Dimension(86, 30));
            resourceListTitle.setFont(MDCFonts.HEADER_FONT);
            resourceListTitle.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
            resourceListTitle.setHorizontalAlignment(javax.swing.SwingConstants.LEADING);
            headerPanel.add(resourceListTitle);
        }
        return headerPanel;
    }

} //  @jve:decl-index=0:visual-constraint="192,33"
