/*
 * MDC Desktop Client Created on 06-May-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import org.mdcog.client.desktop.gui.controllers.Controller;
import org.mdcog.client.desktop.gui.controllers.ResourceListHeaderControllerInterface;
import org.mdcog.client.desktop.gui.images.MDCFonts;
import org.mdcog.client.desktop.gui.images.MDCIcons;
import org.mdcog.client.desktop.gui.models.MDCModelUpdateListener;

/**
 * This class implements the resource list header panel. This panel is generic
 * and used in more than one place (LibraryTab and CreateList dialog) <br/>
 * <br/>Note - It was partially created using the Eclipse Visual Editor plugin
 * 
 * @uml.dependency supplier="org.mdcog.client.desktop.gui.controllers.ResourceListHeaderControllerInterface" stereotypes="Basic::Call"
 */

public class ResourceListHeaderPanel extends JPanel implements MDCModelUpdateListener
{

    /**
     * Stores a reference to the controller for this panel. The controller has
     * to implement the ResourceListHeaderControllerInterface
     */
    private ResourceListHeaderControllerInterface controller = null;

    /**
     * Stores a reference to the labels panel
     */
    private JPanel labelsPanel = null;

    /**
     * Stores a reference to the fields panel
     */
    private JPanel fieldsPanel = null;

    /**
     * Stores a reference to the author label
     */
    private JLabel authorLabel = null;

    /**
     * Stores a reference to the owner label
     */
    private JLabel ownerLabel = null;

    /**
     * Stores a reference to the header label
     */
    private JLabel headerLabel = null;

    /**
     * Stores a reference to the title label
     */
    private JLabel titleLabel = null;

    /**
     * Stores a reference to the author field
     */
    private JTextField authorField = null;

    /**
     * Stores a reference to the owner field
     */
    private JTextField ownerField = null;

    /**
     * Stores a reference to the owener panel
     */
    private JPanel ownerPanel = null;

    /**
     * Stores a reference to the author panel
     */
    private JPanel authorPanel = null;

    /**
     * Stores a reference to the title panel
     */
    private JPanel titlePanel = null;

    /**
     * Stores a reference to the title field
     */
    private JTextField titleField = null;

    /**
     * Stores a reference to the header panel
     */
    private JPanel headerPanel = null;

    /**
     * Stores a reference to the annotation button
     */
    private JButton annotationButton = null;

    /**
     * Stores a reference to the date created label
     */
    private JLabel dateCreatedLabel = null;

    /**
     * Stores a reference to the date created panel
     */
    private JPanel dateCreatedPanel = null;

    /**
     * Stores a reference to the date created text field
     */
    private JTextField dateCreatedField = null;

    /**
     * This is the default constructor
     * 
     * @param controller the controller for this panel. The controller has to
     *        implement the ResourceListHeaderControllerInterface
     */
    public ResourceListHeaderPanel(ResourceListHeaderControllerInterface controller)
    {
        super();
        this.controller = controller;
        // register for model updates
        ((Controller) controller).registerModelUpdateListener(this);
        initialize();
        // now we are set up fill in any fields
        modelUpdated();
    }

    /**
     * called when the model has been updated by the controller
     */
    public void modelUpdated()
    {
        // update the header fields
        getOwnerField().setText(controller.getResourceListOwner());
        getAuthorField().setText(controller.getResourceListAuthor());
        getTitleField().setText(controller.getResourceListTitle());
        getDateCreatedField().setText(controller.getResourceListCreationDate());
    }

    /**
     * This method initializes this panel
     * 
     * @return void
     */
    private void initialize()
    {
        this.setLayout(new BorderLayout());
        this.setSize(846, 143);
        this.setBorder(javax.swing.BorderFactory.createEtchedBorder(javax.swing.border.EtchedBorder.LOWERED));
        this.add(getLabelsPanel(), java.awt.BorderLayout.WEST);
        this.add(getFieldsPanel(), java.awt.BorderLayout.CENTER);
        this.add(getHeaderPanel(), java.awt.BorderLayout.NORTH);
    }

    /**
     * This method initializes the labels panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="labelsPanel"
     */
    private JPanel getLabelsPanel()
    {
        if (labelsPanel == null)
        {
            dateCreatedLabel = new JLabel();
            labelsPanel = new JPanel();
            ownerLabel = new JLabel();
            authorLabel = new JLabel();
            titleLabel = new JLabel();
            GridLayout gridLayout = new GridLayout();
            labelsPanel.setLayout(gridLayout);
            gridLayout.setRows(4);
            gridLayout.setColumns(1);
            gridLayout.setVgap(5);
            authorLabel.setText("Author");
            ownerLabel.setText("Owner");
            dateCreatedLabel.setText("Date created");
            titleLabel.setText("Title");
            authorLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            ownerLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            dateCreatedLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            titleLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            labelsPanel.add(authorLabel, null);
            labelsPanel.add(ownerLabel, null);
            labelsPanel.add(dateCreatedLabel, null);
            labelsPanel.add(titleLabel, null);

        }
        return labelsPanel;
    }

    /**
     * This method initializes the fields panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="fieldsPanel"
     */
    private JPanel getFieldsPanel()
    {
        if (fieldsPanel == null)
        {
            fieldsPanel = new JPanel();
            GridLayout gridLayout = new GridLayout();
            fieldsPanel.setLayout(gridLayout);
            gridLayout.setRows(4);
            gridLayout.setColumns(2);
            gridLayout.setVgap(5);
            gridLayout.setHgap(10);
            fieldsPanel.add(getAuthorPanel(), null);
            fieldsPanel.add(getOwnerPanel(), null);
            fieldsPanel.add(getDateCreatedPanel(), null);
            fieldsPanel.add(getTitlePanel(), null);

        }
        return fieldsPanel;
    }

    /**
     * This method initializes the author text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="authorField"
     */
    private JTextField getAuthorField()
    {
        if (authorField == null)
        {
            authorField = new JTextField();
            authorField.setColumns(25);
            authorField.addFocusListener(new java.awt.event.FocusAdapter()
            {

                public void focusLost(java.awt.event.FocusEvent e)
                {

                    controller.setResourceListAuthor(authorField.getText());

                }
            });
        }
        return authorField;
    }

    /**
     * This method initializes the owner text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="ownerField"
     */
    private JTextField getOwnerField()
    {
        if (ownerField == null)
        {
            ownerField = new JTextField();
            ownerField.setColumns(25);
            ownerField.addFocusListener(new java.awt.event.FocusAdapter()
            {

                public void focusLost(java.awt.event.FocusEvent e)
                {

                    controller.setResourceListOwner(ownerField.getText());

                }
            });
        }
        return ownerField;
    }

    /**
     * This method initializes the owner panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="ownerPanel"
     */
    private JPanel getOwnerPanel()
    {
        if (ownerPanel == null)
        {
            ownerPanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            ownerPanel.setLayout(flowLayout);
            ownerPanel.add(getOwnerField(), null);
        }
        return ownerPanel;
    }

    /**
     * This method initializes the author panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="authorPanel"
     */
    private JPanel getAuthorPanel()
    {
        if (authorPanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            authorPanel = new JPanel();
            authorPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            authorPanel.add(getAuthorField(), null);
        }
        return authorPanel;
    }

    /**
     * This method initializes the titleField panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="titlePanel"
     */
    private JPanel getTitlePanel()
    {
        if (titlePanel == null)
        {
            FlowLayout flowLayout9 = new FlowLayout();
            titlePanel = new JPanel();
            titlePanel.setLayout(flowLayout9);
            flowLayout9.setAlignment(java.awt.FlowLayout.LEFT);
            titlePanel.add(getTitleField(), null);
            titlePanel.add(getAnnotationButton(), null);
        }
        return titlePanel;
    }

    /**
     * This method initializes the titleField field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="titleField"
     */
    private JTextField getTitleField()
    {
        if (titleField == null)
        {
            titleField = new JTextField();
            titleField.setColumns(50);
            titleField.addFocusListener(new java.awt.event.FocusAdapter()
            {

                public void focusLost(java.awt.event.FocusEvent e)
                {

                    controller.setResourceListTitle(titleField.getText());

                }
            });
        }
        return titleField;
    }

    /**
     * This method initializes the header panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="headerPanel"
     */
    private JPanel getHeaderPanel()
    {
        if (headerPanel == null)
        {
            headerPanel = new JPanel();
            headerLabel = new JLabel();
            headerPanel.setLayout(new BorderLayout());
            headerPanel.setSize(811, 45);
            headerPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(10, 5, 10, 5));
            headerLabel.setText("List Header");
            headerLabel.setFont(MDCFonts.HEADER_FONT);
            headerLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
            headerPanel.add(headerLabel, java.awt.BorderLayout.WEST);
        }
        return headerPanel;
    }

    /**
     * This method initializes the annotation button
     * 
     * @return javax.swing.JButton
     * @uml.property name="annotationButton"
     */
    private JButton getAnnotationButton()
    {
        if (annotationButton == null)
        {
            annotationButton = new JButton();
            annotationButton.setText("Annotation...");
            annotationButton.setIcon(MDCIcons.ANNOTATION_ICON);
            annotationButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.openResourceListAnnotation();
                }
            });
        }
        return annotationButton;
    }

    /**
     * This method initializes the date created panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="dateCreatedPanel"
     */
    private JPanel getDateCreatedPanel()
    {
        if (dateCreatedPanel == null)
        {
            dateCreatedPanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            dateCreatedPanel.setLayout(flowLayout);
            dateCreatedPanel.add(getDateCreatedField(), null);
        }
        return dateCreatedPanel;
    }

    /**
     * This method initializes the date created field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="dateCreatedField"
     */
    private JTextField getDateCreatedField()
    {
        if (dateCreatedField == null)
        {
            dateCreatedField = new JTextField();
            dateCreatedField.setColumns(12);
            dateCreatedField.setEditable(false);
        }
        return dateCreatedField;
    }

} //  @jve:decl-index=0:visual-constraint="10,10"
