/*
 * MDC Desktop Client Created on 02-May-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;

import org.mdcog.client.desktop.gui.controllers.SearchTabController;
import org.mdcog.client.desktop.gui.images.MDCFonts;
/**
 * This class implements the search criteria panel <br/><br/>Note - It was
 * partially created using the Eclipse Visual Editor plugin
 */
public class SearchCriteriaPanel extends JPanel
{

    /**
     * Stores a reference to the controller for the panel
     */
    private SearchTabController controller = null;

    /**
     * Stores a reference to the header panel
     */
    private JPanel headerPanel = null;

    /**
     * Stores a reference to the search label
     */
    private JLabel searchLabel = null;

    /**
     * Stores a reference to the options panel
     */
    private JPanel optionsPanel = null;

    /**
     * Stores a reference to the options button group
     */
    private ButtonGroup optionsButtonGroup = null;

    /**
     * Stores a reference to the book radio button
     */
    private JRadioButton bookRadio = null;

    /**
     * Stores a reference to the author radio button
     */
    private JRadioButton authorRadio = null;

    /**
     * Stores a reference to the assessment radio button
     */
    private JRadioButton assessmentRadio = null;

    /**
     * Stores a reference to the journal radio button
     */
    private JRadioButton journalRadio = null;

    /**
     * Stores a reference to the image radio button
     */
    private JRadioButton imageRadio = null;

    /**
     * Stores a reference to the video radio button
     */
    private JRadioButton videoRadio = null;

    /**
     * Stores a reference to the keyword only radio button
     */
    private JRadioButton keywordRadio = null;

    /**
     * Stores a reference to the serach text panel
     */
    private JPanel searchTextPanel = null;

    /**
     * Stores a reference to the serach text field
     */
    private JTextField searchText = null;

    /**
     * Stores a reference to the search button
     */
    private JButton searchButton = null;

    /**
     * Stores a reference to the search panel
     */
    private JPanel searchPanel = null;

    /**
     * Stores a reference to the import list button
     */
    private JButton importListButton = null;

    /**
     * Stores a reference to the search control layout panel
     */
    private JPanel searchControlLayoutPanel = null;

    /**
     * This is the default constructor
     */
    public SearchCriteriaPanel()
    {
        super();
        initialize();
    }

    /**
     * This method initializes this panel
     */
    private void initialize()
    {
        controller = SearchTabController.getInstance();
        this.setLayout(new BorderLayout());
        this.setSize(996, 80);
        this.setBorder(new javax.swing.border.SoftBevelBorder(javax.swing.border.SoftBevelBorder.LOWERED));
        this.add(getSearchPanel(), java.awt.BorderLayout.CENTER);
        this.add(getHeaderPanel(), java.awt.BorderLayout.WEST);
    }

    /**
     * This method initializes the search panel
     * 
     * @return javax.swing.JPanel
     */
    private JPanel getSearchPanel()
    {
        if (searchPanel == null)
        {
            searchPanel = new JPanel();
            searchPanel.setLayout(new FlowLayout());
            searchPanel.add(getSearchControlLayoutPanel(), null);
        }
        return searchPanel;
    }

    /**
     * This method initializes the header panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="headerPanel"
     */
    private JPanel getHeaderPanel()
    {
        if (headerPanel == null)
        {
            headerPanel = new JPanel();
            headerPanel.setSize(800, 64);
            searchLabel = new JLabel();
            headerPanel.setLayout(new BorderLayout());
            headerPanel.setSize(632, 48);
            headerPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(5, 5, 10, 5));
            headerPanel.add(searchLabel, java.awt.BorderLayout.NORTH);
            searchLabel.setText("Search");
            searchLabel.setFont(MDCFonts.HEADER_FONT);
            searchLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        }
        return headerPanel;
    }

    /**
     * This method initializes the options panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="optionsPanel"
     */
    private JPanel getOptionsPanel()
    {
        if (optionsPanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            optionsPanel = new JPanel();
            optionsPanel.setLayout(flowLayout);
            optionsPanel.setSize(652, 108);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            optionsPanel.add(getKeywordRadio(), null);
            optionsPanel.add(getAuthorRadio(), null);
            optionsPanel.add(getBookRadio(), null);
            optionsPanel.add(getJournalRadio(), null);
            optionsPanel.add(getAssessmentRadio(), null);
            optionsPanel.add(getImageRadio(), null);
            optionsPanel.add(getVideoRadio(), null);
            optionsButtonGroup = new ButtonGroup();
            controller.setSearchOptionsButtonGroup(optionsButtonGroup);
            optionsButtonGroup.add(assessmentRadio);
            optionsButtonGroup.add(journalRadio);
            optionsButtonGroup.add(imageRadio);
            optionsButtonGroup.add(videoRadio);
            optionsButtonGroup.add(bookRadio);
            optionsButtonGroup.add(keywordRadio);
            optionsButtonGroup.add(authorRadio);
        }
        return optionsPanel;
    }

    /**
     * This method initializes the book radio button
     * 
     * @return javax.swing.JRadioButton
     * @uml.property name="bookRadio"
     */
    private JRadioButton getBookRadio()
    {
        if (bookRadio == null)
        {
            bookRadio = new JRadioButton();
            bookRadio.setText("Book");
            bookRadio.setActionCommand(SearchTabController.SEARCH_BOOK);
        }
        return bookRadio;
    }

    /**
     * This method initializes the assessment radio button
     * 
     * @return javax.swing.JRadioButton
     */
    private JRadioButton getAssessmentRadio()
    {
        if (assessmentRadio == null)
        {
            assessmentRadio = new JRadioButton();
            assessmentRadio.setText("Assessment question");
            assessmentRadio.setActionCommand(SearchTabController.SEARCH_ASSESSMENT);
        }
        return assessmentRadio;
    }

    /**
     * This method initializes the book radio button
     * 
     * @return javax.swing.JRadioButton
     * @uml.property name="authorRadio"
     */
    private JRadioButton getAuthorRadio()
    {
        if (authorRadio == null)
        {
            authorRadio = new JRadioButton();
            authorRadio.setText("Author");
            authorRadio.setActionCommand(SearchTabController.SEARCH_AUTHOR);
        }
        return authorRadio;
    }

    /**
     * This method initializes the journal radio button
     * 
     * @return javax.swing.JRadioButton
     * @uml.property name="journalRadio"
     */
    private JRadioButton getJournalRadio()
    {
        if (journalRadio == null)
        {
            journalRadio = new JRadioButton();
            journalRadio.setText("Journal article");
            journalRadio.setActionCommand(SearchTabController.SEARCH_JOURNAL);
        }
        return journalRadio;
    }

    /**
     * This method initializes the image radio button
     * 
     * @return javax.swing.JRadioButton
     * @uml.property name="imageRadio"
     */
    private JRadioButton getImageRadio()
    {
        if (imageRadio == null)
        {
            imageRadio = new JRadioButton();
            imageRadio.setText("Image");
            imageRadio.setActionCommand(SearchTabController.SEARCH_IMAGE);
        }
        return imageRadio;
    }

    /**
     * This method initializes the video radio button
     * 
     * @return javax.swing.JRadioButton
     * @uml.property name="videoRadio"
     */
    private JRadioButton getVideoRadio()
    {
        if (videoRadio == null)
        {
            videoRadio = new JRadioButton();
            videoRadio.setText("Video");
            videoRadio.setActionCommand(SearchTabController.SEARCH_VIDEO);
        }
        return videoRadio;
    }

    /**
     * This method initializes the keywordOnlyRadio only radio button
     * 
     * @return javax.swing.JRadioButton
     * @uml.property name="keywordOnlyRadio"
     */
    private JRadioButton getKeywordRadio()
    {
        if (keywordRadio == null)
        {
            keywordRadio = new JRadioButton();
            keywordRadio.setText("Keyword");
            keywordRadio.setActionCommand(SearchTabController.SEARCH_KEYWORD);
            keywordRadio.setSelected(true);
        }
        return keywordRadio;
    }

    /**
     * This method initializes the search text panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="searchTextPanel"
     */
    private JPanel getSearchTextPanel()
    {
        if (searchTextPanel == null)
        {
            FlowLayout flowLayout = new FlowLayout();
            searchTextPanel = new JPanel();
            searchTextPanel.setSize(664, 43);
            searchTextPanel.setLayout(flowLayout);
            flowLayout.setAlignment(java.awt.FlowLayout.LEFT);
            searchTextPanel.add(getSearchText(), null);
            searchTextPanel.add(getSearchButton(), null);
            searchTextPanel.add(getImportListButton());
        }
        return searchTextPanel;
    }

    /**
     * This method initializes the serach text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="searchText"
     */
    private JTextField getSearchText()
    {
        if (searchText == null)
        {
            searchText = new JTextField();
            searchText.setColumns(50);
            searchText.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            searchText.setHorizontalAlignment(javax.swing.JTextField.LEFT);
            searchText.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.newSearch(searchText.getText());
                    searchText.setText("");
                }
            });
        }
        return searchText;
    }

    /**
     * This method initializes the search button
     * 
     * @return javax.swing.JButton
     * @uml.property name="searchButton"
     */
    private JButton getSearchButton()
    {
        if (searchButton == null)
        {
            searchButton = new JButton();
            searchButton.setText("Search");
            searchButton.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            searchButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.newSearch(searchText.getText());
                    searchText.setText("");
                }
            });
        }
        return searchButton;
    }

    /**
     * This method initializes import list button
     * 
     * @return javax.swing.JButton
     * @uml.property name="importResourcesButton"
     */
    private JButton getImportListButton()
    {
        if (importListButton == null)
        {
            importListButton = new JButton();
            importListButton.setText("Import List...");
            importListButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.importResults();
                }
            });
        }
        return importListButton;
    }

    /**
     * This method initializes serach control layout
     * 
     * @return javax.swing.JPanel
     */
    private JPanel getSearchControlLayoutPanel()
    {
        if (searchControlLayoutPanel == null)
        {
            searchControlLayoutPanel = new JPanel();
            searchControlLayoutPanel.setLayout(new BorderLayout());
            searchControlLayoutPanel.add(getSearchTextPanel(), java.awt.BorderLayout.NORTH);
            searchControlLayoutPanel.add(getOptionsPanel(), java.awt.BorderLayout.CENTER);
        }
        return searchControlLayoutPanel;
    }
	
	
 } //  @jve:decl-index=0:visual-constraint="9,10"
