/*
 * MDC Desktop Client Created on 03-May-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Point;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

import org.mdcog.client.desktop.gui.controllers.SearchTabController;
import org.mdcog.client.desktop.gui.error.MDCInternalException;
import org.mdcog.client.desktop.gui.error.MDCMessageBox;
import org.mdcog.client.desktop.gui.images.MDCFonts;
import org.mdcog.client.desktop.gui.menus.SearchMyListResourceGridPopUpMenu;
import org.mdcog.client.desktop.gui.models.ResourceItemButtonMouseListener;
import org.mdcog.client.desktop.gui.models.ResourceItemTableFormat;
import org.mdcog.client.desktop.gui.models.SearchMyListResourceItemTransferInHandler;

import ca.odell.glazedlists.swing.EventTableModel;
import ca.odell.glazedlists.swing.TableComparatorChooser;

/**
 * This class implements the search my list grid panel <br/><br/>Note - It was
 * partially created using the Eclipse Visual Editor plugin
 */
public class SearchMyListGridPanel extends JPanel
{

    /**
     * Stores a reference to the my list table
     */
    private JTable myListTable = null;

    /**
     * Stores a reference to the my list scroll pane
     */
    private JScrollPane myListScrollPane = null;

    /**
     * Stores a reference to the controller for the panel
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private SearchTabController controller = null;

    /**
     * Stores a reference to the buttons panel
     */
    private JPanel buttonsPanel = null;

    /**
     * Stores a reference to the save library button
     */
    private JButton saveLibraryButton = null;

    /**
     * Stores a reference to the create list button
     */
    private JButton createListButton = null;

    /**
     * Stores a reference to the filter panel
     */
    private JPanel filterPanel = null;

    /**
     * Stores a reference to the filter label
     */
    private JLabel filterLabel = null;

    /**
     * Stores a reference to the filter text
     */
    private JTextField filterTextField = null;

    /**
     * Stores a reference to the add resource button
     */
    private JButton addResourcesButton = null;

    /**
     * Stores a reference to the header panel
     */
    private JPanel headerPanel = null;

    /**
     * Stores a reference to the header label
     */
    private JLabel myListHeaderLabel = null;

    /**
     * Stores a reference to the my list header panel
     */
    private JPanel myListPanel = null;

    /**
     * This is the default constructor
     */
    public SearchMyListGridPanel()
    {
        super();
        initialize();
    }

    /**
     * This method initializes this panel
     */
    private void initialize()
    {
        controller = SearchTabController.getInstance();
        this.setBorder(new javax.swing.border.SoftBevelBorder(javax.swing.border.SoftBevelBorder.LOWERED));
        this.setSize(1133, 272);
        this.setLayout(new BorderLayout());
        this.add(getMyListScrollPane(), java.awt.BorderLayout.CENTER);
        this.add(getMyListPanel(), java.awt.BorderLayout.NORTH);
        this.add(getButtonsPanel(), java.awt.BorderLayout.SOUTH);
    }

    /**
     * This method initializes the my list panel
     * 
     * @return javax.swing.JTable
     * @uml.property name="myListTable"
     */
    public JTable getMyListTable()
    {
        if (myListTable == null)
        {
            myListTable = new JTable(controller.getMyListResourceTableModel());
            myListTable.setAutoCreateColumnsFromModel(true);
            new TableComparatorChooser(myListTable, controller.getMyListSortedResourceItems(), false);
            myListTable.setSelectionMode(javax.swing.ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
            // set up special renders
            myListTable.setRowHeight(ResourceItemTableFormat.ROW_HEIGHT);
            myListTable.setAutoResizeMode(javax.swing.JTable.AUTO_RESIZE_NEXT_COLUMN);
            myListTable.setRowSelectionAllowed(true);
            myListTable.setDragEnabled(true);
            myListTable.setTransferHandler(new SearchMyListResourceItemTransferInHandler());
            myListTable.addMouseListener(new ResourceItemButtonMouseListener(myListTable));
            myListTable.getTableHeader().addMouseListener(new java.awt.event.MouseAdapter()
            {

                // handle right click on resource list to show popup
                public void mouseReleased(java.awt.event.MouseEvent e)
                {
                    // check if context popup event
                    if (e.isPopupTrigger())
                    {
                        try
                        {
                            // get the column where click occured as new column
                            // may be inserted here
                            int columnClicked = myListTable.columnAtPoint(new Point(e.getX(), e.getY()));
                            // get the table format information holder
                            EventTableModel eventTableModel = (EventTableModel) myListTable.getModel();
                            ResourceItemTableFormat tableFormat = (ResourceItemTableFormat) eventTableModel.getTableFormat();
                            tableFormat.showSelectedColumnsPopUp(myListTable, columnClicked, e.getX(), e.getY());
                        }
                        catch (MDCInternalException exc)
                        {
                            exc.printStackTrace();
                            MDCMessageBox.showInternalError(exc, null);
                        }
                    }
                }
            });
            myListTable.addMouseListener(new java.awt.event.MouseAdapter()
            {

                // handle right click on resource list to show popup
                public void mouseReleased(java.awt.event.MouseEvent e)
                {
                    // check if context popup event
                    if (e.isPopupTrigger())
                    {
                        // find out row and column affected
                        int rowAffected = myListTable.rowAtPoint(new Point(e.getX(), e.getY()));
                        //make sure the row/column is automatically selected
                        // that this popup is on
                        myListTable.addRowSelectionInterval(rowAffected, rowAffected);
                        // show the popup giving it reference to the
                        // resourceList
                        SearchMyListResourceGridPopUpMenu popup = new SearchMyListResourceGridPopUpMenu(myListTable
                                .getSelectedRows());
                        popup.show(myListTable, e.getX(), e.getY());
                    }
                    else
                    {
                        super.mouseReleased(e);
                    }
                }
            });
            setupColumns(myListTable);
        }
        return myListTable;
    }

    /**
     * This method initializes my list scroll pane
     * 
     * @return javax.swing.JScrollPane
     * @uml.property name="myListScrollPane"
     */
    private JScrollPane getMyListScrollPane()
    {
        if (myListScrollPane == null)
        {
            myListScrollPane = new JScrollPane();
            myListScrollPane.setViewportView(getMyListTable());
            // make the scroll pannel the grid is in also accept the drag fro
            // the table
            myListScrollPane.setTransferHandler(new SearchMyListResourceItemTransferInHandler());

        }
        return myListScrollPane;
    }

    /**
     * Sets up the special renders for the grid using ResourceItemTableFormat
     * 
     * @param resourceTable
     */
    private void setupColumns(JTable resourceTable)
    {
        // get the table format information holder
        EventTableModel eventTableModel = (EventTableModel) resourceTable.getModel();
        ResourceItemTableFormat tableFormat = (ResourceItemTableFormat) eventTableModel.getTableFormat();
        // get the column model
        TableColumnModel columnModel = resourceTable.getColumnModel();
        TableColumn column = null;
        // now loop round each column setting it upt
        for (int i = 0; i < columnModel.getColumnCount(); i++)
        {
            column = columnModel.getColumn(i);
            tableFormat.setUpColumn(column, column.getModelIndex());

        }
    }

    /**
     * This method initializes the buttons panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="buttonsPanel"
     */
    private JPanel getButtonsPanel()
    {
        if (buttonsPanel == null)
        {
            buttonsPanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            buttonsPanel.setLayout(flowLayout);
            buttonsPanel.setSize(279, 58);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            buttonsPanel.add(getSaveLibraryButton(), null);
            buttonsPanel.add(getAddResourcesButton(), null);
            buttonsPanel.add(getCreateListButton(), null);
        }
        return buttonsPanel;
    }

    /**
     * This method initializes the save library button
     * 
     * @return javax.swing.JButton
     * @uml.property name="saveLibraryButton"
     */
    private JButton getSaveLibraryButton()
    {
        if (saveLibraryButton == null)
        {
            saveLibraryButton = new JButton();
            saveLibraryButton.setText("Save to My Library");
            saveLibraryButton.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            saveLibraryButton.addActionListener(new java.awt.event.ActionListener()
            {

                /**
                 * Called to save resources to all resources list
                 */
                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    // save the selected rows to my library all resource
                    controller.saveToMyLibrary(myListTable.getSelectedRows());
                }
            });
        }
        return saveLibraryButton;
    }

    /**
     * This method initializes the create list button
     * 
     * @return javax.swing.JButton
     * @uml.property name="createListButton"
     */
    private JButton getCreateListButton()
    {
        if (createListButton == null)
        {
            createListButton = new JButton();
            createListButton.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            createListButton.setText("Create List...");
            createListButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.createList();
                }
            });
        }
        return createListButton;
    }

    /**
     * This method initializes the filter panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="filterPanel"
     */
    private JPanel getFilterPanel()
    {
        if (filterPanel == null)
        {
            filterPanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            filterLabel = new JLabel();
            filterPanel.setLayout(flowLayout);
            filterPanel.setSize(50, 46);
            filterPanel.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            filterLabel.setText("Filter: ");
            filterLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            filterPanel.add(filterLabel, null);
            filterPanel.add(getFilterTextField(), null);

        }
        return filterPanel;
    }

    /**
     * This method initializes the filter text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="filterTextField"
     */
    private JTextField getFilterTextField()
    {
        if (filterTextField == null)
        {
            filterTextField = controller.getMyListResourceItemsFilterTextControl();
            filterTextField.setPreferredSize(new java.awt.Dimension(500, 23));
        }
        return filterTextField;
    }

    /**
     * This method initializes the add resource button
     * 
     * @return javax.swing.JButton
     * @uml.property name="addResourcesButton"
     */
    private JButton getAddResourcesButton()
    {
        if (addResourcesButton == null)
        {
            addResourcesButton = new JButton();
            addResourcesButton.setText("Add Resources...");
            addResourcesButton.addActionListener(new java.awt.event.ActionListener()
            {

                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.createResourceItems();
                }
            });
        }
        return addResourcesButton;
    }

    /**
     * This method initializes jPanel
     * 
     * @return javax.swing.JPanel
     */
    private JPanel getMyListPanel()
    {
        if (myListPanel == null)
        {
            myListPanel = new JPanel();
            myListPanel.setLayout(new BorderLayout());
            myListPanel.add(getHeaderPanel(), java.awt.BorderLayout.WEST);
            myListPanel.add(getFilterPanel(), java.awt.BorderLayout.CENTER);
        }
        return myListPanel;
    }

    /**
     * This method initializes the header panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="headerPanel"
     */
    private JPanel getHeaderPanel()
    {
        if (headerPanel == null)
        {
            headerPanel = new JPanel();
            myListHeaderLabel = new JLabel();
            headerPanel.setLayout(new BorderLayout());
            headerPanel.setSize(811, 45);
            headerPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(5, 5, 10, 5));
            myListHeaderLabel.setText("My List");
            myListHeaderLabel.setFont(MDCFonts.HEADER_FONT);
            myListHeaderLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
            headerPanel.add(myListHeaderLabel, java.awt.BorderLayout.WEST);
        }
        return headerPanel;
    }
}
