/*
 * MDC Desktop Client Created on 03-May-2005
 */
package org.mdcog.client.desktop.gui.panels;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Point;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

import org.mdcog.client.desktop.gui.controllers.SearchResultsTabController;
import org.mdcog.client.desktop.gui.error.MDCInternalException;
import org.mdcog.client.desktop.gui.error.MDCMessageBox;
import org.mdcog.client.desktop.gui.menus.SearchResultsResourceGridPopUpMenu;
import org.mdcog.client.desktop.gui.models.ResourceItemButtonMouseListener;
import org.mdcog.client.desktop.gui.models.ResourceItemTableFormat;
import org.mdcog.client.desktop.gui.models.SearchResultResourceItemTableFormat;
import org.mdcog.client.desktop.gui.models.SearchResultsResourceItemTransferOutHandler;

import ca.odell.glazedlists.swing.EventTableModel;
import ca.odell.glazedlists.swing.TableComparatorChooser;

/**
 * This class implements the generic tab for displaying search results <br/>
 * <br/>Note - It was partially created using the Eclipse Visual Editor plugin
 */
public class SearchResultsGenericTabPanel extends JPanel
{

    /**
     * Stores a reference to the controller for the panel
     * 
     * @uml.property name="controller"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    private SearchResultsTabController controller = null;

    /**
     * Stores a reference to the results table
     */
    private JTable resultsTable = null;

    /**
     * Stores a reference to the results scroll pane
     */
    private JScrollPane resultsScrollPane = null;

    /**
     * Stores a reference to the results filter panel
     */
    private JPanel searchResultsFilterGridPanel = null;

    /**
     * Stores a reference to the filter label
     */
    private JLabel filterLabel = null;

    /**
     * Stores a reference to the filter text field
     */
    private JTextField filterTextField = null;

    /**
     * Stores a reference to the results button panel
     */
    private JPanel searchResultsButtonPanel = null;

    /**
     * Stores a reference to the move to list button
     */
    private JButton moveToListButton = null;

    /**
     * This is the default constructor
     * 
     * @param controller the controller for the panel
     */
    public SearchResultsGenericTabPanel(SearchResultsTabController controller)
    {
        super();
        this.controller = controller;
        initialize();
    }

    /**
     * This method initializes this panel
     */
    private void initialize()
    {
        this.setLayout(new BorderLayout());
        this.setSize(1083, 299);
        this.add(getResultsScrollPane(), java.awt.BorderLayout.CENTER);
        this.add(getSearchResultsFilterGridPanel(), java.awt.BorderLayout.NORTH);
        this.add(getSearchResultsButtonPanel(), java.awt.BorderLayout.SOUTH);
    }

    /**
     * The tab has been closed so we need to clean up all data
     */
    public void closeAndCleanUp()
    {
        // tell the controller to close and clean up
        controller.closeAndCleanUp();
        // set all variables to null to help upclean up process
        controller = null;
        resultsTable = null;
        resultsScrollPane = null;
        searchResultsButtonPanel = null;
        searchResultsFilterGridPanel = null;

    }

    /**
     * This method initializes the results table
     * 
     * @return javax.swing.JTable
     * @uml.property name="resultsTable"
     */
    private JTable getResultsTable()
    {
        if (resultsTable == null)
        {
            resultsTable = new JTable(controller.getResourceTableModel());
            resultsTable.setAutoCreateColumnsFromModel(true);
            new TableComparatorChooser(resultsTable, controller.getSortedResourceItems(), false);
            resultsTable.setSelectionMode(javax.swing.ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
            // set up special renders
            resultsTable.setRowHeight(ResourceItemTableFormat.ROW_HEIGHT);
            resultsTable.setAutoResizeMode(javax.swing.JTable.AUTO_RESIZE_NEXT_COLUMN);
            resultsTable.setRowSelectionAllowed(true);
            resultsTable.setDragEnabled(true);
            resultsTable.setTransferHandler(new SearchResultsResourceItemTransferOutHandler(controller));
            resultsTable.addMouseListener(new ResourceItemButtonMouseListener(resultsTable));
            resultsTable.getTableHeader().addMouseListener(new java.awt.event.MouseAdapter()
            {

                // handle right click on resource list to show popup
                public void mouseReleased(java.awt.event.MouseEvent e)
                {
                    // check if context popup event
                    if (e.isPopupTrigger())
                    {
                        try
                        {
                            // get the column where click occured as new column
                            // may be inserted here
                            int columnClicked = resultsTable.columnAtPoint(new Point(e.getX(), e.getY()));
                            // get the table format information holder
                            EventTableModel eventTableModel = (EventTableModel) resultsTable.getModel();
                            ResourceItemTableFormat tableFormat = (ResourceItemTableFormat) eventTableModel.getTableFormat();
                            tableFormat.showSelectedColumnsPopUp(resultsTable, columnClicked, e.getX(), e.getY());
                        }
                        catch (MDCInternalException exc)
                        {
                            exc.printStackTrace();
                            MDCMessageBox.showInternalError(exc, null);
                        }
                    }
                }
            });
            resultsTable.addMouseListener(new java.awt.event.MouseAdapter()
            {

                // handle right click on resource list to show popup
                public void mouseReleased(java.awt.event.MouseEvent e)
                {
                    // check if context popup event
                    if (e.isPopupTrigger())
                    {
                        // find out row and column affected
                        int rowAffected = resultsTable.rowAtPoint(new Point(e.getX(), e.getY()));
                        //make sure the row/column is automatically selected
                        // that this popup is on
                        resultsTable.addRowSelectionInterval(rowAffected, rowAffected);
                        // show the popup giving it reference to the
                        // resourceList
                        SearchResultsResourceGridPopUpMenu popup = new SearchResultsResourceGridPopUpMenu(controller,
                                resultsTable.getSelectedRows());
                        popup.show(resultsTable, e.getX(), e.getY());
                    }
                    else
                    {
                        super.mouseReleased(e);
                    }
                }
            });
            setupColumns(resultsTable);
        }
        return resultsTable;
    }

    /**
     * Sets up the special renders for the grid using
     * SearchResultResourceItemTableFormat
     * 
     * @param resourceTable
     */
    private void setupColumns(JTable resourceTable)
    {
        // get the table format information holder
        EventTableModel eventTableModel = (EventTableModel) resourceTable.getModel();
        SearchResultResourceItemTableFormat tableFormat = (SearchResultResourceItemTableFormat) eventTableModel.getTableFormat();
        // get the column model
        TableColumnModel columnModel = resourceTable.getColumnModel();
        TableColumn column = null;
        // now loop round each column setting it upt
        for (int i = 0; i < columnModel.getColumnCount(); i++)
        {
            column = columnModel.getColumn(i);
            tableFormat.setUpColumn(column, column.getModelIndex());

        }
    }

    /**
     * This method initializes the results scroll pane
     * 
     * @return javax.swing.JScrollPane
     * @uml.property name="resultsScrollPane"
     */
    private JScrollPane getResultsScrollPane()
    {
        if (resultsScrollPane == null)
        {
            resultsScrollPane = new JScrollPane();
            resultsScrollPane.setViewportView(getResultsTable());
        }
        return resultsScrollPane;
    }

    /**
     * This method initializes filter grid panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="searchResultsFilterGridPanel"
     */
    private JPanel getSearchResultsFilterGridPanel()
    {
        if (searchResultsFilterGridPanel == null)
        {
            searchResultsFilterGridPanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            filterLabel = new JLabel();
            searchResultsFilterGridPanel.setLayout(flowLayout);
            searchResultsFilterGridPanel.setSize(50, 46);
            searchResultsFilterGridPanel.setComponentOrientation(java.awt.ComponentOrientation.LEFT_TO_RIGHT);
            filterLabel.setText("Filter: ");
            filterLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            searchResultsFilterGridPanel.add(filterLabel, null);
            searchResultsFilterGridPanel.add(getFilterTextField(), null);
        }
        return searchResultsFilterGridPanel;
    }

    /**
     * This method initializes filter text field
     * 
     * @return javax.swing.JTextField
     * @uml.property name="filterTextField"
     */
    private JTextField getFilterTextField()
    {
        if (filterTextField == null)
        {
            filterTextField = controller.getResourceItemsFilterTextControl();
            filterTextField.setPreferredSize(new java.awt.Dimension(500, 23));
        }
        return filterTextField;
    }

    /**
     * This method initializes the buttons panel
     * 
     * @return javax.swing.JPanel
     * @uml.property name="searchResultsButtonPanel"
     */
    private JPanel getSearchResultsButtonPanel()
    {
        if (searchResultsButtonPanel == null)
        {
            searchResultsButtonPanel = new JPanel();
            FlowLayout flowLayout = new FlowLayout();
            searchResultsButtonPanel.setLayout(flowLayout);
            searchResultsButtonPanel.setSize(517, 42);
            flowLayout.setAlignment(java.awt.FlowLayout.RIGHT);
            searchResultsButtonPanel.add(getMoveToListButton(), null);
        }
        return searchResultsButtonPanel;
    }

    /**
     * This method initializes the move to my list button
     * 
     * @return javax.swing.JButton
     * @uml.property name="moveToListButton"
     */
    private JButton getMoveToListButton()
    {
        if (moveToListButton == null)
        {
            moveToListButton = new JButton();
            moveToListButton.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
            moveToListButton.setText("Move to my list");
            moveToListButton.addActionListener(new java.awt.event.ActionListener()
            {

                /**
                 * Add the selected rows to my list
                 */
                public void actionPerformed(java.awt.event.ActionEvent e)
                {
                    controller.copySearchResultResourceItemsToMyList(resultsTable.getSelectedRows());
                }
            });
        }
        return moveToListButton;
    }

} //  @jve:decl-index=0:visual-constraint="10,10"
