/*
 * MDC Desktop Client Created on 22-Apr-2005
 */
package org.mdcog.client.desktop.gui.table.renderers;

import java.awt.Component;
import java.util.Iterator;
import java.util.Vector;

import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

import org.mdcog.client.desktop.gui.models.ResourceItemButtonListener;

/**
 * This class renders the buttons for the ResourceItem URLs
 * 
 * @uml.dependency supplier="org.mdcog.client.desktop.gui.models.ResourceItemButtonListener" stereotypes="Basic::Call"
 */

public class ResourceItemURLRenderer extends JButton implements TableCellRenderer
{

    /**
     * Stores a reference to the action listeners
     */
    private Vector URLListeners = null;

    /**
     * Constructor
     * 
     * @param buttonText The text for the button
     * @param image the image to display on the button
     */
    public ResourceItemURLRenderer(String buttonText, Icon image)
    {
        init(buttonText, image);
        setOpaque(true);
        URLListeners = new Vector();
    }

    /**
     * Registers listeners to this renderer. These are called when the item is
     * clicked
     * 
     * @param listener The ResourceItemButtonListener to register
     */
    public void addURLListener(ResourceItemButtonListener listener)
    {
        URLListeners.add(listener);
    }

    /**
     * Called to get the renderer by the table This is called to get the
     * component renderer
     * 
     * @param table The table the editor is against
     * @param value The data to be edited
     * @param isSelected indicates if currently selected
     * @param cellHasFocus indicates if the cell has focus
     * @param row The cell row
     * @param column the cell column
     * @return The component that does the editing
     */
    public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean cellHasFocus, int row,
            int column)
    {
        // sort out the highlight colors if we are selected
        if (isSelected)
        {
            setBackground(table.getSelectionBackground());
        }
        else
        {
            setBackground(table.getBackground());
        }

        return this;
    }

    /**
     * This is Called when the table tells the renderer it was clicked. This
     * method informs registered listeners of the click
     * 
     * @param row the row that was clicked
     */
    public void clicked(int row)
    {
        // iterate around the URLlistners and tell them the URL was clicked
        Iterator iter = URLListeners.iterator();
        while (iter.hasNext())
        {
            ((ResourceItemButtonListener) iter.next()).buttonClicked(row);
        }
    }
}
