/*
 * MDC Desktop Client Created on 22-Apr-2005
 */
package org.mdcog.client.desktop.gui.table.renderers;

import java.awt.Component;

import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import javax.swing.table.TableCellRenderer;

import org.mdcog.client.desktop.model.ResourceList;

/**
 * Renders a ResourceList into the list
 */
public class ResourceListEntryRenderer extends JLabel implements TableCellRenderer
{

    /**
     * Stores a reference to a border object for rendering a small border
     */
    private static Border noFocusBorder = new EmptyBorder(1, 1, 1, 1);

    /**
     * Constructor
     */
    public ResourceListEntryRenderer()
    {
        setOpaque(true);
        setIconTextGap(12);
    }

    /**
     * This is called to get the component renderer
     * @param table The table the editor is against
     * @param value The data to be edited
     * @param isSelected indicates if currently selected 
     * @param cellHasFocus indicates if the cell has focus
     * @param row The cell row
     * @param column the cell column
     * @return The component that does the editing
     */
   
    public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean cellHasFocus, int row,
            int column)
    {

        // get the ResourceList and set on the label
        ResourceList entry = (ResourceList) value;
        setText(entry.getResourceListName());
        setIcon(entry.getImage());

        // sort out the highlight colors if we are selected
        if (isSelected)
        {
            setBackground(table.getSelectionBackground());
            setForeground(table.getSelectionForeground());
        }
        else
        {
            setBackground(table.getBackground());
            setForeground(table.getForeground());
        }

        // now sort out highlights if cell has focus
        if (cellHasFocus)
        {
            setBorder(UIManager.getBorder("List.focusCellHighlightBorder"));
        }
        else
        {
            setBorder(noFocusBorder);
        }
        return this;
    }
}
