/*
 * MDC Desktop Client Created on 28-Jun-2005
 */
package org.mdcog.client.desktop.utils;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

/**
 * This class loads and stores the configuration properties
 */
public class MDCConfig
{
    /**
     * Stores a reference to the singleton instance
     */
    private static MDCConfig instance = new MDCConfig();
    
    /**
     * Stores a reference to the configuration filename
     */
    private final static String MDCCONFIG = "MDCConfig.properties";

    /**
     * Stores a reference to the lookup key for the last library
     */
    public final static String LASTLIBRARY = "lastlibrary";
    
    /**
     * Stores a reference to the lookup key for the last library
     */
    public final static String BASE_RESOLVER = "baseresolver";
    
    /**
     * Stores a reference to the to the lookup key for the mdc webservice
     */
    public final static String MDC_WEB_SERVICE = "mdcwebservice";
    
    /**
     * Stores a reference to the to the lookup key for the mdc webservice num record
     */
    public final static String MDC_WEB_SERVICE_MAX_RECORDS = "mdcwebservicemaxrecords";
    /**
     * Stores a reference to the the to the lookup key for the mdc home page
     */
    public final static String MDC_HOME_PAGE = "mdchomepage";
    
    /**
     * Stores a reference to the the to the lookup key for the mdc home page hyperlink html
     */
    public final static String MDC_HYPERLINK = "mdchomehyperlinkhtml";
    
    /**
     * Stores a reference to the the to the lookup key for the mdc home page hyperlink html
     */
    public final static String MDC_USER_GUIDE = "mdcuserguide";
    
    
    /**
     * Stores a reference to the properties loaded
     */
    private Properties config = new Properties();

    /**
     * Private constructor
     */
    private MDCConfig()
    {
        // attempt to load configuration
        loadConfig();
    }
    
    /**
     * Get an instance of the MDC configuratiion settings
     * @return The static instance of MDCConfig
     */
    public static MDCConfig getInstance()
    {
        return instance;
    }
    
    /**
     * Loads the MDC application config properites in from file
     * 
     * @return true if file loaded ok
     */
    public boolean loadConfig()
    {
        boolean loaded = false;

        try
        {
            // open the properties file
            FileInputStream instream = new FileInputStream(MDCCONFIG);
            config.load(instream);
            instream.close();
            loaded = true;
        }
        catch (FileNotFoundException e)
        {
            System.err.println("PROPERTIES FILE NOT FOUND");
        }
        catch (IOException e)
        {
            System.err.println("PROPERTIES FILE LOAD IO EXCEPTION");
            e.printStackTrace();
        }
        return loaded;
    }

    /**
     * Save the MDC application config properites to file
     * 
     * @return true if file saved ok
     */
    public boolean saveConfig()
    {
        boolean saved = false;

        try
        {
            // open the properties file
            FileOutputStream outstream = new FileOutputStream(MDCCONFIG);
            config.store(outstream, "MDC Configuration File");
            outstream.close();
            saved = true;
        }
        catch (FileNotFoundException e)
        {
            System.err.println("PROPERTIES FILE NOT SAVED");
        }
        catch (IOException e)
        {
            System.err.println("PROPERTIES FILE SAVE IO EXCEPTION");
            e.printStackTrace();
        }
        return saved;
    }

    /**
     * Returns the property specified by the key in the configuration settings
     * @param key The key to search for
     * @return The value or null if not found
     */
    public String getProperty(String key)
    {
        return config.getProperty(key);
    }
    
    /**
     * Returns the property specified by the key in the configuration settings
     * @param key The key to search for
     * @param defaultValue The default value returned if not found
     * @return The value or null if not found
     */
    public String getProperty(String key,String defaultValue)
    {
        return config.getProperty(key,defaultValue);
    }

    /**
     * stores the property into the configuration settings
     * @param key The key to store under
     * @param value The value to store
     */
    public void setProperty(String key, String value)
    {
        config.setProperty(key, value);
    }

}
