<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:m="http://www.loc.gov/mods/v3"
    xmlns="http://www.w3.org/1999/xhtml"
    exclude-result-prefixes=""
    >
<!--
mod3 to xhtml - for mdc
-->

<xsl:param name="style">vaguely-harvard</xsl:param>

<xsl:template match="/">
	<html>
		<head>
			<title>MDC Resource List</title>
			<style type="text/css">
				<xsl:choose>
					<xsl:when test="$style='vaguely-harvard'">
						body {color:black;}
						.author {color:red; padding: 3px;}
						.title {font-style:italic; padding: 3px;}
						.publisher {color:green; padding: 3px;}
						.publicationPlace {color: maroon; padding: 3px;}
						.publicationDate {color: teal; padding: 3px;}
					</xsl:when>
					<xsl:otherwise>
						body {color:black;}
						.author {color:red; padding: 3px;}
						.title {color:blue; padding: 3px;}
						.publisher {color:green; padding: 3px;}
						.publicationPlace {color: maroon; padding: 3px;}
						.publicationDate {color: teal; padding: 3px;}
					</xsl:otherwise>
				</xsl:choose>
			</style>
		</head>
		<body>
			
			<div id="header">
				<xsl:apply-templates select="//m:mods" mode="header" />
			</div>
			
			<ol>
				<xsl:apply-templates select="//m:mods" mode="item" />
			</ol>
		</body>
	</html>
</xsl:template>


<xsl:template match="m:mods" mode="header">
 <xsl:if test="position() &lt; 2" >
 	<h2>
			<xsl:call-template name="strip-char">
				<xsl:with-param name="text" select="m:titleInfo/m:title" />
			</xsl:call-template>
	</h2>
 	<strong>Creator: </strong><xsl:value-of select="m:name[@type='personal']/m:displayForm" /><br/>
	<strong>Issued: </strong>
			<xsl:call-template name="strip-char">
				<xsl:with-param name="text" select="m:originInfo/m:dateIssued" />
			</xsl:call-template>
 </xsl:if>
</xsl:template>

<!-- VAGULEY HARVARD: Author's surname, author's first name or initial. (year of publication), Title of the Book, edition [if not first], publisher's name, place of publication -->

<xsl:template match="m:mods" mode="item">
 <xsl:if test="position() &gt; 1 " >
	<li>
		<p>
		<span class="author">
			<xsl:call-template name="strip-char">
				<xsl:with-param name="text" select="m:name[@type='personal']/m:displayForm" />
			</xsl:call-template>
		</span>
		<span class="publicationDate">
			<xsl:call-template name="strip-char">
				<xsl:with-param name="text" select="m:originInfo/m:dateIssued" />
			</xsl:call-template>
		</span>
		<span class="title">
			<xsl:call-template name="strip-char">
				<xsl:with-param name="text" select="m:titleInfo/m:title" />
			</xsl:call-template>
		</span>
		<span class="publisher">
     <xsl:apply-templates select="m:originInfo/m:publisher" />
		</span>
		<span class="publisher">
			<xsl:call-template name="strip-char">
				<xsl:with-param name="text" select="m:originInfo/m:place/m:placeTerm[@type='text']" />
			</xsl:call-template>
		</span>
		</p>
	</li>
 </xsl:if>
</xsl:template>


<xsl:template name="strip-char">
	<xsl:param name="text" />
	<xsl:if test="string-length($text) > 0" > 
		<xsl:variable name="starttext" select="substring($text, 1, (string-length($text) - 1 ) )" />
		<xsl:variable name="endtext" select="substring($text, (string-length($text) ) )" />
		<xsl:choose>
			<xsl:when test="translate($endtext, '/ ,:.', '') = ''">
				<xsl:call-template name="strip-char">
					<xsl:with-param name="text" select="$starttext" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:if>
</xsl:template>


</xsl:stylesheet>