/*
 * MDC Desktop Client Created on 30-Jun-2005
 */
package org.mdcog.util;

import gov.loc.www.zing.srw.RecordType;
import gov.loc.www.zing.srw.SearchRetrieveRequestType;
import gov.loc.www.zing.srw.SearchRetrieveResponseType;
import gov.loc.www.zing.srw.srw_bindings.SRWSoapBindingStub;

import java.net.MalformedURLException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.List;

import org.apache.axis.AxisFault;
import org.apache.axis.types.PositiveInteger;
import org.mdcog.client.desktop.gui.error.MDCInternalException;

/**
 * This class performs all the communication with the web servers webservices
 */
public class MDCWebServiceHandler
{

    /**
     * Stores a reference to the web service URL. Intialised to the default oxford server
     */
    private String serviceURL = "http://oxfordltgdev.org.uk:8080/mdc/services/SRW";

    /**
     * Creates an instance of the webs ervice handler specifying the URL to use to find the web service
     * @param url The url to use with this web service handler
     */
    public MDCWebServiceHandler(String url)
    {
        serviceURL = url;
    }
    
    /**
     * Returns a collection of mods records for supplied search
     * 
     * @param searchText The text to search under
     * @param startRecord the record to start at
     * @param maxRecords The maximum number of records to return
     * @return A mods Collection string containg the results
     * @throws MDCInternalException
     */
    public List doSearch(String searchText, int startRecord, int maxRecords) throws MDCInternalException
    {
        ArrayList modsArray = new ArrayList();

        try
        {
            SRWSoapBindingStub srwBinding;
            srwBinding = new SRWSoapBindingStub(new java.net.URL(serviceURL), null);

            SearchRetrieveRequestType request = new SearchRetrieveRequestType();
            request.setVersion("1.1");
            request.setQuery(searchText);
            request.setStartRecord(new PositiveInteger(Integer.toString(startRecord)));
            request.setMaximumRecords(new PositiveInteger(Integer.toString(maxRecords)));
            request.setRecordPacking("string");

            SearchRetrieveResponseType response = srwBinding.searchRetrieveOperation(request);
            RecordType[] records = response.getRecords().getRecord();

            // make sure we found records
            if (records != null)
            {
                for (int i = 0; i < records.length; i++)
                {
                    String recordPacking = records[i].getRecordPacking();
                    if (recordPacking == null)
                    {
                        // This is only here because of a broken DSpace SRW
                        // server!!! strictly recordPacking should never be null
                        recordPacking = "string"; //strictly recordPacking
                                                  // should
                    }

                    if (recordPacking.equalsIgnoreCase("string"))
                    {
                        // append the xml data to return string
                        modsArray.add(records[i].getRecordData().get_any()[0].getNodeValue());
                    }
                }
            }
        }
        catch (AxisFault e)
        {
            e.printStackTrace();
            throw new MDCInternalException("Failure processing request with webservice");
        }
        catch (MalformedURLException e)
        {
            e.printStackTrace();
            throw new MDCInternalException("Failure processing request with webservice - BAD URL");
        }
        catch (RemoteException e)
        {
            e.printStackTrace();
            throw new MDCInternalException("Remote exception processing request with webservice");
        }

        return modsArray;
    }
}
