/*
 * MDC Desktop Client Created on 23-May-2005
 */
package org.mdcog.util.transfer;

import java.util.Iterator;

/**
 * This interface defines the methods that must be implemented to transfer
 * resource information between the client and server. Although the format will
 * always be XML this class does not expose the mechanisum being used to
 * manipulate and access the the underlying data. <BR>
 * <BR>
 * The ResourceTransferHeader and ResourceTransferItem objects below are
 * lightweight classes that encapsulates all the data in the xml section they
 * are related to. <BR>
 */
public interface MDCDataTransferer
{

    /**
     * This method creates a new list blanking any currently loaded data
     * 
     * @param header The header to create the list about. If Null a blank header
     *        will be created
     */
    public void createEmptyList(ResourceTransferHeader header);

    /**
     * This method loads the list from XML supplied, blanking any currently
     * loaded data
     * 
     * @param transferData String representation of the data.
     * @throws TransferException thrown on any transfer problem encaspulating
     *         exception that caused problem
     */
    public void loadList(String transferData) throws TransferException;

    /***************************************************************************
     * TRANSFORM Methods
     **************************************************************************/

    /**
     * Converts the current list into MODS format
     * 
     * @return The list as XML in MODS format
     * @throws TransferException thrown on any transfer problem encaspulating
     *         exception that caused problem
     */
    public String toMODS() throws TransferException;

    /**
     * Converts the current list into RLI format
     * 
     * @return The list as XML in RLI format
     * @throws TransferException thrown on any transfer problem encaspulating
     *         exception that caused problem
     */
    public String toRLI() throws TransferException;

    /**
     * TRANSFERING IN / IMPORTING METHODS
     * 
     * @return ResourceTransferHeader
     * @uml.property name="header"
     * @uml.associationEnd multiplicity="(0 1)"
     */
    public ResourceTransferHeader getHeader();


    /**
     * This method provides an iterator round each of the resource items in the
     * list. Each element returned by the iterator will be of type Resource
     * 
     * @return An iterator of all the Resource items
     */
    public Iterator getResourceIterator();

    /***************************************************************************
     * TRANSFERING OUT / EXPORTING METHODS
     **************************************************************************/

    /**
     * This method adds a resource to the list.
     * 
     * @param resource The Resource to add
     */
    public void addResource(ResourceTransferItem resource);

    /**
     * This method sets the current ResourceTransferHeader.
     * 
     * @param header The header to be set
     * 
     * @uml.property name="header"
     */
    public void setHeader(ResourceTransferHeader header);

}
