/*
 * MDC Desktop Client Created on 23-May-2005
 */
package org.mdcog.util.transfer;

import org.mdcog.util.ModsUtils;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * This class represents the Resource List header that has been transfered.
 */
public class ResourceTransferHeader extends ResourceTransferData
{

    /**
     * Use this string to get the author field
     */
    public final static String AUTHOR = "author";

    /**
     * Use this string to get the owner field
     */
    public final static String OWNER = "owner";

    /**
     * Use this string to get the title field
     */
    public final static String TITLE = "title";
    
    /**
     * Use this string to get the date created field
     */
    public final static String DATE_CREATED = "dateIssued";

    /**
     * Use this string to get the annotation field
     */
    public final static String ANNOTATION = "annotation";

    /**
     * Sets the raw XML that constitutes this header. Overrides the parent
     * method. The fields map is initialised from appropriate fields in the xml
     * document. You should call super(rawXmlAsDomNode), so that the source xml
     * string is correctly stored.
     * 
     * @param rawXmlAsDomNode The rawxml to set.
     * @throws TransferException thrown on any transfer problem encaspulating
     *         exception that caused problem
     */
    protected void setRawXml(Node rawXmlAsDomNode) throws TransferException
    {
        super.setRawXml(rawXmlAsDomNode);
        // Extract fields and populate fields map
        setFields(ModsUtils.getFields((Element) rawXmlAsDomNode));
    }

    /**
     * This method updates the raw xml with the current data stored in the
     * fields map. It is abstract and every specific Transfer Data class must
     * implement it to convert their specific data. If the raw xml is blank then
     * this method will also create the xml from scratch. <br>
     * <br>
     * As this is the header record and is MDC specific we can regenerate it
     * every time we need to
     * 
     * @throws TransferException thrown on any transfer problem encaspulating
     *         exception that caused problem
     */
    public void updateRawXMLFromFields() throws TransferException
    {
        // use modes utils to create the record as when exporting the header needs to be recreated every time
        super.setRawXml(ModsUtils.toModsRecordXml(getFields(), "", ModsUtils.SOURCE_CLIENT, ModsUtils.TYPE_HEADER, null));
    }

}