/*
 * MDC Desktop Client Created on 23-May-2005
 */
package org.mdcog.util.transfer;

import org.mdcog.util.ModsUtils;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * This class represents the one Resource Item int eh list that has been
 * transfered.
 */
public class ResourceTransferItem extends ResourceTransferData
{

    /**
     * Use this string to get the author field
     */
    public final static String AUTHOR = "author";

    /**
     * Use this string to get the type field
     */
    public final static String TYPE = "type";

    /**
     * Use this string to get the title field
     */
    public final static String TITLE = "title";

    /**
     * Use this string to get the abstract field
     */
    public final static String ABSTRACT = "abstract";

    /**
     * Use this string to get the annotation field
     */
    public final static String ANNOTATION = "annotation";

    /**
     * Use this string to get the publisher field
     */
    public final static String PUBLISHER = "publisher";

    /**
     * Use this string to get the dateIssued field
     */
    public final static String DATE_ISSUED = "dateIssued";

    /**
     * Use this string to get the dateCreated field
     */
    public final static String DATE_CREATED = "dateCreated";

    /**
     * Use this string to get the isbn field
     */
    public final static String ISBN = "isbn";

    /**
     * Use this string to get the issn field
     */
    public final static String ISSN = "issn";

    /**
     * Use this string to get the web url field
     */
    public final static String WEB_URL = "weburl";

    /**
     * Sets the raw XML that constitutes this header. Overrides the parent
     * method. The fields map is initialised from appropriate fields in the xml
     * document. You should call super(rawXmlAsDomNode), so that the source xml
     * string is correctly stored.
     * 
     * @param rawXmlAsDomNode The rawxml to set.
     * @throws TransferException thrown on any transfer problem encaspulating
     *         exception that caused problem
     */
    protected void setRawXml(Node rawXmlAsDomNode) throws TransferException
    {
        super.setRawXml(rawXmlAsDomNode);
        // Extract fields and populate fields map
        setFields(ModsUtils.getFields((Element) rawXmlAsDomNode));
    }

    /**
     * This method updates the raw xml with the current data stored in the
     * fields map. It is abstract and every specific Transfer Data class must
     * implement it to convert their specific data. If the raw xml is blank then
     * this method will also create the xml from scratch. <br>
     * <br>
     * Currently the desktopclient can only update the annotation so if the
     * rawxml already exists then this is the only field updated by this method.
     * 
     * @throws TransferException thrown on any transfer problem encaspulating
     *         exception that caused problem
     */
    public void updateRawXMLFromFields() throws TransferException
    {
        try
        {
            // Have we set any raw xml yet
            if (rawXml.length() == 0)
            {
                // use mods utils to create new raw xml and store it. call super version as we do not want to parse out the data again.
                super.setRawXml(ModsUtils.toModsRecordXml(getFields(), "", ModsUtils.SOURCE_CLIENT, ModsUtils.TYPE_RESOURCE, null));
            }
            else
            {
                // update annotation adding if not currently present
                ModsUtils.updateAnnotation((Element)rawXmlNode, getField(ANNOTATION));
                // call super version as we do not want to parse out the data again just restore the new rawXML
                super.setRawXml(rawXmlNode);
            }
        }
        catch (Exception e)
        {
            throw new TransferException(e);
        }
    }

}
